/***************************************************************************
 *   KFreeFlight : a FlightGear GUI-Frontend designed for KDE users        *
 *                                                                         *
 *   Copyright (C) 2006 by Didier Fabert                                   *
 *   [didier.fabert AT free.fr]                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "aircraft_view.h"
/*
-lsgroute -lsgsky -lsgsound -lsgephem -lsgmaterial -lsgtgdb -lsgmodel -lsgtiming -lsgio -lsgscreen -lsgmath -lsgbucket -lsgprops -lsgdebug -lsgmagvar -lsgmisc -lsgnasal -lsgxml -lsgsound -lsgserial -lsgstructure -lsgenvironment -lsgthreads -lpthread  -lplibpu -lplibfnt -lplibjs -lplibnet -lplibssgaux -lplibssg -lplibsg -lplibul  -lz -lglut -lGLU -lGL -lXmu -lXt -lSM -lICE -lXi -lXext -lX11 -ldl -lm  -lopenal -ldl -lm   -lpthread  -ljpeg

*/
Aircraft_view::Aircraft_view(QWidget *parent, const char *name)
 : QGLWidget(parent, name)
{
    scene = 0;
    aircraft=0;
    obj=0;
    branch=0;
    m_aircraftName = new QString();
    resetOffset();
    m_font = new QFont();
    m_font->setFamily( "Serif" );
    m_font->setPointSize( 10 );
    m_font->setBold( true );
    m_font->setItalic( FALSE );
}


Aircraft_view::~Aircraft_view()
{
    glEnd();
}

void Aircraft_view::resetOffset()
{
    EyeDist = 0.0f;
    EyeAz = 165.0f;
    EyeEl = 0.0f;
    Ex = 0.0f;
    Ey = 0.0f;
    Ez = 0.0f;
}

void Aircraft_view::initPlib()
{
    // Init opengl
    glInit();
    setAutoBufferSwap(true);
    //updateGL();

    // Some basic OpenGL setup
    qglClearColor (*m_backgroundColor);
    qglColor ( *m_foregroundColor );
    glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
    glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
    glEnable ( GL_DEPTH_TEST ) ;
    glEnable(GL_BLEND);
    glEnable(GL_LIGHTING);
    glShadeModel(GL_SMOOTH);
    glViewport(0,0,width(),height());

    // Initialise SSG
    ssgInit () ;

    // Set up the viewing parameters
    ssgSetFOV     ( 60.0f, atan(tan(30.0 * SG_DEGREES_TO_RADIANS) *
        height() / width() ) * SG_RADIANS_TO_DEGREES * 2 ) ;
    ssgSetNearFar ( 3.0f, 1000.0f ) ;

    // Set up the Sun.
    sgVec3 sunposn ;
    sgSetVec3 ( sunposn, -0.5f, 0.5f, 0.5f ) ;
    ssgGetLight ( 0 ) -> setPosition ( sunposn ) ;
    updateGL();

    // Create a root node
    scene    = new ssgRoot ;
    aircraft = new ssgTransform ;
    obj=0;
    branch=0;
}


/**
  *
*/
void Aircraft_view::loadAircraft( QString fname, QString tpath )
{
    KStandardDirs appShareDir;
    QString buffer;
    bool tuxRendering=false;

    const char* model = fname.ascii();
    buffer=fname.remove(fname.section('/',-1,-1));
    const char* modelPath = buffer.ascii();
    const char* texturePath = tpath.ascii();

    ssgModelPath   ( modelPath ) ;
    ssgTexturePath ( texturePath ) ;

    obj=0;
    branch=0;

    if (!isValid()) initPlib();

    obj = ssgLoad ( model ) ;

    if ( obj == 0 )
    {
        KMessageBox::sorry(this, QString(tr2i18n("Cannot load file :")+"\n"+fname) );
        QString buffer;
        buffer = appShareDir.findResource("data", "kfreeflight/tux.ac");
        const char *texturePathTux = buffer.remove("/tux.ac").latin1();
        ssgModelPath   ( texturePathTux ) ;
        ssgTexturePath ( texturePathTux ) ;
        obj = ssgLoad ( "tux.ac" ) ;
        tuxRendering=true;
    }

    if (tuxRendering == false) EyeDist = obj->getBSphere()->getRadius() +10.0f;
    else EyeDist = obj->getBSphere()->getRadius() +3.0f;
    center = obj->getBSphere()->getCenter();
    sgVec3 dir;
    sgSetVec3( dir, -center[0], -center[1], -center[2] );

    sgMat4 transMat;
    sgMakeTransMat4 ( transMat, dir ) ;

    aircraft  -> setTransform( transMat );
    aircraft  -> addKid ( obj  ) ;

    //obj->print();

    scene    -> addKid ( aircraft ) ;
    update();
    emit (modelLoaded());
}

void Aircraft_view::loadAircraftXml( QString fgroot, QString xmlFile )
{
    QString buffer;
    SGPropertyNode *propNode;

    obj=0;
    branch=0;

    if (!isValid()) initPlib();

    propNode = new SGPropertyNode();
    branch = sgLoad3DModel(fgroot.ascii(), xmlFile.ascii(), propNode, 1.0);

    if ( !branch )
    {
        KMessageBox::sorry(this, QString(tr2i18n("Cannot load file :")+"\n"+xmlFile) );
        return;
    }

    EyeDist = branch->getBSphere()->getRadius() +10.0f;
    center = branch->getBSphere()->getCenter();
    sgVec3 dir;
    sgSetVec3( dir, -center[0], -center[1], -center[2] );

    sgMat4 transMat;
    sgMakeTransMat4 ( transMat, dir ) ;


    aircraft -> setTransform( transMat );
    aircraft -> addKid ( branch  ) ;
    scene    -> addKid ( aircraft ) ;
    update();
    delete propNode;
    emit modelLoaded();
}

void Aircraft_view::makeMatrix(sgMat4 mat)
{
  SGfloat angle = -EyeAz * SG_DEGREES_TO_RADIANS ;
  sgVec3 eye ;
  eye[0] = (SGfloat) cos (angle) * EyeDist ;
  eye[1] = (SGfloat) sin (angle) * EyeDist ;
  angle = EyeEl * SG_DEGREES_TO_RADIANS ;
  eye[2] = (SGfloat) sin (angle) * EyeDist ;
  sgVec3 center ;
  sgSetVec3(center, Ex, Ey, Ez);
  sgVec3 up;
  sgSetVec3(up, 0.0f, 0.0f, 0.1f);
  sgMakeLookAtMat4(mat, eye, center, up);
}

void Aircraft_view::clear()
{
    if (scene)
    {
        aircraft->removeAllKids();
        scene->removeAllKids();
        //delete aircraft;
        delete scene;
    }
    glClear  ( GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT ) ;
    updateGL();
    resetOffset();
}

void Aircraft_view::updateView()
{
    static bool flagDirDown=false;
    EyeAz -= 0.5f;
    if (EyeAz <= 0.0f) EyeAz = 360.0f;
    if (EyeEl <= -5.0f)  flagDirDown = false;
    if (EyeEl >=  35.0f) flagDirDown = true;
    if (flagDirDown == false) EyeEl += 0.2f;
    else EyeEl -= 0.2f;
    update();
}

void Aircraft_view::update()
{
    QString buffer;

    glClear  ( GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT ) ;
    qglColor (*m_foregroundColor);
    renderText ( 10, 20, *m_aircraftName, *m_font);
    //renderText ( 10, 260, "Eye Distance = "+buffer.setNum(EyeDist, 'f', 2), *m_font);
    glPushMatrix();
    sgMat4 mat;
    makeMatrix(mat);
    ssgSetCamera(mat);
    ssgCullAndDraw(scene);
    glPopMatrix();
    updateGL();
}

void Aircraft_view::mousePressEvent( QMouseEvent* e )
{
    if ( !rect().contains( e->pos() ) )
        return;

    switch( e->button() )
    {
        case LeftButton: { EyeDist = EyeDist-2.0f; update(); break; }
        case MidButton: { resetOffset(); update(); break; }
        case RightButton: { EyeDist = EyeDist+2.0f; update(); break; }
        default: break;
    }
}

void Aircraft_view::keyPressEvent( QKeyEvent* e )
{
    switch (e->key())
    {
        /*
        case (Qt::Key_4 ): { ;break; }
        case (Qt::Key_6 ): { ;break; }
        case (Qt::Key_9 ): { ;break; }
        case (Qt::Key_3 ): { ;break; }
        case (Qt::Key_8 ): { ;break; }
        case (Qt::Key_2 ): { ;break; }
        case (Qt::Key_S ): { ;break; }
        case (Qt::Key_R ): { ;break; }
        */
        case (Qt::Key_Plus ):  { EyeDist -= 1.0f;break; }
        case (Qt::Key_Minus ): { EyeDist += 1.0f;break; }

        default: return;
    }
}

