/***************************************************************************
 *   KFreeFlight : a FlightGear GUI-Frontend designed for KDE users        *
 *                                                                         *
 *   Copyright (C) 2006 by Didier Fabert                                   *
 *   [didier.fabert AT free.fr]                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef AIRCRAFT_VIEW_H
#define AIRCRAFT_VIEW_H

#include <qobject.h>
#include <qgl.h>
#include <qcolor.h>
#include <qfont.h>
#include <qimage.h>
#include <qdir.h>
#include <qstring.h>


#include <GL/glut.h>
#include <plib/ssg.h>
#include <simgear/misc/sg_path.hxx>
#include <simgear/props/props.hxx>
#include <simgear/scene/model/model.hxx>
#include <vector>
#include <set>

#include <kstandarddirs.h>
#include <kmessagebox.h>
#include <klocale.h>

/**
	@author Didier Fabert <didier.fabert@free.fr>
*/
class Aircraft_view : public QGLWidget
{
    Q_OBJECT
public:
    Aircraft_view( QWidget *parent = 0, const char *name = 0 );

    ~Aircraft_view();

    void initPlib();
    void loadAircraft( QString fname, QString tpath );
    void loadAircraftXml( QString fgroot, QString xmlFile );
    void clear();

public:
    GLfloat downDist, downEl, downAz, downEx, downEy, downEz;
    GLfloat EyeDist, EyeAz, EyeEl, Ex, Ey, Ez;
    const float *center;
    QColor *m_backgroundColor, *m_foregroundColor;
    QFont *m_font;
    QString *m_aircraftName;

public slots:
    void update();
    void updateView();

private:
    void resetOffset();
    void makeMatrix(sgMat4 mat);

private:
    ssgRoot* scene;
    ssgTransform *aircraft;
    ssgEntity *obj;
    ssgBranch *branch;

public slots:
    virtual void mousePressEvent( QMouseEvent* e );
    virtual void keyPressEvent( QKeyEvent* e );

signals:
    void modelLoaded();
};

#endif
