/***************************************************************************
 *   KFreeFlight : a FlightGear GUI-Frontend designed for KDE users        *
 *                                                                         *
 *   Copyright (C) 2006 by Didier Fabert                                   *
 *   [didier.fabert AT free.fr]                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#include "airport_view.h"
#include <zlib.h>

Airport_view::Airport_view(QWidget* parent, const char* name, WFlags fl,
    QString airportID)
: airportWindow(parent,name,fl)
{
    LE_AirportID->setText(airportID);
    LE_Airport->setText(airportID);
    Table_Runway->setColumnWidth(0,60);
    Table_Runway->setColumnWidth(1,155);
    Table_Runway->setColumnWidth(2,130);
    Table_Runway->setColumnWidth(3,120);
    ListBox_Airport->insertItem(tr2i18n("Search by name, ICAO code or coordinates"),0);

    m_fgroot = new QString();
    m_airportName = new QString();
    m_longit = new QString();
    m_latit = new QString();
    m_radius = new QString();
    m_appShareDir = new KStandardDirs();

    m_worldView=0;
    *m_longit="E0,0";
    *m_latit="N0,0";
    *m_radius="100";
}

Airport_view::~Airport_view()
{
}

/*$SPECIALIZATION$*/
void Airport_view::closeSlot()
{
    close();
}

void Airport_view::findAirportSlot()
{
    char line[128];
    QString buffer, buffer2, letterID, airportList;
    bool flagWriting=false, flagRewriting=false;
    int row=0, It=0;
    gzFile m_airportfile;
    int countAirport=0, reply;
    double longitudeAirport, longitude, latitudeAirport, latitude, radius, distance;

    m_airportfile = 0;
    Table_Runway->setNumRows(0);
    ListBox_Airport->clear();
    LE_AirportID->setText("");
    LE_AirportName->setText("");
    LE_AirportElevation->setText("");
    LE_Longitude->setText("");
    LE_Latitude->setText("");
    ListBox_Atis->clear();
    ListBox_Tower->clear();
    ListBox_Others->clear();
    airportList="";

    m_config->setGroup("Settings FlightGear");
    *m_fgroot=m_config->readEntry("FG_ROOT", "undefined");
    buffer=*m_fgroot;
    buffer.append("/Airports/apt.dat.gz");
    m_airportfile = gzopen( buffer, "rb" );
    if (m_airportfile == 0)
    {
        KMessageBox::sorry(this, buffer+"\n"
            +tr2i18n("file not found!\n\nPlease check your FG_ROOT path in the settings menu."));
        return;
    }
    if (LE_Airport->text()=="")
    {
        KMessageBox::sorry(this, tr2i18n("No search to do!\n\nPlease tell me what to do!"));
        return;
    }
    if (RB_researchCoordinate->isChecked())
    {
        //interpreter la recherche
        if (LE_Airport->text().section(" ",2,2) == "0") return;

        longitudeAirport=LE_Airport
          ->text().section(" ",0,0).replace("E","").replace("W","-").replace(',',".").toDouble();
        latitudeAirport=LE_Airport
          ->text().section(" ",1,1).replace("N","").replace("S","-").replace(',',".").toDouble();
        radius=LE_Airport->text().section(" ",2,2).replace(',',".").toDouble();
    }
    for (It=0; gzgets( m_airportfile, line, sizeof line ) != 0 ; It++)
    {
      buffer = line;
      buffer=buffer.simplifyWhiteSpace();
      if (RB_researchName->isChecked())
      {
        if ((buffer.simplifyWhiteSpace().contains(LE_Airport->text().simplifyWhiteSpace(),false) > 0) && 
            ((buffer.left(2) == "1 ") || (buffer.left(2) == "17") ))
        {
            if(flagRewriting == true)
            {
                Table_Runway->setNumRows(0);
                row=0;
            }
            flagWriting=true; flagRewriting=true;
            buffer = buffer.simplifyWhiteSpace();
            LE_AirportElevation->setText(buffer.section(' ',1,1));
            LE_AirportID->setText(buffer.section(' ',4,4));
            LE_AirportName->setText(buffer.section(' ',5));
            ListBox_Airport->insertItem(buffer.section(' ',4,4)+" "+buffer.section(' ',5),
                (ListBox_Airport->count()));
            countAirport++;
        }
        if (buffer.stripWhiteSpace() == "")  { flagWriting=false; }
        if ((buffer.stripWhiteSpace().left(2) == "10") && (flagWriting == true) 
            && (buffer.contains("xxx",false) <= 0))
        {
            buffer=buffer.stripWhiteSpace().simplifyWhiteSpace();
            LE_Longitude->setText(buffer2.setNum(buffer.section(' ',2,2).toDouble(),'f',2));
            LE_Latitude->setText(buffer2.setNum(buffer.section(' ',1,1).toDouble(),'f',2));
            Table_Runway->insertRows(row, 1);
            Table_Runway->setText(row, 0, buffer.section(' ',3,3).remove('x'));
            Table_Runway->setText(row, 1, buffer.section(' ',4,4));
            Table_Runway->setText(row, 2, buffer2=buffer2.setNum(buffer.section(' ',5,5)
                .toDouble()*0.3048006,'f',0));
            Table_Runway->setText(row, 3, buffer2=buffer2.setNum(buffer.section(' ',8,8)
                .toDouble()*0.3048006,'f',0));
            row++;

            if (buffer.section(' ',3,3).remove('x').toInt() > 0)
            {
                if (buffer.section(' ',3,3).remove('x').toInt() <= 18)
                    buffer2 = buffer2.setNum(buffer.section(' ',3,3).remove('x').toInt()+18,10);
                else buffer2 = buffer2.setNum(buffer.section(' ',3,3).remove('x').toInt()-18,10);
            }
            else
            {
                letterID=buffer.section(' ',3,3);
                if (letterID.right(1) == "L")
                {
                    if(buffer.section(' ',3,3).remove('L').toInt() <= 18)
                        buffer2 = buffer2.setNum(buffer.section(' ',3,3).remove('L').toInt()+18,10)+"R";
                    if(buffer.section(' ',3,3).remove('L').toInt() > 18)
                        buffer2 = buffer2.setNum(buffer.section(' ',3,3).remove('L').toInt()-18,10)+"R";
                }
                if (letterID.right(1) == "R")
                {
                    if(buffer.section(' ',3,3).remove('R').toInt() <= 18)
                        buffer2 = buffer2.setNum(buffer.section(' ',3,3).remove('R').toInt()+18,10)+"L";
                    if(buffer.section(' ',3,3).remove('R').toInt() > 18)
                        buffer2 = buffer2.setNum(buffer.section(' ',3,3).remove('R').toInt()-18,10)+"L";
                }
                if ((letterID.right(1) != "R") && (letterID.right(1) != "L"))
                {
                    if(buffer.section(' ',3,3).remove(letterID.right(1)).toInt() <= 18)
                        buffer2 = buffer2.setNum(
                        buffer.section(' ',3,3).remove(letterID.right(1)).toInt()+18,10)
                            +letterID.right(1);
                    if(buffer.section(' ',3,3).remove(letterID.right(1)).toInt() > 18)
                        buffer2 = buffer2.setNum(
                        buffer.section(' ',3,3).remove(letterID.right(1)).toInt()-18,10)
                            +letterID.right(1);
                    if(buffer.section(' ',3,3).contains('H') > 0 ) buffer2="";
                }
            }
            if(buffer2 != "")
            {
                Table_Runway->insertRows(row, 1);
                Table_Runway->setText(row, 0, buffer2);
                Table_Runway->setText(row, 1, buffer2=buffer2.setNum(
                    (buffer.section(' ',4,4).toDouble()+180.0),'f',2));
                Table_Runway->setText(row, 2, buffer2=buffer2.setNum(
                    buffer.section(' ',5,5).toDouble()*0.3048006,'f',0));
                Table_Runway->setText(row, 3, buffer2=buffer2.setNum(
                    buffer.section(' ',8,8).toDouble()*0.3048006,'f',0));
                row++;
            }
        }
        if ((buffer.stripWhiteSpace().left(1) == "5") && (flagWriting == true))
        {
            if ((buffer.contains("ATIS",false) <= 0) && (buffer.contains("TWR",false) <= 0))
            {
                buffer2=buffer.section(' ',1,1).left(3)+"."+buffer.section(' ',1,1).right(2)
                    +" "+buffer.section(' ',2);
                ListBox_Others->insertItem(buffer2,-1);
            }
        }
      }
      if (RB_researchCoordinate->isChecked())
      {
        //interpreter la recherche

        //lire airport id et mettre dans la liste apparente
        buffer = buffer.simplifyWhiteSpace();
        if((buffer.left(2) == "1 ") || (buffer.left(2) == "17") )
        {
            *m_airportName = buffer.section(' ',4,4)+" "+buffer.section(' ',5);
            flagWriting=true;
        }
        if ((buffer.stripWhiteSpace().left(2) == "10") && (buffer.contains("xxx",false) <=0)
             && (flagWriting == true) )
        {
            longitude=buffer.section(' ',2,2).toDouble();
            latitude=buffer.section(' ',1,1).toDouble();
            distance=calculateDistance( longitudeAirport, latitudeAirport, longitude, latitude);
            if (distance <= radius)
            {
                buffer2 = buffer2.setNum(distance,'f',1);
                buffer2.append("km "+*m_airportName);
                ListBox_Airport->insertItem(buffer2,-1);
                countAirport++;
            }
            flagWriting=false;
        }
      }
    }

    gzclose(m_airportfile);
    if (((RB_researchCoordinate->isChecked()) && (countAirport>0)) || 
        ((countAirport>0) && (RB_researchName->isChecked()) ))
    {
            reply = KMessageBox::questionYesNo(this,tr2i18n("Number of airport found :")
                +buffer.setNum(countAirport,10)+"\n"+tr2i18n("Try in KWeather database ?"));
            switch (reply)
            {
                case 3:searchInKWeatherDatabase();break;
                default:break;
            }
    }

    if (((LE_AirportName->text().stripWhiteSpace() == "") && (RB_researchName->isChecked()) ) ||
        ((RB_researchCoordinate->isChecked()) && (countAirport==0)))
    {
        if ((LE_AirportName->text().stripWhiteSpace() == "") && (RB_researchName->isChecked()) )
        {
            reply = KMessageBox::warningYesNo(this,tr2i18n("No airport found !")+"\n"+
                tr2i18n("Try in KWeather database ?"));
            switch (reply)
            {
                case 3:searchInKWeatherDatabase();break;
                default:break;
            }
        }
        if ((RB_researchCoordinate->isChecked()) && (countAirport==0))
        {
            LE_Airport->clear();
            KMessageBox::sorry(this,tr2i18n("No airport found !"));
        }
    }
    else
    {
        if (RB_researchName->isChecked())
        {
            findILSFrequency();
            findGroundFrequency();
        }
        else { LE_Airport->clear(); }
    }
    RB_researchCoordinate->setChecked(false);
    RB_researchName->setChecked(true);
}

void Airport_view::findILSFrequency()
{
    QString buffer, buffer2;
    char line[128];
    gzFile m_navfile;
    int It, ItBis;

    buffer=*m_fgroot;
    buffer.append("/Navaids/nav.dat.gz");
    m_navfile = gzopen( buffer, "rb" );
    if (m_navfile == 0)
    {
        KMessageBox::sorry(this, buffer+"\n"
            +tr2i18n("file not found!\n\nPlease check your FG_ROOT path in the settings menu."));
        return;
    }
    for (It=0; gzgets( m_navfile, line, sizeof line ) != 0 ; It++)
    {
        buffer = line;
        //ILS
        if (buffer.simplifyWhiteSpace().contains(LE_AirportID->text().simplifyWhiteSpace(),true) > 0)
        {
            buffer=buffer.simplifyWhiteSpace();
            for (ItBis=0 ; ItBis <= Table_Runway->numRows() ; ItBis++)
            {
                //FlightGear CVS version
                if ((buffer.section(' ',9,9) == Table_Runway->text(ItBis,0) ) &&
                  ((buffer.contains("ILS-cat-") > 0) || (buffer.contains("LOC") ) ))
                {
                    buffer2=buffer.simplifyWhiteSpace().section(' ',4,4);
                    Table_Runway->setText(ItBis, 4, buffer2.left(3)+"."+buffer2.right(2));
                }
                //FlightGear 0.9.9 version
                if ((buffer.section(' ',8,8) == Table_Runway->text(ItBis,0) ) &&
                  ((buffer.left(1) == "4") || (buffer.left(1) == "5" ) ) && (buffer.right(3) == "LLZ"))
                {
                    buffer2=buffer.simplifyWhiteSpace().section(' ',4,4);
                    Table_Runway->setText(ItBis, 4, buffer2.left(3)+"."+buffer2.right(2));
                }
            }
        }
    }
    gzclose(m_navfile);
}

void Airport_view::findGroundFrequency()
{
    QString fichier,buffer;
    QFile file;
    QTextStream stream;
    QListBox *m_listBox;

    for (int It=0 ; It < 2 ; It++)
    {
        fichier = *m_fgroot;
        stream.unsetDevice();
        switch (It)
        {
            //ATIS frequencies
            case 0: { fichier.append("/ATC/default.atis"); m_listBox=ListBox_Atis; break; }
            //Tower frequencies
            case 1: { fichier.append("/ATC/default.tower");m_listBox=ListBox_Tower; break;  }
        }
        file.setName(fichier);
        if ( file.open( IO_ReadOnly ) ) 
        {
            stream.setDevice( &file );

            while ( !stream.atEnd() )
            {
            buffer = stream.readLine();
            if (buffer.simplifyWhiteSpace().contains(LE_AirportID->text().simplifyWhiteSpace(),true) > 0)
            {
                buffer=buffer.simplifyWhiteSpace();
                m_listBox->insertItem(buffer.section(' ',4,4),-1);
            }
        }
        file.close();
        }
        else
        {
            KMessageBox::sorry(this, fichier+"\n"
                +tr2i18n("file not found!\n\nPlease check your FG_ROOT path in the settings menu."));
            return;
        }
    }
}

void Airport_view::searchInKWeatherDatabase()
{
    QString fichier,buffer;
    QFile file;
    QTextStream stream;

    fichier = m_appShareDir->findResource("data","kweatherservice/stations.dat");

    file.setName(fichier);
    if ( file.open( IO_ReadOnly ) ) 
    {
        stream.setDevice( &file );

        while ( !stream.atEnd() )
        {
        buffer = stream.readLine();
        buffer=buffer.simplifyWhiteSpace();
        if (buffer.contains(LE_Airport->text().simplifyWhiteSpace(),false) > 0)
        {
            ListBox_Airport->insertItem("(KWeather) "+buffer.section(';',0,0)+" "+buffer.section(';',3,3)
                +" "+buffer.section(';',5,5),-1);
        }
    }
    file.close();
    }
    else
    {
        KMessageBox::sorry(this, fichier+"\n"
            +tr2i18n("file not found!\n\nPlease check if KWeather is installed."));
        return;
    }
}

void Airport_view::putFindingAirportSlot()
{
    RB_researchCoordinate->setChecked(false);
    RB_researchName->setChecked(true);
    if((ListBox_Airport->currentText().section(' ',0,0).remove("km").toDouble() > 0.0) ||
        (ListBox_Airport->currentText().section(' ',0,0) == "0.0km") )
    {
        LE_Airport->setText(ListBox_Airport->currentText().section(' ',1));
        return;
    }

    if (ListBox_Airport->currentText().section(' ',0,0) == "(KWeather)")
    {
        LE_Airport->setText(ListBox_Airport->currentText().section(' ',1,1));
        return;
    }

    LE_Airport->setText(ListBox_Airport->currentText());
}

void Airport_view::showPlaceSlot()
{
    m_worldView = new World_view(0, "World Map", 0 ,m_config);
    m_worldView->show();
    m_worldView->putPoint(LE_Longitude->text().section('.',0,0).toInt(),
        LE_Latitude->text().section('.',0,0).toInt() );
    m_worldView->setFont(*m_font);
    m_worldView->setPaletteForegroundColor( *m_foreground );
    m_worldView->m_close->setPaletteForegroundColor( *m_foreground );
    m_worldView->m_showGrid->setPaletteForegroundColor( *m_foreground );
    m_worldView->m_change->setPaletteForegroundColor( *m_foreground );
    m_worldView->m_config = m_config;

}

void Airport_view::coordinateWindowSlot()
{
    m_researchView = new Research_view(0, "Coordinates", 0, *m_longit, *m_latit, *m_radius);
    m_researchView->setFont(*m_font);
    m_researchView->setPaletteForegroundColor( *m_foreground );
    m_researchView->m_okButton->setPaletteForegroundColor( *m_foreground );
    m_researchView->m_latitude->setPaletteForegroundColor( *m_edit );
    m_researchView->m_longitude->setPaletteForegroundColor( *m_edit );
    m_researchView->m_radius->setPaletteForegroundColor( *m_edit );
    m_researchView->m_latitude->setPaletteBackgroundColor( *m_background );
    m_researchView->m_longitude->setPaletteBackgroundColor( *m_background );
    m_researchView->m_radius->setPaletteBackgroundColor( *m_background );
    connect (m_researchView, SIGNAL(parametersAre( QString )), this, SLOT(coordinateReceiveSlot(QString)));
    m_researchView->show();
}

void Airport_view::coordinateReceiveSlot( QString coordinates)
{
    LE_Airport->setText(coordinates);
    *m_longit = coordinates.section(' ',0,0);
    *m_latit = coordinates.section(' ',1,1);
    *m_radius = coordinates.section(' ',2,2);
}

double Airport_view::calculateDistance(double lon1, double lat1, double lon2, double lat2)
{
    double earthRadius = 6371.0; // earth's mean radius in km
    double dLat, dLong, a, c, d;

    //convert angle in radians and calculate the delta
    lon1 = M_PI*(lon1)/180;
    lat1 = M_PI*(lat1)/180;
    lon2 = M_PI*(lon2)/180;
    lat2 = M_PI*(lat2)/180;
    dLat  = lat2 - lat1;
    dLong = lon2 - lon1;

    //apply the very very simple math formula :-)
    //found at http://www.movable-type.co.uk/scripts/LatLong.html
    a = (sin(dLat/2) * sin(dLat/2)) + ( cos(lat1) * cos(lat2) * sin(dLong/2) * sin(dLong/2));
    c = 2 * atan2(sqrt(a), sqrt(1-a));
    d = earthRadius * c;

    return d;
}

void Airport_view::applySettings()
{
    setFont(*m_font);
    setPaletteForegroundColor( *m_foreground );
    Table_Runway->setPaletteForegroundColor( *m_edit );
    LE_Airport->setPaletteForegroundColor( *m_edit );
    LE_AirportID->setPaletteForegroundColor( *m_edit );
    LE_AirportName->setPaletteForegroundColor( *m_edit );
    LE_AirportElevation->setPaletteForegroundColor( *m_edit );
    ListBox_Airport->setPaletteForegroundColor( *m_edit );
    BTN_Close->setPaletteForegroundColor( *m_foreground );
    BTN_Find->setPaletteForegroundColor( *m_foreground );
    ListBox_Atis->setPaletteForegroundColor( *m_edit );
    ListBox_Tower->setPaletteForegroundColor( *m_edit );
    ListBox_Others->setPaletteForegroundColor( *m_edit );
    LE_Longitude->setPaletteForegroundColor( *m_edit );
    LE_Latitude->setPaletteForegroundColor( *m_edit );
    BTN_ShowPlace->setPaletteForegroundColor( *m_foreground );

    Table_Runway->setPaletteBackgroundColor( *m_background );
    LE_Airport->setPaletteBackgroundColor( *m_background );
    LE_AirportID->setPaletteBackgroundColor( *m_background );
    LE_AirportName->setPaletteBackgroundColor( *m_background );
    LE_AirportElevation->setPaletteBackgroundColor( *m_background );
    ListBox_Airport->setPaletteBackgroundColor( *m_background );
    ListBox_Atis->setPaletteBackgroundColor( *m_background );
    ListBox_Tower->setPaletteBackgroundColor( *m_background );
    ListBox_Others->setPaletteBackgroundColor( *m_background );
    LE_Longitude->setPaletteBackgroundColor( *m_background );
    LE_Latitude->setPaletteBackgroundColor( *m_background );

    if (m_worldView != 0)
    {
        m_worldView->setFont(*m_font);
        m_worldView->setPaletteForegroundColor( *m_foreground );
        m_worldView->m_close->setPaletteForegroundColor( *m_foreground );
        m_worldView->m_showGrid->setPaletteForegroundColor( *m_foreground );
        m_worldView->m_change->setPaletteForegroundColor( *m_foreground );
        m_worldView->m_config = m_config;
    }
}
#include "airport_view.moc"

