/***************************************************************************
 *   KFreeFlight : a FlightGear GUI-Frontend designed for KDE users        *
 *                                                                         *
 *   Copyright (C) 2006 by Didier Fabert                                   *
 *   [didier.fabert AT free.fr]                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <klocale.h>

#include "fgpref.h"

FgPref::FgPref(QWidget* parent, const char* name, WFlags fl)
: Flightgear(parent,name,fl)
{
    //Initialising pointer QLineEdit
    m_fgroot=LE_FG_ROOT;
    m_fgscenery=LE_FG_SCENERY_2;
    m_fgexe=LE_FG_exe;
    m_fgoptions=LE_options;
    //Initialising pointer QListBox
    m_fgexelist=ListBox_FgExe;
    m_fgoptionslist=ListBox_Option;
    //Initialising pointer QPushButton
    m_fgexeadd=BTN_AddExe;
    m_fgexedel=BTN_DelExe;
    m_fgoptionsadd=BTN_AddOption;
    m_fgoptionsdel=BTN_DelOption;

    LE_FG_ROOT->setText("/usr/share/games/FlightGear/");
    LE_FG_SCENERY_2->setText("/usr/share/games/FlightGear/Data/Scenery/");
    LE_FG_exe->setText("fgfs");

    m_fileDlg = new KFileDialog(QString::null, "text/plain", this, "fileDlgFg", true);
}

FgPref::~FgPref()
{
}

/*$SPECIALIZATION$*/
void FgPref::selectEXESlot()
{
    LE_FG_exe->setText(ListBox_FgExe->currentText());
}

void FgPref::findExeSlot()
{
 QString buffer, Path;

    if (LE_FG_ROOT->text().isEmpty()) { Path="/usr"; }
    else Path=LE_FG_ROOT->text().stripWhiteSpace();

    buffer = m_fileDlg->getOpenFileName(Path,
    "all/allfiles",
     this, tr2i18n("Choose your FlightGear exe file"));

    if (!buffer.isEmpty()) LE_FG_exe->setText(buffer);
}

void FgPref::findFGSCENERYSlot()
{
    QString buffer, Path;

    if (LE_FG_SCENERY_2->text().isEmpty())
    {
        if (LE_FG_ROOT->text().isEmpty()) Path="/usr/share";
        else Path=Path=LE_FG_ROOT->text().stripWhiteSpace();
    }
    else Path=LE_FG_SCENERY_2->text().stripWhiteSpace();

    buffer = m_fileDlg->getExistingDirectory(Path, this,
        tr2i18n("Choose your FlightGear addon scenery directory"));
    if (!buffer.isEmpty()) LE_FG_SCENERY_2->setText(buffer);
}

void FgPref::findFGROOTSlot()
{
    QString buffer, Path;

    if (LE_FG_ROOT->text().isEmpty()) Path="/usr/share";
    else Path=LE_FG_ROOT->text().stripWhiteSpace();

    buffer = m_fileDlg->getExistingDirectory(Path, this,
        tr2i18n("Choose your FlightGear root directory"));
    if (!buffer.isEmpty()) LE_FG_ROOT->setText(buffer);
}

void FgPref::delExeSlot()
{
    ListBox_FgExe->removeItem(ListBox_FgExe->currentItem());
}

void FgPref::addExeSlot()
{
    ListBox_FgExe->insertItem(LE_FG_exe->text().stripWhiteSpace(),(ListBox_FgExe->count()+1));
}

void FgPref::addOptionSlot()
{
    ListBox_Option->insertItem(LE_options->text().stripWhiteSpace(),(ListBox_Option->count()+1));
}

void FgPref::delOptionSlot()
{
    ListBox_Option->removeItem(ListBox_Option->currentItem());
}

void FgPref::editOptionSlot()
{
    LE_options->setText(ListBox_Option->currentText());
    ListBox_Option->removeItem(ListBox_Option->currentItem());
}

#include "fgpref.moc"

