/***************************************************************************
 *   KFreeFlight : a FlightGear GUI-Frontend designed for KDE users        *
 *                                                                         *
 *   Copyright (C) 2006 by Didier Fabert                                   *
 *   [didier.fabert AT free.fr]                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "kfreeflight.h"

/**
 * kfreeflight class constructor: init the kmainwindow
 * @return 
 */
kfreeflight::kfreeflight()
    : KSystemTray( 0, "kfreeflight")
{
    KIconLoader iconLoader;

    integratedSystray=false;

    m_splashScreen = new Splash();
    m_splashScreen->show();

    m_gui = new kfreeflight_window();
    setPixmap( loadIcon( "kfreeflight") );

    popup = contextMenu();
    popup->idAt( 0 );
    popup->insertItem( iconLoader.loadIcon( "fork", KIcon::Small ),
                    "&"+tr2i18n( "Fly now") , this,
                    SLOT( launchFlightgear() ) );
    popup->insertSeparator();
    popup->insertItem( iconLoader.loadIcon( "contents", KIcon::Small ),
                    tr2i18n( "&Help") , this,
                    SLOT( showHelp()));
    popup->insertItem( iconLoader.loadIcon( "help", KIcon::Small ),
                    tr2i18n( "&About") , this,
                    SLOT( showAbout()));
    popup->insertSeparator();
    popup->insertItem( iconLoader.loadIcon( "configure", KIcon::Small ),
                    tr2i18n( "&Configure")+" KFreeFlight" , this,
                    SLOT( showConfigureDialog()) );

    SystrayIntegration(checkConfig( "Settings General", "Systray integration"));

    /*connect( m_gui->m_mainWindow, SIGNAL(loadingData( QString )),
        m_splashScreen, SLOT(writeMessages(QString)));*/
    //splashScreen();
    m_timerSplash = new QTimer();
    m_timerSplash->start(1000*5, false);
    connect(m_timerSplash, SIGNAL(timeout()), SLOT(timerFinished()));
    connect( m_gui->m_mainWindow, SIGNAL(allJobsFinished()), SLOT(appFinished()));
    connect( this, SIGNAL(quitSelected ()), this, SLOT(quitApp()));
    connect( m_gui, SIGNAL(queryIntegrated(bool)), this, SLOT(SystrayIntegration(bool)));

    timerFinish=false;
    appFullyLoaded=false;
}

/**
 * kfreeflight class destructor
 * @return 
 */
kfreeflight::~kfreeflight()
{
}

void kfreeflight::quitApp()
{
    m_gui->externExitQuery=true;
    m_gui->m_mainWindow->saveSlot();
    kapp->quit();
}

void kfreeflight::mousePressEvent( QMouseEvent* e )
{
    if ( !rect().contains( e->pos() ) )
        return;

    switch( e->button() )
    {
        case LeftButton:
        {
            if (m_gui->isShown() )
            {
                m_gui->hide();
                m_gui->m_mainWindow->disableOpenGLWidget();
            }
            else  //setActive();
            {
                m_gui->show(); 
                m_gui->m_mainWindow->enableOpenGLWidget();
                m_gui->m_mainWindow->changePixmapSlot();
            }
            break;
        }
        case MidButton: { showAbout(); break; }
        case RightButton: { KSystemTray::mousePressEvent( e ); break; }
        default: break;
    }
}

void kfreeflight::timerFinished()
{
    timerFinish=true;
    closeSplash();
}

void kfreeflight::appFinished()
{
    appFullyLoaded=true;
    closeSplash();
}

void kfreeflight::closeSplash()
{
    if ((timerFinish == false) || (appFullyLoaded == false)) { return; }

    m_timerSplash->stop();
    delete m_timerSplash;
    //close splashscreen
    delete m_splashScreen;
    m_gui->splashClosed();
    if (integratedSystray == true)
    {
        if (checkConfig("Settings General", "Minimized starting") == true) { m_gui->hide(); }
        else { m_gui->show(); }
    }
    else { m_gui->show(); }
}

void kfreeflight::showConfigureDialog()
{
    m_gui->optionPreferences();
}

void kfreeflight::launchFlightgear()
{
    m_gui->m_mainWindow->launchFlightgearSlot();
}

void kfreeflight::showHelp()
{
    kapp -> invokeHelp (0, "kfreeflight");
}

void kfreeflight::showAbout()
{
    KAboutApplication aboutApp( m_about );
    aboutApp.exec();
}


bool kfreeflight::checkConfig(QString groupConfig, QString entryConfig)
{
    KConfig *m_generalConfig, *m_config;
    bool returnFlag=false;
    QString buffer;

    m_generalConfig = new KConfig("kfreeflightrc", false, true, "config");

    if (m_generalConfig->hasGroup("Config file"))
    {
        m_generalConfig->setGroup("Config file");
        buffer=m_generalConfig->readEntry("File", "default");
        m_config = new KConfig("kfreeflight/"+buffer, false, true, "config");
        if (m_config->hasGroup(groupConfig))
        {
            m_config->setGroup(groupConfig);
            buffer=m_config->readEntry(entryConfig,"false");
            if (buffer == "true") { returnFlag=true; }
            else  { returnFlag=false; }
        }
        delete m_config;
    }
    delete m_generalConfig;
    return returnFlag;
}

void kfreeflight::SystrayIntegration(bool integrate)
{
    if (integrate == true)
    {
        m_gui->notSystrayIntegrated = false;
        integratedSystray = true;
        //setActive ();
        show();
    }
    else
    {
        m_gui->notSystrayIntegrated = true;
        integratedSystray = false;
        //setInactive ();
        hide();
    }
}

#include "kfreeflight.moc"
