/***************************************************************************
 *   KFreeFlight : a FlightGear GUI-Frontend designed for KDE users        *
 *                                                                         *
 *   Copyright (C) 2006 by Didier Fabert                                   *
 *   [didier.fabert AT free.fr]                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#include "kfreeflight_view.h"

/*$Global variable $*/
    bool verbose_app=false;
    bool notFirstAircraftFilling=false;
    bool notFirstDisplay=false;

KFreeFlight_view::KFreeFlight_view(QWidget* parent, const char* name, WFlags fl)
: mymainwindow(parent,name,fl)
{
    QString  HomeDirectory, DestDirectory, buffer;
    QDir tmp;
    QFile file;

    //initialising pointer to the actual config file
    getConfigFile();
    m_weatherWindow=0;
    m_airportWindow=0;
    m_aircraftView=0;
    m_aircraftSpinTimer=0;
    m_aircraftPixmapView=0;
    openglEnabled=false;


    //Filling the objects of the widget
    emit(loadingData( tr2i18n("Apply Settings")));
    fillObjects ();

    //VERbose?
    verboseSlot();
    applySettings();

    m_fgfsOutput = new QString();
    m_aircraftModel = new QString("c172p/Models/c172p.ac");
    m_aircraftTexturePath = new QString("c172p/Models/");
    m_aircraftToolTip = new QString(tr2i18n("Left click - Major the model size\nRight click - Minor the model size\n"));

    // Checking of directory existence in $HOME and Creating application directory if false
    HomeDirectory=QDir::homeDirPath ();
    DestDirectory=HomeDirectory+AppDirectory;
    m_destDirectory = new QString(DestDirectory);
    if (tmp.mkdir(DestDirectory,true))
    {
        if (verbose_app == true ) 
            { TXTEdit_STDOUT->append(tr2i18n("Construction of directory :")+DestDirectory);}
        createIniFiles(DestDirectory);
    }
    else
    {
        if (verbose_app == true ) 
            { TXTEdit_STDOUT->append(DestDirectory
                +tr2i18n(" directory already exist, skip creating!")); }
    }

    m_loadBySimgear=0;
    reloadSimgearList();

    //create aircraft list
    getAircraftListSlot();

    if (verbose_app == true ) TXTEdit_STDOUT->append(tr2i18n("Load airport list!"));
    emit(loadingData( tr2i18n("Load Airport list")));
    switch (loadAirportList())
    {
        case 0:
            if (verbose_app == true ) TXTEdit_STDOUT->append(tr2i18n("*** Success *** : Airports file loaded"));
            break;

        default:
            if (verbose_app == true ) 
            {
                TXTEdit_STDOUT->append(tr2i18n("*** Error *** : Can't open airports file"));
                TXTEdit_STDOUT->append(tr2i18n("*** Error *** : Did you erase airports.dat in your $HOME")
                    +AppDirectory+" ?");
            }
    }
    emit(loadingData( tr2i18n("Make aircraft list")));
    connect(this, SIGNAL(aircraftComboBoxFully()), this, SLOT(reloadSlot()) );

    if (m_config->hasGroup("Settings FlightGear"))
    {
        m_config->setGroup("Settings FlightGear");
        buffer=m_config->readEntry("Personnal resolution","undefined");
        if (buffer != "undefined")
        {
            ComboBox_Resolution->insertItem(buffer,-1);
        }
    }
    m_fileDlg = new KFileDialog(QString::null, "text/plain", this, "fileDlg", true);

    //when settings are changed
    connect(parent, SIGNAL(settingsChanged()), this, SLOT(applySettings()) );
    connect(parent, SIGNAL(settingsFileChanged()), this, SLOT(changeSettingsFile()) );
    connect(parent, SIGNAL(settingsNewFile()), this, SLOT(changeNewFile()) );
}

KFreeFlight_view::~KFreeFlight_view()
{
    saveSlot();
}

/*$SPECIALIZATION$*/
void KFreeFlight_view::dmeDefreezeSlot()
{
    kDoubleSpinBox_DME->setEnabled(true);
}

void KFreeFlight_view::dmeFreezeSlot()
{
    kDoubleSpinBox_DME->setEnabled(false);
}

void KFreeFlight_view::runwayAddSlot()
{
    QFile file;
    QStringList lines;
    QTextStream stream;
    QString buffer;

    file.setName(QDir::homeDirPath ()+AppDirectory+LE_Airport->text().stripWhiteSpace().upper()+".dat");
    if ( file.open( IO_ReadOnly ) ) 
    {
        stream.setDevice( &file );
        while ( !stream.atEnd() ) { lines << stream.readLine(); }
        file.close();
    }
    buffer=LE_Runway->text().stripWhiteSpace().upper();
    if (!buffer.isEmpty()) lines << buffer;
    if ( file.open( IO_WriteOnly ) ) 
    {
        stream.setDevice( &file );
        for ( QStringList::Iterator it = lines.begin(); it != lines.end(); ++it )
        { stream << *it << "\n"; }
        file.close();
    }
    changeAirportInformations();
}

void KFreeFlight_view::runwayDelSlot()
{
    QFile file;
    QStringList lines;
    QTextStream stream;
    QString buffer;
    bool flag_eraseFile=false;

    file.setName(QDir::homeDirPath ()+AppDirectory+LE_Airport->text().stripWhiteSpace().upper()+".dat");
    if ( file.open( IO_ReadOnly ) ) 
    {
        stream.setDevice( &file );
        while ( !stream.atEnd() )
        {
            buffer=stream.readLine();
            buffer=buffer.stripWhiteSpace();
            if (buffer != LE_Runway->text().stripWhiteSpace().upper())
            lines << buffer;
        }
        file.close();
    }

    //traitement
    stream.reset();
    if ( file.open( IO_WriteOnly ) ) 
    {
        stream.setDevice( &file );
        for ( QStringList::Iterator it = lines.begin(); it != lines.end(); ++it )
        { stream << *it << "\n"; }
        file.close();
        QStringList::Iterator it=lines.begin();
        buffer=*it;
        if (buffer.stripWhiteSpace().isEmpty()) flag_eraseFile=true;
    }
    //si pas de piste -> efface fichier
    if (flag_eraseFile)
    {
        KMessageBox::sorry( this, tr2i18n("Empty File, Deleted file!"));
        file.remove();
    }
    changeAirportInformations();
    LE_Runway->clear();
}

void KFreeFlight_view::airportDelSlot()
{
    QFile file;
    QStringList lines;
    QTextStream stream;
    QString buffer,bufferBegin;

    file.setName(QDir::homeDirPath ()+AppDirectory+AirportFile);
    if ( file.open( IO_ReadOnly ) ) 
    {
        stream.setDevice( &file );
        while ( !stream.atEnd() )
        {
            buffer=stream.readLine();
            bufferBegin=buffer.stripWhiteSpace().section(' ',0,0);
            if (bufferBegin != LE_Airport->text().stripWhiteSpace().upper())
            lines << buffer;
        }
        file.close();
    }

    //traitement

    file.setName(QDir::homeDirPath ()+AppDirectory+AirportFile);
    if ( file.open( IO_WriteOnly ) ) 
    {
        stream.setDevice( &file );
        for ( QStringList::Iterator it = lines.begin(); it != lines.end(); ++it )
        { stream << *it << "\n"; }
        file.close();
    }
    loadAirportList();
    file.setName(QDir::homeDirPath ()+AppDirectory+LE_Airport->text().stripWhiteSpace().upper()+".dat");
    file.remove();
    LE_Runway->clear();
    changeAirportInformations();
}

void KFreeFlight_view::airportAddSlot()
{
    QFile file;
    QStringList lines;
    QTextStream stream;

    file.setName(QDir::homeDirPath ()+AppDirectory+AirportFile);
    if ( file.open( IO_ReadOnly ) ) 
    {
        stream.setDevice( &file );
        while ( !stream.atEnd() ) { lines << stream.readLine(); }
        file.close();
    }
    lines << LE_Airport->text().stripWhiteSpace().upper()
        +" "+LE_AddAirport_City->text().stripWhiteSpace();
    file.setName(QDir::homeDirPath ()+AppDirectory+AirportFile);
    if ( file.open( IO_WriteOnly ) ) 
    {
        stream.setDevice( &file );
        for ( QStringList::Iterator it = lines.begin(); it != lines.end(); ++it )
        { stream << *it << "\n"; }
        file.close();
    }
    loadAirportList();
    changeAirportInformations();
}

void KFreeFlight_view::wayPointDefreezeEditSlot()
{
    ListBox_WayPoint->setEnabled(true);
    BTN_WayPoint_Help->setEnabled(true);
    BTN_WayPoint_Delete->setEnabled(true);
    BTN_WayPoint_Save->setEnabled(true);
    BTN_WayPoint_Add->setEnabled(true);
    LE_Waypoint_ID->setEnabled(true);
    TXTLabel_Waypoint_ID->setEnabled(true);
    TXTLabel_Waypoint_Altitude->setEnabled(true);
    SpinBox_WayPoint_Altitude->setEnabled(true);
    PixmapLabel_WayPoint->setEnabled(true);
    BTN_FindFile->setEnabled(false);
    LE_FindFile->setEnabled(false);
    ListBox_WayPoint->setEnabled(true);
}

void KFreeFlight_view::wayPointDefreezeFileSlot()
{
    ListBox_WayPoint->setEnabled(false);
    BTN_WayPoint_Help->setEnabled(false);
    BTN_WayPoint_Delete->setEnabled(false);
    BTN_WayPoint_Save->setEnabled(false);
    BTN_WayPoint_Add->setEnabled(false);
    LE_Waypoint_ID->setEnabled(false);
    TXTLabel_Waypoint_ID->setEnabled(false);
    TXTLabel_Waypoint_Altitude->setEnabled(false);
    SpinBox_WayPoint_Altitude->setEnabled(false);
    PixmapLabel_WayPoint->setEnabled(false);
    LE_FindFile->setEnabled(true);
    BTN_FindFile->setEnabled(true);
    ListBox_WayPoint->setEnabled(false);
}

bool KFreeFlight_view::searchPID( QString appName)
{
    KProcess *m_getPID;
    QString buffer;

    m_pid = new QStringList();
    m_getPID = new KProcess();
    *m_getPID << "ps aux";

    m_getPID->setUseShell(true,"/bin/sh");

    QApplication::connect(m_getPID,
        SIGNAL(receivedStdout(KProcess *, char *, int)),
        this,
        SLOT(receivePID(KProcess *, char *, int )));

    m_getPID->start(KProcess::Block, KProcess::AllOutput);

    for ( QStringList::Iterator it = m_pid->begin(); it != m_pid->end(); ++it )
    {
        buffer = *it ;
        buffer=buffer.simplifyWhiteSpace();
        if (buffer.contains(appName.simplifyWhiteSpace(),true) > 0)
        {
            if (verbose_app == true )
                { TXTEdit_STDOUT->append(appName+" "+tr2i18n("already running")); }
            return true;
        }
    }
    return false;
}

void KFreeFlight_view::receivePID(KProcess *, char *b, int l)
{
    m_pid->append(QString::fromLatin1(b,l));
}

void KFreeFlight_view::atlasSlot()
{
typedef QValueList<QCString> Args;

    Args arguments;
    KProcess *Atlas;
    bool flag_run;
    QString buffer;

    m_config->setGroup("Settings Atlas");
    buffer=m_config->readEntry("Only one instance","false");
    if ((buffer == "true") && (searchPID("Atlas") == true))
    {
        return;
    }

    Atlas=new KProcess;

    buffer=m_config->readEntry("Atlas exe","Atlas");
    if ((buffer == "undefined") || (buffer == ""))
    {
        buffer=tr2i18n("<h3>Attention</h3><p>No \"Atlas\" executable file selected</p>");
        KMessageBox::sorry( this, buffer, "Help" );
        return;
    }

    *Atlas << buffer;
    *Atlas << "--airport="+LE_Airport->text().upper().stripWhiteSpace();
    m_config->setGroup("Settings FlightGear");

    buffer=m_config->readEntry("FG_ROOT", "undefined");
    if ((buffer != "undefined") && (buffer.stripWhiteSpace() != ""))
        {  *Atlas << "--fg-root="+buffer; }

    m_config->setGroup("Settings Atlas");
    buffer=m_config->readEntry("Images Directory Path", "undefined");
    if ((buffer != "undefined") && (buffer.stripWhiteSpace() != ""))
        {  *Atlas << "--path="+buffer;  }
    buffer=m_config->readEntry("Glut Fonts", "undefined");
    if ((buffer != "undefined") && (buffer.stripWhiteSpace() != ""))
        {  *Atlas << "--glutfonts";  }

    m_config->setGroup("Flightgear Network");
    buffer=m_config->readEntry("PortHttp", "undefined");
    if ((buffer != "undefined") && (buffer.stripWhiteSpace() != ""))
        {  *Atlas << "--udp="+buffer;  }

    arguments = Atlas->args();
    Args::iterator Iterator ;

    buffer="";
    for ( Iterator = arguments.begin() ; Iterator != arguments.end() ; ++Iterator )
    {
        buffer += (*Iterator)+" ";
    }
    if (verbose_app == true ) 
    {
        TXTEdit_STDOUT->append(buffer);
    }
    flag_run=(Atlas->start(KProcess:: NotifyOnExit, KProcess::AllOutput));
    if (!flag_run)
    {
        if (verbose_app == true ) 
            { TXTEdit_STDOUT->append(tr2i18n("*** Error *** : Can't launch Atlas!")); }
        KMessageBox::error( this, tr2i18n("Can't find \"Atlas\" program"));
    }
}

void KFreeFlight_view::wayPointSaveSlot()
{
    QStringList lines;
    QString fileName;
    QFile file;
    QTextStream stream;
    uint i;

    for (i=0 ; i< ListBox_WayPoint->count() ; i++)
    {
        ListBox_WayPoint->setCurrentItem(i);
        lines << ListBox_WayPoint->currentText().stripWhiteSpace().upper() ;
    }

    fileName = m_fileDlg->getSaveFileName (QDir::homeDirPath ()+AppDirectory,
        "text/plain", this,  tr2i18n("Choose a file" ));

    if (!fileName.isEmpty())
    {
        file.setName(fileName);
            if ( file.open( IO_WriteOnly ) ) 
            {
                stream.setDevice( &file );
                for ( QStringList::Iterator it = lines.begin(); it != lines.end(); ++it )
                { stream << *it << "\n"; }
                file.close();
            }
    }
}

void KFreeFlight_view::wayPointHelpSlot()
{
    QString buffer=tr2i18n("<h3>Very simple</h3>");
    buffer.append(tr2i18n("<p>Add an ID (you can get it by \"Atlas\" program) and its altitude,<br>and the GC autopilot will following the plan for you.\nTake a look at</p>"));
    buffer.append("<p>"+QDir::homeDirPath ()+AppDirectory+"promenade_marseille.txt</p>");
    buffer.append(tr2i18n("<p>for an example.</p>"));

    KMessageBox::information( this, buffer);
}

void KFreeFlight_view::wayPointDeleteSlot()
{
    ListBox_WayPoint->removeItem(ListBox_WayPoint->currentItem());
}

void KFreeFlight_view::wayPointFreezeAllSlot()
{
    ListBox_WayPoint->setEnabled(false);
    BTN_WayPoint_Help->setEnabled(false);
    BTN_WayPoint_Delete->setEnabled(false);
    BTN_WayPoint_Save->setEnabled(false);
    BTN_WayPoint_Add->setEnabled(false);
    LE_Waypoint_ID->setEnabled(false);
    TXTLabel_Waypoint_ID->setEnabled(false);
    TXTLabel_Waypoint_Altitude->setEnabled(false);
    SpinBox_WayPoint_Altitude->setEnabled(false);
    PixmapLabel_WayPoint->setEnabled(false);
    LE_FindFile->setEnabled(false);
    BTN_FindFile->setEnabled(false);
    ListBox_WayPoint->setEnabled(false);
}

void KFreeFlight_view::findFlightPlanFileSlot()
{
    QString buffer;

    buffer = m_fileDlg->getOpenFileName (QDir::homeDirPath ()+"/.kfreeflight",
        "text/plain", this,  tr2i18n("Choose a file" ));

    if (buffer != "") LE_FindFile->setText(buffer);
}

void KFreeFlight_view::runwaySlot()
{
    LE_Runway->setText(Table_Runway->text(Table_Runway->currentRow(), 0 ).stripWhiteSpace());
}

void KFreeFlight_view::verboseSlot()
{
    QString buffer;
    bool old_flag_verbose;

    old_flag_verbose=verbose_app;

    m_config->setGroup("Settings General");
    buffer=m_config->readEntry("Verbose", "undefined");
    if (buffer != "undefined")
    {
        if (buffer == "true")
        {
            verbose_app=true;
            if (old_flag_verbose != verbose_app)
                TXTEdit_STDOUT->append(tr2i18n("talkative mode active"));
        }
        if (buffer == "false")
        {
            verbose_app=false;
            if (old_flag_verbose != verbose_app)
                TXTEdit_STDOUT->append(tr2i18n("talkative mode inactive"));
        }
    }
}

void KFreeFlight_view::reloadSimgearList()
{
    QTextStream stream;
    QFile file;
    QString buffer;

    if (m_loadBySimgear) delete m_loadBySimgear;
    m_loadBySimgear= new QStringList() ;

    buffer=*m_destDirectory;
    buffer=buffer.append("aircraft.dat");

    file.setName(buffer);
    if ( file.open( IO_ReadOnly ) ) 
    {
        stream.setDevice( &file );
        while ( !stream.atEnd() ) 
        {
            *m_loadBySimgear << stream.readLine();
        }
        file.close();
    }
    else
    {
        if ( file.open( IO_WriteOnly ) ) 
        {
            stream.setDevice( &file );
            stream << "A380\n" << "MD11\n" << "\n";
            file.close();
        }
        *m_loadBySimgear << "A380" << "MD11" ;
    }
}


void KFreeFlight_view::changePixmapSlot()
{
    QString Aircraft, PathImage, buffer, buffer2, buf;
    QString fgroot;
    QFile file;
    QStringList loadBySimgear;

    QToolTip::add( ComboBox_Aircraft, m_aircraftDescription->section('\n',
        ComboBox_Aircraft->currentItem(), ComboBox_Aircraft->currentItem()));

    m_config->setGroup("Settings FlightGear");
    buffer=m_config->readEntry("FG_ROOT", "undefined");

    if ((buffer == "") || (buffer == "undefined"))  return;
    fgroot=buffer;

    Aircraft=ComboBox_Aircraft->currentText().stripWhiteSpace();
    if (verbose_app == true )
                { TXTEdit_STDOUT->append(tr2i18n("Change thumbnail aircraft with current aircraft")); }

    PathImage=fgroot.stripWhiteSpace()+"/Aircraft/";
    buffer = PathImage.replace("//","/");

    PathImage=PathImage.append(getAircraftDirectory(buffer.remove('\n'))+"/"+
        ComboBox_Aircraft->currentText().stripWhiteSpace()+"-set.xml");
    TXTEdit_STDOUT->append(PathImage);
    file.setName(PathImage);
    if (!file.open(IO_ReadOnly))
    {
        *m_aircraftModel="undefined";
        if (notFirstDisplay == true)
        {
            disableOpenGLWidget();
            enableOpenGLWidget();
            aircraftViewSlot(*m_aircraftModel);
            TXTEdit_STDOUT->append(tr2i18n("No model found for this aircraft :")+Aircraft);
        }
        return;
    }
    file.close();

    buffer2 = searchInXMLFile(PathImage, "sim/model/path");
    if ((buffer2.isNull()) || (buffer2.right(4) != ".xml"))
    {
        if (buffer2.isNull()) { *m_aircraftModel="undefined"; }
        if (buffer2.right(4) != ".xml")
        {
            *m_aircraftModel=fgroot+"/"+buffer2;
            *m_aircraftTexturePath=fgroot+"/"+buffer2.remove(buffer2.section('/',-1,-1));
        }
    }
    else
    {
        TXTEdit_STDOUT->append(tr2i18n("Aircraft xml file :")+buffer2);

        for ( QStringList::Iterator it = m_loadBySimgear->begin(); it != m_loadBySimgear->end(); ++it )
        {
            buf = *it ;
            buf = buf.simplifyWhiteSpace();
            if (Aircraft.left(4) == buf.left(4))
            {
                *m_aircraftModel = buffer2;
                if (notFirstDisplay == true)
                {
                    disableOpenGLWidget();
                    enableOpenGLWidget();
                    //if (Aircraft.left(4) == "MD11") aircraftViewXmlSlot(*m_aircraftModel, false);
                    /*else*/
                    aircraftViewXmlSlot(*m_aircraftModel, true);
                }
                return;
            }
        }

        buffer = searchInXMLFile( fgroot+"/"+buffer2, "path");
        PathImage = buffer2.replace("//","/");
        PathImage = PathImage.remove(PathImage.section('/',-1,-1));
        if (buffer.left(1) == "/")
        {
            *m_aircraftModel = fgroot+"/"+buffer;
            *m_aircraftModel = m_aircraftModel->replace("//","/");
        }
        else
        {
            *m_aircraftModel = fgroot+"/"+PathImage+"/"+buffer;
            *m_aircraftModel = m_aircraftModel->replace("//","/");
        }
        TXTEdit_STDOUT->append(tr2i18n("Aircraft")+" :"+*m_aircraftModel);

        buffer = searchInXMLFile( fgroot+"/"+buffer2, "texture-path");
        PathImage = buffer2;
        PathImage = PathImage.remove(PathImage.section('/',-1,-1));
        if (buffer.left(1) == "/")
        {
            *m_aircraftTexturePath = fgroot+"/"+buffer; 
            *m_aircraftTexturePath = m_aircraftTexturePath->replace("//","/") ;
        }
        else
        {
            *m_aircraftTexturePath = fgroot+"/"+PathImage+"/"+buffer; 
            *m_aircraftTexturePath = m_aircraftTexturePath->replace("//","/") ; 
        }
        TXTEdit_STDOUT->append(tr2i18n("Textures")+" :"+*m_aircraftTexturePath);
    }
    if (notFirstDisplay == true)
    {
        disableOpenGLWidget();
        enableOpenGLWidget();
        aircraftViewSlot(*m_aircraftModel, *m_aircraftTexturePath);
    }

}

void KFreeFlight_view::getAirportWebInfoSlot()
{
typedef QValueList<QCString> Args;

    Args arguments;
    QString buffer;
    //open the internet navigator at a select page

    KProcess *commandline;
    commandline=new KProcess;

    m_config->setGroup("Settings General");
    buffer=m_config->readEntry("WebBrowser", "undefined");

    if ((buffer == "") || (buffer == "undefined")) return;
    else *commandline << buffer.stripWhiteSpace();

    *commandline << "http://www.sia.aviation-civile.gouv.fr/html/frameset_aip_uk.htm";

    commandline->start(KProcess::DontCare, KProcess::NoCommunication);

    if (verbose_app == true )
    {
        arguments = commandline->args();
        Args::iterator Iterator ;

        buffer="";
        for ( Iterator = arguments.begin() ; Iterator != arguments.end() ; ++Iterator )
        {
            buffer += (*Iterator)+" ";
        }
        TXTEdit_STDOUT->append(buffer);
    }
}

void KFreeFlight_view::getAirportWeatherSlot()
{
    m_weatherWindow = new Weather_view(0, "weather", 0, 
        LE_Airport->text().upper().stripWhiteSpace(), *m_destDirectory);

    m_weatherWindow->m_font = m_appFont;
    m_weatherWindow->m_foreground = m_appForegroundColor;
    m_weatherWindow->m_background = m_appBackgroundColor;
    m_weatherWindow->m_edit = m_appEditColor;
    m_weatherWindow->m_config = m_config;
    m_weatherWindow->applySettings();
    m_weatherWindow->show();
}

void KFreeFlight_view::startPositionSlot()
{
    if(RB_Ground->isChecked() || RB_Carrier->isChecked())
    {
        TXTLabel_Altitude->setEnabled(false);
        TXTLabel_Speed->setEnabled(false);
        SpinBox_Altitude->setEnabled(false);
        SpinBox_Speed->setEnabled(false);
        TXTLabel_GPS_long->setEnabled(false);
        TXTLabel_GPS_lat->setEnabled(false);
        kDoubleSpinBox_GPS_long->setEnabled(false);
        kDoubleSpinBox_GPS_lat->setEnabled(false);
        SpinBox_Heading->setEnabled(false);
        TXTLabel_Heading->setEnabled(false);
    }
    if(RB_InAIr->isChecked())
    {
        TXTLabel_Altitude->setEnabled(true);
        TXTLabel_Speed->setEnabled(true);
        SpinBox_Altitude->setEnabled(true);
        SpinBox_Speed->setEnabled(true);
        TXTLabel_GPS_long->setEnabled(false);
        TXTLabel_GPS_lat->setEnabled(false);
        kDoubleSpinBox_GPS_long->setEnabled(false);
        kDoubleSpinBox_GPS_lat->setEnabled(false);
        SpinBox_Heading->setEnabled(false);
        TXTLabel_Heading->setEnabled(false);
    }
    if(RB_GPS->isChecked())
    {
        TXTLabel_Altitude->setEnabled(false);
        TXTLabel_Speed->setEnabled(false);
        SpinBox_Altitude->setEnabled(false);
        SpinBox_Speed->setEnabled(false);
        TXTLabel_GPS_long->setEnabled(true);
        TXTLabel_GPS_lat->setEnabled(true);
        kDoubleSpinBox_GPS_long->setEnabled(true);
        kDoubleSpinBox_GPS_lat->setEnabled(true);
        SpinBox_Heading->setEnabled(true);
        TXTLabel_Heading->setEnabled(true);
    }
}

void KFreeFlight_view::defreezeTimeOfDaySlot()
{
    ComboBox_Time->setEnabled(true);
    TXTLabel_Date->setEnabled(false);
    TXTLabel_Time->setEnabled(false);
    DateEdit_Date->setEnabled(false);
    TimeEdit_Time->setEnabled(false);
}

void KFreeFlight_view::changeAirportInformations()
{
    QString fichier,buffer,DestDirectory,HomeDirectory;
    QFile file;
    QTextStream stream;
    int i=0;

    HomeDirectory=QDir::homeDirPath ();
    DestDirectory=HomeDirectory+AppDirectory;

    if (LE_Airport->text().isEmpty()) return;

    fichier = LE_Airport->text().stripWhiteSpace().upper();
    fichier.prepend(DestDirectory);
    fichier.append(".dat");
    if (verbose_app == true ) TXTEdit_STDOUT->append("Open file :"+fichier);

    file.setName(fichier);
    if ( file.open( IO_ReadOnly ) ) 
    {
        stream.setDevice( &file );
        Table_Runway->setNumRows(0);
        /*Table_Runway->insertColumns(0, 1);
        Table_Runway->horizontalHeader()->setLabel( 0, tr2i18n( "Runway" ) );*/
        while ( !stream.atEnd() )
        {
            buffer = stream.readLine();
            Table_Runway->insertRows(i, 1);
            Table_Runway->setText(i, 0, buffer);
            i++;
        }
        file.close();
    }
    else
    {
        /*Table_Runway->removeColumn(0);
        Table_Runway->insertColumns(0, 1);
        Table_Runway->horizontalHeader()->setLabel( 0, tr2i18n( "Runway" ) );*/
        Table_Runway->setNumRows(0);
        Table_Runway->insertRows(0, 3);
        Table_Runway->setText(0, 0, tr2i18n("No"));
        Table_Runway->setText(1, 0, tr2i18n("runway"));
        Table_Runway->setText(2, 0, tr2i18n("available"));
        TXTEdit_STDOUT->setText(tr2i18n("*** Error *** : to open file ")+fichier);
    }
}

void KFreeFlight_view::defreezeTimeEditSlot()
{
    TXTLabel_Date->setEnabled(true);
    TXTLabel_Time->setEnabled(true);
    DateEdit_Date->setEnabled(true);
    TimeEdit_Time->setEnabled(true);
    ComboBox_Time->setEnabled(false);
}

void KFreeFlight_view::defreezeMultiplayerInternetSlot()
{
    QString buffer;
    int Intbuffer;

    m_config->setGroup("Flightgear Network");
    buffer=m_config->readEntry("IPAdressRange", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         Intbuffer=buffer.section('.',3,3).toInt();
         spinBoxAddressRange4->setValue(Intbuffer);
    }

    TXTLabel_Nbr_Player->setEnabled(false);
    TXTLabel_Hz->setEnabled(true);
    TXTLabel_callsign->setEnabled(true);
    TXTLabel_ServerPort->setEnabled(true);
    SpinBox_Player->setEnabled(false);
    SpinBox_Hz->setEnabled(true);
    LE_callsign->setEnabled(true);
    SpinBox_ServerPort->setEnabled(true);
    spinBoxAddressRange1->setEnabled(true);
    spinBoxAddressRange2->setEnabled(true);
    spinBoxAddressRange3->setEnabled(true);
    spinBoxAddressRange4->setEnabled(true);
    spinBoxAddressRange1out->setEnabled(true);
    spinBoxAddressRange2out->setEnabled(true);
    spinBoxAddressRange3out->setEnabled(true);
    spinBoxAddressRange4out->setEnabled(true);
    GroupBox_IpRange->setEnabled(true);
    GroupBox_IpRangeout->setEnabled(true);
    TXTLabel_network_internetIn->setEnabled(true);
    TXTLabel_network_internetOut->setEnabled(true);
    TXTLabel_network_local->setEnabled(false);
    LE_Server->setEnabled(true);
    ComboBox_Server->setEnabled(true);
    setServerSlot();
}

void KFreeFlight_view::defreezeMultiplayerLocalSlot()
{
    TXTLabel_Nbr_Player->setEnabled(true);
    TXTLabel_Hz->setEnabled(true);
    TXTLabel_callsign->setEnabled(false);
    TXTLabel_ServerPort->setEnabled(true);
    SpinBox_Player->setEnabled(true);
    SpinBox_Hz->setEnabled(true);
    LE_callsign->setEnabled(false);
    SpinBox_ServerPort->setEnabled(true);
    spinBoxAddressRange1->setEnabled(true);
    spinBoxAddressRange2->setEnabled(true);
    spinBoxAddressRange3->setEnabled(true);
    spinBoxAddressRange4->setValue(255);
    LE_Point3->setEnabled(false);
    spinBoxAddressRange4->setEnabled(false);
    spinBoxAddressRange1out->setEnabled(false);
    spinBoxAddressRange2out->setEnabled(false);
    spinBoxAddressRange3out->setEnabled(false);
    spinBoxAddressRange4out->setEnabled(false);
    GroupBox_IpRange->setEnabled(true);
    GroupBox_IpRangeout->setEnabled(false);
    TXTLabel_network_internetIn->setEnabled(false);
    TXTLabel_network_internetOut->setEnabled(false);
    TXTLabel_network_local->setEnabled(true);
    LE_Server->setEnabled(false);
    ComboBox_Server->setEnabled(false);
}

void KFreeFlight_view::freezeMultiplayerSlot()
{
    TXTLabel_Nbr_Player->setEnabled(false);
    TXTLabel_Hz->setEnabled(false);
    TXTLabel_callsign->setEnabled(false);
    TXTLabel_ServerPort->setEnabled(false);
    SpinBox_Player->setEnabled(false);
    SpinBox_Hz->setEnabled(false);
    LE_callsign->setEnabled(false);
    SpinBox_ServerPort->setEnabled(false);
    spinBoxAddressRange1->setEnabled(false);
    spinBoxAddressRange2->setEnabled(false);
    spinBoxAddressRange3->setEnabled(false);
    spinBoxAddressRange4->setEnabled(false);
    spinBoxAddressRange1out->setEnabled(false);
    spinBoxAddressRange2out->setEnabled(false);
    spinBoxAddressRange3out->setEnabled(false);
    spinBoxAddressRange4out->setEnabled(false);
    GroupBox_IpRange->setEnabled(false);
    GroupBox_IpRangeout->setEnabled(false);
    TXTLabel_network_internetIn->setEnabled(false);
    TXTLabel_network_internetOut->setEnabled(false);
    TXTLabel_network_local->setEnabled(false);
    LE_Server->setEnabled(false);
    ComboBox_Server->setEnabled(false);
}

void KFreeFlight_view::wayPointAddSlot()
{
    QString buffer;
    if ((buffer=LE_Waypoint_ID->text().stripWhiteSpace().upper()).isEmpty()) return;
    buffer.append("@"+SpinBox_WayPoint_Altitude->text().stripWhiteSpace());
    ListBox_WayPoint->insertItem(buffer);
}

void KFreeFlight_view::quitSlot()
{
    saveSlot();
    emit(queryClose());
}

void KFreeFlight_view::freezeTimeSlot()
{
    TXTLabel_Date->setEnabled(false);
    TXTLabel_Time->setEnabled(false);
    DateEdit_Date->setEnabled(false);
    TimeEdit_Time->setEnabled(false);
    ComboBox_Time->setEnabled(false);
}

void KFreeFlight_view::freezeCarrierStartEditSlot()
{
    LE_CarrierStart->setEnabled(false);
}

void KFreeFlight_view::defreezeCarrierStartEditSlot()
{
    LE_CarrierStart->setEnabled(true);
}

void KFreeFlight_view::reloadSlot()
{
    QDate TheDate;
    QTime TheTime;
    int Intbuffer1, Intbuffer2, Intbuffer3, Intbuffer4;
    QString buffer, buf1, buf2, buf3, buf4, error;
    QStringList list;
    bool errorReading=false;

    if (!m_config->hasGroup("Flightgear General"))
    {
        //init objects:button radio

        RB_Real_Time->setChecked(true);
        RB_Ground->setChecked(true);
        startPositionSlot();
        freezeTimeSlot();
        RB_Fog_0->setChecked(true);RB_Fog_1->setChecked(false);RB_Fog_2->setChecked(false);
        RB_nav1->setChecked(true);RB_nav2->setChecked(false);
        RB_Shading_flat->setChecked(true);RB_Shading_smooth->setChecked(false);
        RB_WayPoint_none->setChecked(true);
        wayPointFreezeAllSlot();
        RB_WayPoint_none->setChecked(true);
        wayPointFreezeAllSlot();
        return;
    }
error="";
m_config->setGroup("Flightgear General");

    buffer=m_config->readEntry("AtlasWithFlightgear", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_AtlasToo->setChecked(true);
         if (buffer == "0") CB_AtlasToo->setChecked(false);
    }
    else { errorReading =true; error.append("AtlasWithFlightgear "); }
    buffer=m_config->readEntry("FullScreen", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_Fullscreen->setChecked(true);
         if (buffer == "0") CB_Fullscreen->setChecked(false);
    }
    else { errorReading =true; error.append("FullScreen "); }
    buffer=m_config->readEntry("GameMode", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_GameMode->setChecked(true);
         if (buffer == "0") CB_GameMode->setChecked(false);
    }
    else { errorReading =true; error.append("GameMode "); }
    buffer=m_config->readEntry("IntroMusic", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_IntroMusic->setChecked(true);
         if (buffer == "0") CB_IntroMusic->setChecked(false);

    }
    else { errorReading =true; error.append("IntroMusic "); }
    buffer=m_config->readEntry("Joystick", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_Joystick->setChecked(true);
         if (buffer == "0") CB_Joystick->setChecked(false);
    }
    else { errorReading =true; error.append("Joystick "); }
    buffer=m_config->readEntry("RealWeather", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_RealWeather->setChecked(true);
         if (buffer == "0") CB_RealWeather->setChecked(false);
    }
    else { errorReading =true; error.append("RealWeather "); }
    buffer=m_config->readEntry("SplashScreen", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_Splashscreen->setChecked(true);
         if (buffer == "0") CB_Splashscreen->setChecked(false);
    }
    else { errorReading =true; error.append("SplashScreen "); }
    buffer=m_config->readEntry("UnitMeter", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_UnitMeter->setChecked(true);
         if (buffer == "0") CB_UnitMeter->setChecked(false);
    }
    else { errorReading =true; error.append("UnitMeter "); }
    buffer=m_config->readEntry("httpd", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_ServerHttp->setChecked(true);
         if (buffer == "0") CB_ServerHttp->setChecked(false);
    }
    else { errorReading =true; error.append("httpd "); }
    buffer=m_config->readEntry("nmea", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_NMEA->setChecked(true);
         if (buffer == "0") CB_NMEA->setChecked(false);
    }
    else { errorReading =true; error.append("nmea "); }
    buffer=m_config->readEntry("Wireframe", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_Wireframe->setChecked(true);
         if (buffer == "0") CB_Wireframe->setChecked(false);
    }
    else { errorReading =true; error.append("Wireframe "); }
    buffer=m_config->readEntry("WireframeObjects", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_WireframeObjects->setChecked(true);
         if (buffer == "0") CB_WireframeObjects->setChecked(false);
    }
    else { errorReading =true; error.append("WireframeObjects "); }

m_config->setGroup("Flightgear Render");
    buffer=m_config->readEntry("Clouds", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_Clouds->setChecked(true);
         if (buffer == "0") CB_Clouds->setChecked(false);
    }
    else { errorReading =true; error.append("Clouds "); }
    buffer=m_config->readEntry("Clouds3d", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_Clouds3d->setChecked(true);
         if (buffer == "0") CB_Clouds3d->setChecked(false);
    }
    else { errorReading =true; error.append("Clouds3d "); }
    buffer=m_config->readEntry("CloudsBump", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_CloudsBump->setChecked(true);
         if (buffer == "0") CB_CloudsBump->setChecked(false);
    }
    else { errorReading =true; error.append("CloudsBump "); }
    buffer=m_config->readEntry("DistanceAttenuation", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_DistanceAttenuation->setChecked(true);
         if (buffer == "0") CB_DistanceAttenuation->setChecked(false);
    }
    else { errorReading =true; error.append("DistanceAttenuation "); }
    buffer=m_config->readEntry("EnhancedLighting", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_EnhancedLighting->setChecked(true);
         if (buffer == "0") CB_EnhancedLighting->setChecked(false);
    }
    else { errorReading =true; error.append("EnhancedLighting "); }
    buffer=m_config->readEntry("HorizonEffect", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_HorizonEffect->setChecked(true);
         if (buffer == "0") CB_HorizonEffect->setChecked(false);
    }
    else { errorReading =true; error.append("HorizonEffect "); }
    buffer=m_config->readEntry("Mousepointer", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_MousePointer->setChecked(true);
         if (buffer == "0") CB_MousePointer->setChecked(false);
    }
    else { errorReading =true; error.append("Mousepointer "); }
    buffer=m_config->readEntry("RandomObjects", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_RandomObjects->setChecked(true);
         if (buffer == "0") CB_RandomObjects->setChecked(false);
    }
    else { errorReading =true; error.append("RandomObjects "); }
    buffer=m_config->readEntry("Resolution", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         ComboBox_Resolution->setCurrentItem(buffer.toInt());
    }
    else { errorReading =true; error.append("Resolution "); }
    buffer=m_config->readEntry("Resolution bpp", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         ComboBox_Resolution_bpp->setCurrentItem(buffer.toInt());
    }
    else { errorReading =true; error.append("Resolutionbpp "); }
    buffer=m_config->readEntry("ShadingFlat", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") RB_Shading_flat->setChecked(true);
         if (buffer == "0") RB_Shading_flat->setChecked(false);
    }
    else { errorReading =true; error.append("ShadingFlat "); }
    buffer=m_config->readEntry("ShadingSmooth", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") RB_Shading_smooth->setChecked(true);
         if (buffer == "0") RB_Shading_smooth->setChecked(false);
    }
    else { errorReading =true; error.append("ShadingSmooth "); }
    buffer=m_config->readEntry("SkyBlend", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_SkyBlend->setChecked(true);
         if (buffer == "0") CB_SkyBlend->setChecked(false);
    }
    else { errorReading =true; error.append("SkyBlend "); }
    buffer=m_config->readEntry("SpecularHighlight", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_SpecularHighlight->setChecked(true);
         if (buffer == "0") CB_SpecularHighlight->setChecked(false);
    }
    else { errorReading =true; error.append("SpecularHighlight "); }
    buffer=m_config->readEntry("Textures", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_Textures->setChecked(true);
         if (buffer == "0") CB_Textures->setChecked(false);
    }
    else { errorReading =true; error.append("Textures "); }
    buffer=m_config->readEntry("ShadowsAircraft", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_Shadows_Aircraft->setChecked(true);
         if (buffer == "0") CB_Shadows_Aircraft->setChecked(false);
    }
    else { errorReading =true; error.append("ShadowsAircraft "); }
    buffer=m_config->readEntry("ShadowsAircraftTransp", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_Shadows_AircraftTransp->setChecked(true);
         if (buffer == "0") CB_Shadows_AircraftTransp->setChecked(false);
    }
    else { errorReading =true; error.append("ShadowsAircraftTransp "); }
    buffer=m_config->readEntry("ShadowsSceneryObjects", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_Shadows_SceneryObjects->setChecked(true);
         if (buffer == "0") CB_Shadows_SceneryObjects->setChecked(false);
    }
    else { errorReading =true; error.append("ShadowsSceneryObjects "); }
    buffer=m_config->readEntry("ShadowsAiObjects", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_Shadows_AiObjects->setChecked(true);
         if (buffer == "0") CB_Shadows_AiObjects->setChecked(false);
    }
    else { errorReading =true; error.append("ShadowsAiObjects "); }
    buffer=m_config->readEntry("Lightning", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_Lightning->setChecked(true);
         if (buffer == "0") CB_Lightning->setChecked(false);
    }
    else { errorReading =true; error.append("Lightning "); }
    buffer=m_config->readEntry("Precipitation", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_Precipitation->setChecked(true);
         if (buffer == "0") CB_Precipitation->setChecked(false);
    }
    else { errorReading =true; error.append("Precipitation "); }

m_config->setGroup("Flightgear Airport");

    buffer=m_config->readEntry("Airport", "undefined");
    if (buffer != "undefined")
    {
         LE_Airport->setText(buffer.stripWhiteSpace());
         changeAirportInformations();
    }
    else { errorReading =true; error.append("Airport "); }

    buffer=m_config->readEntry("Runway", "undefined");
    if (buffer != "undefined")
    {
         LE_Runway->setText(buffer.stripWhiteSpace());
    }
    else { errorReading =true; error.append("Runway "); }
    buffer=m_config->readEntry("City", "undefined");
    if (buffer != "undefined")
    {
         LE_AddAirport_City->setText(buffer.stripWhiteSpace());
    }
    else { errorReading =true; error.append("City "); }
    buffer=m_config->readEntry("AirportNb", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         Table_Airport->selectRow(buffer.toInt());
    }
    else { errorReading =true; error.append("AirportNb "); }
    buffer=m_config->readEntry("RunwayNb", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         Table_Runway->selectRow(buffer.toInt());
    }
    else { errorReading =true; error.append("RunwayNb "); }

m_config->setGroup("Flightgear Carrier");

    buffer=m_config->readEntry("Carrier name", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         LE_CarrierName->setText(buffer.stripWhiteSpace());
    }
    else { errorReading =true; error.append("CarrierName "); }
    buffer=m_config->readEntry("Carrier prop", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         LE_CarrierProp->setText(buffer.stripWhiteSpace());
    }
    else { errorReading =true; error.append("CarrierProp "); }
    buffer=m_config->readEntry("Cat1", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") { RB_CarrierPosC1->setChecked(true); freezeCarrierStartEditSlot();}
         if (buffer == "0") RB_CarrierPosC1->setChecked(false);
    }
    else { errorReading =true; error.append("Cat1 "); }
    buffer=m_config->readEntry("Cat2", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") { RB_CarrierPosC2->setChecked(true); freezeCarrierStartEditSlot(); }
         if (buffer == "0") RB_CarrierPosC2->setChecked(false);
    }
    else { errorReading =true; error.append("Cat2 "); }
    buffer=m_config->readEntry("Cat3", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") { RB_CarrierPosC3->setChecked(true); freezeCarrierStartEditSlot();}
         if (buffer == "0") RB_CarrierPosC3->setChecked(false);
    }
    else { errorReading =true; error.append("Cat3 "); }
    buffer=m_config->readEntry("Cat4", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") { RB_CarrierPosC4->setChecked(true); freezeCarrierStartEditSlot(); }
         if (buffer == "0") RB_CarrierPosC4->setChecked(false);
    }
    else { errorReading =true; error.append("Cat4 "); }
    buffer=m_config->readEntry("Park1", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") { RB_CarrierPosP1->setChecked(true); freezeCarrierStartEditSlot(); }
         if (buffer == "0") RB_CarrierPosP1->setChecked(false);
    }
    else { errorReading =true; error.append("Park1 "); }
    buffer=m_config->readEntry("Other Place", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") { RB_CarrierPosOther->setChecked(true); defreezeCarrierStartEditSlot(); }
         if (buffer == "0") RB_CarrierPosOther->setChecked(false);
    }
    else { errorReading =true; error.append("OtherPlace "); }
    buffer=m_config->readEntry("Other place name", "undefined");
    if (buffer != "undefined")
    {
         LE_CarrierStart->setText(buffer.stripWhiteSpace());
    }
    else { errorReading =true; error.append("OtherPlaceName "); }
    buffer=m_config->readEntry("Always carrier", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_CarrierProperty->setChecked(true);
         if (buffer == "0") CB_CarrierProperty->setChecked(false);
    }
    else { errorReading =true; error.append("Alwayscarrier "); }

m_config->setGroup("Flightgear Aircraft");

    buffer=m_config->readEntry("AiTraffic", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_AiTraffic->setChecked(true);
         if (buffer == "0") CB_AiTraffic->setChecked(false);
    }
    else { errorReading =true; error.append("AiTraffic "); }
    buffer=m_config->readEntry("Aircraft", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
        ComboBox_Aircraft->setCurrentItem(buffer.toInt());
    }
    else {errorReading =true; error.append("Aircraft "); }

    buffer=m_config->readEntry("AutoCoordon", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_AutoCoordon->setChecked(true);
         if (buffer == "0") CB_AutoCoordon->setChecked(false);
    }
    else { errorReading =true; error.append("AutoCoordon "); }
    buffer=m_config->readEntry("FailurePitot", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_Failure_Pitot->setChecked(true);
         if (buffer == "0") CB_Failure_Pitot->setChecked(false);
    }
    else { errorReading =true; error.append("FailurePitot "); }
    buffer=m_config->readEntry("FailureStatic", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_Failure_Static->setChecked(true);
         if (buffer == "0") CB_Failure_Static->setChecked(false);
    }
    else { errorReading =true; error.append("FailureStatic "); }
    buffer=m_config->readEntry("FailureSystem", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_Failure_System->setChecked(true);
         if (buffer == "0") CB_Failure_System->setChecked(false);
    }
    else { errorReading =true; error.append("FailureSystem "); }
    buffer=m_config->readEntry("FailureVacuum", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_Failure_Vacuum->setChecked(true);
         if (buffer == "0") CB_Failure_Vacuum->setChecked(false);
    }
    else { errorReading =true; error.append("FailureVacuum "); }
    buffer=m_config->readEntry("Freeze", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_Freeze->setChecked(true);
         if (buffer == "0") CB_Freeze->setChecked(false);
    }
    else { errorReading =true; error.append("Freeze "); }
    buffer=m_config->readEntry("FuelFreeze", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_FuelFreeze->setChecked(true);
         if (buffer == "0") CB_FuelFreeze->setChecked(false);
    }
    else { errorReading =true; error.append("FuelFreeze "); }
    buffer=m_config->readEntry("OnGround", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") { RB_Ground->setChecked(true); startPositionSlot(); }
         if (buffer == "0") RB_Ground->setChecked(false);
    }
    else { errorReading =true; error.append("OnGround "); }
    buffer=m_config->readEntry("InAir", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") { RB_InAIr->setChecked(true); startPositionSlot(); }
         if (buffer == "0") RB_InAIr->setChecked(false);
    }
    else { errorReading =true; error.append("InAir "); }
    buffer=m_config->readEntry("OnCarrier", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") { RB_Carrier->setChecked(true); startPositionSlot(); }
         if (buffer == "0") RB_Carrier->setChecked(false);
    }
    else { errorReading =true; error.append("OnCarrier "); }
    buffer=m_config->readEntry("OnGPSpos", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") { RB_GPS->setChecked(true); startPositionSlot(); }
         if (buffer == "0") RB_GPS->setChecked(false);
    }
    else { errorReading =true; error.append("OnGPSpos "); }
    buffer=m_config->readEntry("Altitude", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         SpinBox_Altitude->setValue(buffer.toInt());
    }
    else { errorReading =true; error.append("Altitude "); }
    buffer=m_config->readEntry("Speed", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         SpinBox_Speed->setValue(buffer.toInt());
    }
    else { errorReading =true; error.append("Speed "); }
    buffer=m_config->readEntry("GPSlat", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         kDoubleSpinBox_GPS_lat->setValue(buffer.toDouble());
    }
    else { errorReading =true; error.append("GPSlat "); }
    buffer=m_config->readEntry("GPSlong", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         kDoubleSpinBox_GPS_long->setValue(buffer.toDouble());
    }
    else { errorReading =true; error.append("GPSlong "); }
    buffer=m_config->readEntry("GPSHeading", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         SpinBox_Heading->setValue(buffer.toInt());
    }
    else { errorReading =true; error.append("GPSHeading "); }

m_config->setGroup("Flightgear Time");

    buffer=m_config->readEntry("FixedTime", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") { RB_Fixed_Time->setChecked(true); defreezeTimeEditSlot(); }
         if (buffer == "0") RB_Fixed_Time->setChecked(false);

    }
    else { errorReading =true; error.append("FixedTime "); }
    buffer=m_config->readEntry("RealTime", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") { RB_Real_Time->setChecked(true); freezeTimeSlot(); }
         if (buffer == "0") RB_Real_Time->setChecked(false);
    }
    else { errorReading =true; error.append("RealTime "); }
    buffer=m_config->readEntry("TimeOfDay", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") { RB_TimeOfDay->setChecked(true); defreezeTimeOfDaySlot(); }
         if (buffer == "0") RB_TimeOfDay->setChecked(false);
    }
    else { errorReading =true; error.append("TimeOfDay "); }
    buffer=m_config->readEntry("FreezeTime", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_FreezeTime->setChecked(true);
         if (buffer == "0") CB_FreezeTime->setChecked(false);
    }
    else { errorReading =true; error.append("FreezeTime "); }
    buffer=m_config->readEntry("Combobox_TimeOfDay", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
        ComboBox_Time->setCurrentItem(buffer.toInt());
    }
    else { errorReading =true; error.append("Combobox_TimeOfDay "); }
    buffer=m_config->readEntry("Combobox_Season", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
        ComboBox_Season->setCurrentItem(buffer.toInt());
    }
    else { errorReading =true; error.append("Combobox_Season "); }
        buffer=m_config->readEntry("Date", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
        buf1=buffer; buf2=buffer; buf3=buffer;
        Intbuffer1=buf1.section('-',0,0).toInt();
        Intbuffer2=buf2.section('-',1,1).toInt();
        Intbuffer3=buf3.section('-',2,2).toInt();
        TheDate.setYMD(Intbuffer1,Intbuffer2,Intbuffer3);
        DateEdit_Date->setDate(TheDate);
    }
    else { errorReading =true; error.append("Date "); }
        buffer=m_config->readEntry("Time", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
        buf1=buffer; buf2=buffer;
        Intbuffer1=buf1.section(':',0,0).toInt();
        Intbuffer2=buf2.section(':',1,1).toInt();
        TheTime.setHMS(Intbuffer1,Intbuffer2,0,0);
        TimeEdit_Time->setTime(TheTime);
    }
    else { errorReading =true; error.append("Time "); }

m_config->setGroup("Flightgear Weather");

    buffer=m_config->readEntry("Fog0", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") RB_Fog_0->setChecked(true);
         if (buffer == "0") RB_Fog_0->setChecked(false);
    }
    else { errorReading =true; error.append("Fog0 "); }
    buffer=m_config->readEntry("Fog1", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") RB_Fog_1->setChecked(true);
         if (buffer == "0") RB_Fog_1->setChecked(false);
    }
    else { errorReading =true; error.append("Fog1 "); }
    buffer=m_config->readEntry("Fog2", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") RB_Fog_2->setChecked(true);
         if (buffer == "0") RB_Fog_2->setChecked(false);
    }
    else { errorReading =true; error.append("Fog2 "); }
    buffer=m_config->readEntry("RandomWind", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_RandomWind->setChecked(true);
         if (buffer == "0") CB_RandomWind->setChecked(false);
    }
    else { errorReading =true; error.append("RandomWind "); }
    buffer=m_config->readEntry("DirectionWind", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         SpinBox_DirectionWind->setValue(buffer.toInt());
    }
    else { errorReading =true; error.append("DirectionWind "); }
    buffer=m_config->readEntry("SpeedWind", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         SpinBox_SpeedWind->setValue(buffer.toInt());
    }
    else { errorReading =true; error.append("SpeedWind "); }
    buffer=m_config->readEntry("Turbulence", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         Slider_Turbulence->setValue(buffer.toInt());
    }
    else { errorReading =true; error.append("Turbulence "); }
    buffer=m_config->readEntry("Visibility", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         SpinBox_Visibility->setValue(buffer.toInt());
    }
    else { errorReading =true; error.append("Visibility "); }

m_config->setGroup("Flightgear FlightPlan");

    buffer=m_config->readEntry("FlightPlan", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         LE_FindFile->setText(buffer.stripWhiteSpace());
    }
    else { errorReading =true; error.append("FlightPlan "); }
    buffer=m_config->readEntry("FlightPlanNone", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") RB_WayPoint_none->setChecked(true);wayPointFreezeAllSlot();
         if (buffer == "0") RB_WayPoint_none->setChecked(false);
    }
    else { errorReading =true; error.append("FlightPlanNone "); }
    buffer=m_config->readEntry("FlightPlanEdited", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") RB_WayPoint_edit->setChecked(true);wayPointDefreezeEditSlot();
         if (buffer == "0") RB_WayPoint_edit->setChecked(false);
    }
    else { errorReading =true; error.append("FlightPlanEdited "); }
    buffer=m_config->readEntry("FlightPlanFile", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") RB_WayPoint_load->setChecked(true);wayPointDefreezeFileSlot();
         if (buffer == "0") RB_WayPoint_load->setChecked(false);
    }
    else { errorReading =true; error.append("FlightPlanFile "); }
    buffer=m_config->readEntry("MyFlightPlan", "undefined");
    if ((buffer != "undefined"))
    {
         list=list.split(QString( "," ),buffer,false);
         ListBox_WayPoint->insertStringList ( list, 0 );
    }
    else { errorReading =true; error.append("MyFlightPlan "); }

m_config->setGroup("Flightgear Radio");

    buffer=m_config->readEntry("DmeNav1", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") RB_nav1->setChecked(true);
         if (buffer == "0") RB_nav1->setChecked(false);
    }
    else { errorReading =true; error.append("DmeNav1 "); }
    buffer=m_config->readEntry("DmeNav2", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") RB_nav2->setChecked(true);
         if (buffer == "0") RB_nav2->setChecked(false);
    }
    else { errorReading =true; error.append("DmeNav2 "); }
    buffer=m_config->readEntry("OtherDme", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") { RB_dme->setChecked(true); dmeDefreezeSlot(); }
         if (buffer == "0") { RB_dme->setChecked(false); dmeFreezeSlot(); }
    }
    else { errorReading =true; error.append("OtherDme "); }
    buffer=m_config->readEntry("Nav1", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         kDoubleSpinBox_NAV1->setValue(buffer.toDouble());
    }
    else { errorReading =true; error.append("Nav1 "); }
    buffer=m_config->readEntry("Nav1standby", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         kDoubleSpinBox_NAV1standby->setValue(buffer.toDouble());
    }
    else { errorReading =true; error.append("Nav1standby "); }
    buffer=m_config->readEntry("Nav2", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         kDoubleSpinBox_NAV2->setValue(buffer.toDouble());
    }
    else { errorReading =true; error.append("Nav2 "); }
    buffer=m_config->readEntry("Nav2standby", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         kDoubleSpinBox_NAV2standby->setValue(buffer.toDouble());
    }
    else { errorReading =true; error.append("Nav2standby "); }
    buffer=m_config->readEntry("Adf", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         SpinBox_adf->setValue(buffer.toInt());
    }
    else { errorReading =true; error.append("Adf "); }
    buffer=m_config->readEntry("Adfstandby", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         SpinBox_adfstandby->setValue(buffer.toInt());
    }
    else { errorReading =true; error.append("Adfstandby "); }
    buffer=m_config->readEntry("Nav1Radial", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         SpinBox_nav1_rad->setValue(buffer.toInt());
    }
    else { errorReading =true; error.append("Nav1Radial "); }
    buffer=m_config->readEntry("Nav2Radial", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         SpinBox_nav2_rad->setValue(buffer.toInt());
    }
    else { errorReading =true; error.append("Nav2Radial "); }
    buffer=m_config->readEntry("AdfRotation", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         SpinBox_adf_rot->setValue(buffer.toInt());
    }
    else { errorReading =true; error.append("AdfRotation "); }
    buffer=m_config->readEntry("Dme", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         kDoubleSpinBox_DME->setValue(buffer.toDouble());
    }
    else { errorReading =true; error.append("Dme "); }
    buffer=m_config->readEntry("Tacan", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         SpinBox_TACAN1->setValue(buffer.toInt());
         buf1=buffer; buf2=buffer; buf3=buffer;
         Intbuffer1=buf1.section('.',0,0).toInt();
         Intbuffer2=buf2.section('.',1,1).toInt();
         Intbuffer3=buf3.section('.',2,2).toInt();
         ComboBox_tacan->setCurrentText(buffer.section('.',3,3));
         SpinBox_TACAN1->setValue(Intbuffer1);
         SpinBox_TACAN2->setValue(Intbuffer2);
         SpinBox_TACAN3->setValue(Intbuffer3);
    }
    else { errorReading =true; error.append("Tacan "); }

m_config->setGroup("Flightgear Comm");

    buffer=m_config->readEntry("Comm1", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         kDoubleSpinBox_COMM1->setValue(buffer.toDouble());
    }
    else { errorReading =true; error.append("Comm1 "); }
    buffer=m_config->readEntry("Comm1standby", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         kDoubleSpinBox_COMM1standby->setValue(buffer.toDouble());
    }
    else { errorReading =true; error.append("Comm1standby "); }
    buffer=m_config->readEntry("Comm2", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         kDoubleSpinBox_COMM2->setValue(buffer.toDouble());
    }
    else { errorReading =true; error.append("Comm2 "); }
    buffer=m_config->readEntry("Comm2standby", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         kDoubleSpinBox_COMM2standby->setValue(buffer.toDouble());
    }
    else { errorReading =true; error.append("Comm2standby "); }
    buffer=m_config->readEntry("AtcVoices", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") CB_Comm_AtcVoices->setChecked(true);
         if (buffer == "0") CB_Comm_AtcVoices->setChecked(false);
    }
    else { errorReading =true; error.append("AtcVoices "); }

m_config->setGroup("Flightgear Network");

    buffer=m_config->readEntry("MultiPlayerNone", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") { RB_multiplayer_none->setChecked(true); freezeMultiplayerSlot();}
         if (buffer == "0") RB_multiplayer_none->setChecked(false);
    }
    else { errorReading =true; error.append("MultiPlayerNone "); }
    buffer=m_config->readEntry("MultiPlayerLocal", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") { RB_multiplayer_local->setChecked(true); defreezeMultiplayerLocalSlot();}
         if (buffer == "0") RB_multiplayer_local->setChecked(false);
    }
    else { errorReading =true; error.append("MultiPlayerLocal "); }
    buffer=m_config->readEntry("MultiPlayerInternet", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         if (buffer == "1") { RB_multiplayer_internet->setChecked(true); defreezeMultiplayerInternetSlot();}
         if (buffer == "0") RB_multiplayer_internet->setChecked(false);
    }
    else { errorReading =true; error.append("MultiPlayerInternet "); }
    buffer=m_config->readEntry("IPAdressRange", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         buf1=buffer; buf2=buffer; buf3=buffer; buf4=buffer;
         Intbuffer1=buf1.section('.',0,0).toInt();
         Intbuffer2=buf2.section('.',1,1).toInt();
         Intbuffer3=buf3.section('.',2,2).toInt();
         Intbuffer4=buf4.section('.',3,3).toInt();
         spinBoxAddressRange1->setValue(Intbuffer1);
         spinBoxAddressRange2->setValue(Intbuffer2);
         spinBoxAddressRange3->setValue(Intbuffer3);
         spinBoxAddressRange4->setValue(Intbuffer4);
    }
    else { errorReading =true; error.append("IPAdressRange "); }
    buffer=m_config->readEntry("IPAdressRangeOut", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         buf1=buffer; buf2=buffer; buf3=buffer; buf4=buffer;
         Intbuffer1=buf1.section('.',0,0).toInt();
         Intbuffer2=buf2.section('.',1,1).toInt();
         Intbuffer3=buf3.section('.',2,2).toInt();
         Intbuffer4=buf4.section('.',3,3).toInt();
         spinBoxAddressRange1out->setValue(Intbuffer1);
         spinBoxAddressRange2out->setValue(Intbuffer2);
         spinBoxAddressRange3out->setValue(Intbuffer3);
         spinBoxAddressRange4out->setValue(Intbuffer4);
    }
    else { errorReading =true; error.append("IPAdressRangeOut "); }
    buffer=m_config->readEntry("ServerPort", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         SpinBox_ServerPort->setValue(buffer.toInt());
    }
    else { errorReading =true; error.append("IPAdressRangeOut "); }
    buffer=m_config->readEntry("Callsign", "undefined");
    if (buffer != "undefined")
    {
         LE_callsign->setText(buffer);
    }
    else { errorReading =true; error.append("Callsign "); }
    buffer=m_config->readEntry("NetworkFrequency", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         SpinBox_Hz->setValue(buffer.toInt());
    }
    else { errorReading =true; error.append("NetworkFrequency "); }
    buffer=m_config->readEntry("PlayerNumber", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         SpinBox_Player->setValue(buffer.toInt());
    }
    else { errorReading =true; error.append("PlayerNumber "); }
    buffer=m_config->readEntry("MultiPlayer Server", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         ComboBox_Server->setCurrentItem(buffer.toInt());
    }
    else { errorReading =true; error.append("MultiPlayerServer "); }
    buffer=m_config->readEntry("Server String", "undefined");
    if (buffer != "undefined")
    {
         LE_Server->setText(buffer);
    }
    else { errorReading =true; error.append("ServerString "); }

        if (verbose_app == true)
        {
            if (errorReading == false)
            {
                TXTEdit_STDOUT->append(tr2i18n("*** Success *** : Config load"));
            }
            else
            {
                TXTEdit_STDOUT->append( tr2i18n("*** Warning *** : Can't restore all settings"));
                TXTEdit_STDOUT->append( tr2i18n("*** Warning *** : Perhaps some items was empty when saving"));
                buffer=buffer.setNum(error.contains(" ",false),10);
                TXTEdit_STDOUT->append(tr2i18n("number of errors :")+buffer);
                TXTEdit_STDOUT->append(error);
            }
        }
        if (notFirstDisplay == false)
        {
            emit (allJobsFinished()); notFirstDisplay = true;
            emit(loadingData( tr2i18n("Ready")));
        }
}

void KFreeFlight_view::saveSlot()
{
    QString buffer, buf;
    QDate TheDate;
    QTime TheTime;
    int index;

    m_config->setGroup("Flightgear Network");
    buffer=m_config->readEntry("IPAdressRange", "undefined");
    if ((buffer != "undefined") && (buffer != ""))
    {
         buf=buffer.section('.',3,3);
    }

    m_config->setGroup("Flightgear General");

    m_config->writeEntry("SplashScreen",buffer.sprintf("%d",CB_Splashscreen->isChecked())) ;
    m_config->writeEntry("GameMode",buffer.sprintf("%d",CB_GameMode->isChecked()));
    m_config->writeEntry("IntroMusic",buffer.sprintf("%d",CB_IntroMusic->isChecked()));
    m_config->writeEntry("UnitMeter",buffer.sprintf("%d",CB_UnitMeter->isChecked()));
    m_config->writeEntry("RealWeather",buffer.sprintf("%d",CB_RealWeather->isChecked()));
    m_config->writeEntry("nmea",buffer.sprintf("%d",CB_NMEA->isChecked()));
    m_config->writeEntry("httpd",buffer.sprintf("%d",CB_NMEA->isChecked()));
    m_config->writeEntry("AtlasWithFlightgear",buffer.sprintf("%d",CB_AtlasToo->isChecked()));
    m_config->writeEntry("FullScreen",buffer.sprintf("%d",CB_Fullscreen->isChecked()));
    m_config->writeEntry("Joystick",buffer.sprintf("%d",CB_Joystick->isChecked()));
    m_config->writeEntry("Wireframe",buffer.sprintf("%d",CB_Wireframe->isChecked()));
    m_config->writeEntry("WireframeObjects",buffer.sprintf("%d",CB_WireframeObjects->isChecked()));

    m_config->setGroup("Flightgear Render");

    m_config->writeEntry("SkyBlend",buffer.sprintf("%d",CB_SkyBlend->isChecked()));
    m_config->writeEntry("DistanceAttenuation",buffer.sprintf("%d",CB_DistanceAttenuation->isChecked()));
    m_config->writeEntry("HorizonEffect",buffer.sprintf("%d",CB_HorizonEffect->isChecked()));
    m_config->writeEntry("Textures",buffer.sprintf("%d",CB_Textures->isChecked()));
    m_config->writeEntry("RandomObjects",buffer.sprintf("%d",CB_RandomObjects->isChecked()));
    m_config->writeEntry("Clouds",buffer.sprintf("%d",CB_Clouds->isChecked()));
    m_config->writeEntry("Clouds3d",buffer.sprintf("%d",CB_Clouds3d->isChecked()));
    m_config->writeEntry("CloudsBump",buffer.sprintf("%d",CB_CloudsBump->isChecked()));
    m_config->writeEntry("Mousepointer",buffer.sprintf("%d",CB_MousePointer->isChecked()));
    m_config->writeEntry("EnhancedLighting",buffer.sprintf("%d",CB_EnhancedLighting->isChecked()));
    m_config->writeEntry("SpecularHighlight",buffer.sprintf("%d",CB_SpecularHighlight->isChecked()));
    m_config->writeEntry("ShadingFlat",buffer.sprintf("%d",RB_Shading_flat->isChecked()));
    m_config->writeEntry("ShadingSmooth",buffer.sprintf("%d",RB_Shading_smooth->isChecked()));
    m_config->writeEntry("Resolution",buffer.setNum( ComboBox_Resolution->currentItem(), 10));
    m_config->writeEntry("Resolution bpp",buffer.setNum( ComboBox_Resolution_bpp->currentItem(), 10));
    m_config->writeEntry("ShadowsAircraft",buffer.sprintf("%d",CB_Shadows_Aircraft->isChecked()));
    m_config->writeEntry("ShadowsAircraftTransp",buffer.sprintf("%d",CB_Shadows_AircraftTransp->isChecked()));
    m_config->writeEntry("ShadowsSceneryObjects",buffer.sprintf("%d",CB_Shadows_SceneryObjects->isChecked()));
    m_config->writeEntry("ShadowsAiObjects",buffer.sprintf("%d",CB_Shadows_AiObjects->isChecked()));
    m_config->writeEntry("Lightning",buffer.sprintf("%d",CB_Lightning->isChecked()));
    m_config->writeEntry("Precipitation",buffer.sprintf("%d",CB_Precipitation->isChecked()));

    m_config->setGroup("Flightgear Airport");

    m_config->writeEntry("Airport",LE_Airport->text().stripWhiteSpace());
    m_config->writeEntry("Runway",LE_Runway->text().stripWhiteSpace());
    m_config->writeEntry("AirportNb",buffer.setNum( Table_Airport->currentRow (),10));
    m_config->writeEntry("RunwayNb",buffer.setNum( Table_Runway->currentRow (),10));
    m_config->writeEntry("City",LE_AddAirport_City->text().stripWhiteSpace());

    m_config->setGroup("Flightgear Carrier");
    m_config->writeEntry("Carrier name",LE_CarrierName->text().stripWhiteSpace());
    m_config->writeEntry("Carrier prop",LE_CarrierProp->text().stripWhiteSpace());
    m_config->writeEntry("Cat1",buffer.sprintf("%d",RB_CarrierPosC1->isChecked()));
    m_config->writeEntry("Cat2",buffer.sprintf("%d",RB_CarrierPosC2->isChecked()));
    m_config->writeEntry("Cat3",buffer.sprintf("%d",RB_CarrierPosC3->isChecked()));
    m_config->writeEntry("Cat4",buffer.sprintf("%d",RB_CarrierPosC4->isChecked()));
    m_config->writeEntry("Park1",buffer.sprintf("%d",RB_CarrierPosP1->isChecked()));
    m_config->writeEntry("Other Place",buffer.sprintf("%d",RB_CarrierPosOther->isChecked()));
    m_config->writeEntry("Other place name",LE_CarrierStart->text().stripWhiteSpace());
    m_config->writeEntry("Always carrier",buffer.sprintf("%d",CB_CarrierProperty->isChecked()));

    m_config->setGroup("Flightgear Aircraft");

    m_config->writeEntry("Aircraft",buffer.setNum( ComboBox_Aircraft->currentItem(), 10));
    m_config->writeEntry("Altitude",SpinBox_Altitude->text().stripWhiteSpace()) ;
    m_config->writeEntry("Speed",SpinBox_Speed->text().stripWhiteSpace()) ;
    m_config->writeEntry("FailurePitot",buffer.sprintf("%d",CB_Failure_Pitot->isChecked()));
    m_config->writeEntry("FailureStatic",buffer.sprintf("%d",CB_Failure_Static->isChecked()));
    m_config->writeEntry("FailureSystem",buffer.sprintf("%d",CB_Failure_System->isChecked()));
    m_config->writeEntry("FailureVacuum",buffer.sprintf("%d",CB_Failure_Vacuum->isChecked()));
    m_config->writeEntry("AiTraffic",buffer.sprintf("%d",CB_AiTraffic->isChecked()));
    m_config->writeEntry("Freeze",buffer.sprintf("%d",CB_Freeze->isChecked()));
    m_config->writeEntry("FuelFreeze",buffer.sprintf("%d",CB_FuelFreeze->isChecked()));
    m_config->writeEntry("AutoCoordon",buffer.sprintf("%d",CB_AutoCoordon->isChecked()));
    m_config->writeEntry("InAir",buffer.sprintf("%d",RB_InAIr->isChecked()));
    m_config->writeEntry("OnGround",buffer.sprintf("%d",RB_Ground->isChecked()));
    m_config->writeEntry("OnCarrier",buffer.sprintf("%d",RB_Carrier->isChecked()));
    m_config->writeEntry("OnGPSpos",buffer.sprintf("%d",RB_GPS->isChecked()));
    m_config->writeEntry("GPSlat",kDoubleSpinBox_GPS_lat->text().stripWhiteSpace()) ;
    m_config->writeEntry("GPSlong",kDoubleSpinBox_GPS_long->text().stripWhiteSpace()) ;
    m_config->writeEntry("GPSHeading",SpinBox_Heading->text().stripWhiteSpace()) ;

    m_config->setGroup("Flightgear Time");

    m_config->writeEntry("RealTime",buffer.sprintf("%d",RB_Real_Time->isChecked()));
    m_config->writeEntry("FixedTime",buffer.sprintf("%d",RB_Fixed_Time->isChecked()));
    m_config->writeEntry("TimeOfDay",buffer.sprintf("%d",RB_TimeOfDay->isChecked()));
    m_config->writeEntry("FreezeTime",buffer.sprintf("%d",CB_FreezeTime->isChecked()));
    TheDate=DateEdit_Date->date();
    m_config->writeEntry("Date",TheDate.toString(Qt::ISODate));
    TheTime=TimeEdit_Time->time();
    m_config->writeEntry("Time",TheTime.toString(Qt::ISODate));
    m_config->writeEntry("Combobox_TimeOfDay",buffer.setNum( ComboBox_Time->currentItem(), 10));
    m_config->writeEntry("Combobox_Season",buffer.setNum( ComboBox_Season->currentItem(), 10));

    m_config->setGroup("Flightgear Weather");

    m_config->writeEntry("DirectionWind",SpinBox_DirectionWind->text().stripWhiteSpace() );
    m_config->writeEntry("SpeedWind",SpinBox_SpeedWind->text().stripWhiteSpace()) ;
    m_config->writeEntry("Visibility",SpinBox_Visibility->text());
    m_config->writeEntry("Turbulence" , buffer.setNum( Slider_Turbulence->value(), 10));
    m_config->writeEntry("Fog0",buffer.sprintf("%d",RB_Fog_0->isChecked()));
    m_config->writeEntry("Fog1",buffer.sprintf("%d",RB_Fog_1->isChecked()));
    m_config->writeEntry("Fog2",buffer.sprintf("%d",RB_Fog_2->isChecked()));
    m_config->writeEntry("RandomWind",buffer.sprintf("%d",CB_RandomWind->isChecked()));

    m_config->setGroup("Flightgear FlightPlan");

    m_config->writeEntry("FlightPlan",LE_FindFile->text().stripWhiteSpace());
    m_config->writeEntry("FlightPlanNone",buffer.sprintf("%d",RB_WayPoint_none->isChecked()));
    m_config->writeEntry("FlightPlanEdited",buffer.sprintf("%d",RB_WayPoint_edit->isChecked()));
    m_config->writeEntry("FlightPlanFile",buffer.sprintf("%d",RB_WayPoint_load->isChecked()));
    buffer="";
    for (index=0 ; index < (ListBox_WayPoint->numRows() -1) ; index++)
    {
        ListBox_WayPoint->setCurrentItem(index);
        buffer.append(ListBox_WayPoint->currentText()+",");
    }
    ListBox_WayPoint->setCurrentItem(index++);
    buffer.append(ListBox_WayPoint->currentText());
    m_config->writeEntry("MyFlightPlan",buffer);

    m_config->setGroup("Flightgear Radio");

    m_config->writeEntry("DmeNav1",buffer.sprintf("%d",RB_nav1->isChecked()));
    m_config->writeEntry("DmeNav2",buffer.sprintf("%d",RB_nav2->isChecked()));
    m_config->writeEntry("OtherDme",buffer.sprintf("%d",RB_dme->isChecked()));
    m_config->writeEntry("Nav1",buffer.setNum(kDoubleSpinBox_NAV1->value(),'f',3)) ;
    m_config->writeEntry("Nav1standby",buffer.setNum(kDoubleSpinBox_NAV1standby->value(),'f',3)) ;
    m_config->writeEntry("Nav1Radial",SpinBox_nav1_rad->text()) ;
    m_config->writeEntry("Nav2",buffer.setNum(kDoubleSpinBox_NAV2->value(),'f',3)) ;
    m_config->writeEntry("Nav2standby",buffer.setNum(kDoubleSpinBox_NAV2standby->value(),'f',3)) ;
    m_config->writeEntry("Nav2Radial",SpinBox_nav2_rad->text()) ;
    m_config->writeEntry("Dme",buffer.setNum(kDoubleSpinBox_DME->value(),'f',3)) ;
    m_config->writeEntry("Adf",SpinBox_adf->text() );
    m_config->writeEntry("Adfstandby",SpinBox_adfstandby->text() );
    m_config->writeEntry("AdfRotation",SpinBox_adf_rot->text() );
    buffer=SpinBox_TACAN1->text()+"."+SpinBox_TACAN2->text()+"."+SpinBox_TACAN3->text()+
        "."+ComboBox_tacan->currentText();
    m_config->writeEntry("Tacan",buffer );

    m_config->setGroup("Flightgear Comm");

    m_config->writeEntry("Comm1",buffer.setNum(kDoubleSpinBox_COMM1->value(),'f',3)) ;
    m_config->writeEntry("Comm1standby",buffer.setNum(kDoubleSpinBox_COMM1standby->value(),'f',3)) ;
    m_config->writeEntry("Comm2",buffer.setNum(kDoubleSpinBox_COMM2->value(),'f',3)) ;
    m_config->writeEntry("Comm2standby",buffer.setNum(kDoubleSpinBox_COMM2standby->value(),'f',3)) ;
    m_config->writeEntry("AtcVoices",buffer.sprintf("%d",CB_Comm_AtcVoices->isChecked()));

    m_config->setGroup("Flightgear Network");

    m_config->writeEntry("MultiPlayerNone",buffer.sprintf("%d",RB_multiplayer_none->isChecked()));
    m_config->writeEntry("MultiPlayerLocal",buffer.sprintf("%d",RB_multiplayer_local->isChecked()));
    m_config->writeEntry("MultiPlayerInternet",buffer.sprintf("%d",RB_multiplayer_internet->isChecked()));
    if (spinBoxAddressRange4->value() != 255) buf=spinBoxAddressRange4->text().stripWhiteSpace();
    buffer=spinBoxAddressRange1->text().stripWhiteSpace()+"."+
        spinBoxAddressRange2->text().stripWhiteSpace()+"."+
        spinBoxAddressRange3->text().stripWhiteSpace()+"."
        +buf;
    m_config->writeEntry("IPAdressRange",buffer);
    buffer=spinBoxAddressRange1out->text().stripWhiteSpace()+"."+
        spinBoxAddressRange2out->text().stripWhiteSpace()+"."+
        spinBoxAddressRange3out->text().stripWhiteSpace()+"."
        +spinBoxAddressRange4out->text().stripWhiteSpace();
    m_config->writeEntry("IPAdressRangeOut",buffer);
    m_config->writeEntry("PlayerNumber",SpinBox_Player->text());
    m_config->writeEntry("NetworkFrequency",SpinBox_Hz->text());
    m_config->writeEntry("ServerPort",SpinBox_ServerPort->text());
    m_config->writeEntry("Callsign",LE_callsign->text().stripWhiteSpace());
    m_config->writeEntry("MultiPlayer Server",buffer.setNum( ComboBox_Time->currentItem(), 10));
    m_config->writeEntry("Server String",LE_Server->text().stripWhiteSpace());

    m_config->sync();

    if (verbose_app == true ) TXTEdit_STDOUT->append(tr2i18n("*** Success *** : Config save"));
}

void KFreeFlight_view::launchFlightgearSlot()
{
typedef QValueList<QCString> Args;

    Args arguments;
    KProcess *commandline;
    bool flag_atlas=false;
    QString buffer, buffer2, MyYear, MyMonth, MyDay, MyHour, MyMinute;
    float turbulence;
    uint ite;
    int i;
    bool flagWeatherFetch=false;

    commandline=new KProcess;
    m_config->setGroup("Settings FlightGear");
    buffer=m_config->readEntry("Only one instance","false");
    buffer2=m_config->readEntry("Executable", "undefined");
    if ((buffer2 == "undefined") || (buffer2 == ""))
    {
        buffer2=tr2i18n("No FlightGear executable file selected")+"\n"+
            tr2i18n("Do you want to use default \"fgfs\" executable ?");
        switch (KMessageBox::warningYesNo( this, buffer2))
        {
            case 3: { buffer2="fgfs" ; *commandline << buffer2; break; }
            default: return;
        }
    }
    else *commandline << buffer2;
    if ((buffer == "true") && (searchPID(buffer2) == true))
    {
        return;
    }

    *m_fgfsOutput="";

    buffer=m_config->readEntry("FG_ROOT", "undefined");
    buffer2=m_config->readEntry("FG_SCENERY", "undefined");
    if ((buffer != "undefined") && (buffer.stripWhiteSpace() != "")
        && (buffer2 != "undefined") && (buffer2.stripWhiteSpace() != ""))
    {
         *commandline << "--fg-root="+buffer;
         *commandline << "--fg-scenery="+buffer+"/Scenery/:"+buffer2;
    }

    else
    {
        if ((buffer == "undefined") || (buffer.stripWhiteSpace() == ""))
        {
            buffer=tr2i18n("The FG_Root path is empty\nPlease configure it in the Settings/Configure menu entry")+"\n"+tr2i18n("Try without define this option ?");

            switch (KMessageBox::warningYesNo( this, buffer ))
            {
                case 3: break;
                default: return;
            }

        }
        else { *commandline << "--fg-root="+buffer; }
        if ((buffer2 == "undefined") || (buffer2.stripWhiteSpace() == ""))
        {
            buffer=tr2i18n("The FG_SCENERY path is empty\nThe only mesh you will seeing is San-Fransisco Bay.\nIf you want another place, please download addons scenery and airports from flightgear web site (http://www.flightgear.org) and put the directory name where you put them in the Settings/Configure menu entry at FG_SCENERY path\nIt's a good idea to put scenery in $FG_ROOT/Data/Scenery directory and unzip airports in FG_ROOT/Airports directory.")
            +"\n"+tr2i18n("Try without define this option ?");

            switch (KMessageBox::warningYesNo( this, buffer))
            {
                case 3: break;
                default: return;
            }
        }
    }

    if (CB_AtlasToo->isChecked()) flag_atlas=true;

    //general options

    if (CB_Splashscreen->isChecked()) { *commandline << "--enable-splash-screen"; }
        else { *commandline << "--disable-splash-screen"; }

    if (CB_GameMode->isChecked()) { *commandline << "--enable-game-mode"; }
        else { *commandline << "--disable-game-mode"; }

    if (CB_IntroMusic->isChecked()) { *commandline << "--enable-intro-music"; }
        else { *commandline << "--disable-intro-music"; }

    if (CB_UnitMeter->isChecked()) { *commandline << "--units-meters"; }
        else { *commandline << "--units-feet"; }

    if (CB_RealWeather->isChecked()) { *commandline << "--enable-real-weather-fetch";flagWeatherFetch=true; }
        else { *commandline << "--disable-real-weather-fetch"; }

    m_config->setGroup("Flightgear Network");
    buffer=m_config->readEntry("HostHttp", "undefined");
    if ((buffer == "undefined") || (buffer == ""))
    {
         switch (KMessageBox::warningYesNo(this,
            tr2i18n("No host or port configured, the http server will not be launched\n"
              "and the NMEA protocol will not be actived!")+"\n"+tr2i18n("Continue ?")))
         {
            case 3: break;
            default: return;
        }
    }
    else
    {
        buffer2=m_config->readEntry("PortHttp", "undefined");
        if ((buffer2 == "undefined") || (buffer2 == ""))
        {
            switch (KMessageBox::warningYesNo(this,
            tr2i18n("No host or port configured, the http server will not be launched\n"
              "and the NMEA protocol will not be actived!")+"\n"+tr2i18n("Continue ?")))
            {
                case 3: break;
                default: return;
            }
        }
        else
        {
            if (CB_ServerHttp->isChecked()) { *commandline << "--httpd="+buffer2; }
            if (CB_NMEA->isChecked()) 
            {
                *commandline << "--nmea=socket,out,0.5,"+buffer+","+buffer2+",udp";
            }
        }
    }
    if (CB_Joystick->isChecked()) { *commandline << "--control=joystick"; }

    if (CB_Fullscreen->isChecked()) { *commandline << "--enable-fullscreen"; }
            else { *commandline << "--disable-fullscreen"; }
    if (CB_Wireframe->isChecked()) { *commandline << "--enable-wireframe" ; }
    else { *commandline << "--disable-wireframe" ; }
    if (CB_WireframeObjects->isChecked())
        { *commandline << "--prop:sim/rendering/shadows-debug[0]=true"; }
    else { *commandline << "--prop:sim/rendering/shadows-debug[0]=false"; }

    //render
    if (CB_RandomObjects->isChecked()) { *commandline << "--enable-random-objects"; }
        else { *commandline << "--disable-random-objects"; }

    if (CB_SkyBlend->isChecked()) { *commandline << "--enable-skyblend"; }
        else { *commandline << "--disable-skyblend"; }

    if (CB_Textures->isChecked()) { *commandline << "--enable-textures"; }
        else { *commandline << "--disable-textures"; }

    if (CB_HorizonEffect->isChecked()) { *commandline << "--enable-horizon-effect"; }
        else { *commandline << "--disable-horizon-effect"; }

    if (CB_Clouds->isChecked())
    {
        *commandline << "--enable-clouds";
    }
        else { *commandline << "--disable-clouds"; }
    if (CB_CloudsBump->isChecked())
    {
        *commandline << "--prop:sim/rendering/bump-mapping[0]=1";
    }
    else {*commandline << "--prop:sim/rendering/bump-mapping[0]=0";  }
    if (CB_Clouds3d->isChecked()) { *commandline << "--enable-clouds3d"; }
        else { *commandline << "--disable-clouds3d"; }

    if (CB_EnhancedLighting->isChecked()) { *commandline << "--enable-enhanced-lighting"; }
        else { *commandline << "--disable-enhanced-lighting"; }

    if (CB_MousePointer->isChecked()) { *commandline << "--enable-mouse-pointer"; }
        else { *commandline << "--disable-mouse-pointer"; }

    if (CB_DistanceAttenuation->isChecked()) { *commandline << "--enable-distance-attenuation"; }
            else { *commandline << "--disable-distance-attenuation"; }

    if (CB_SpecularHighlight->isChecked()) { *commandline << "--enable-specular-highlight"; }
        else { *commandline << "--disable-specular-highlight"; }

    if (RB_Shading_flat->isChecked()) { *commandline << "--shading-flat"  ;}
    if (RB_Shading_smooth->isChecked()) { *commandline << "--shading-smooth"  ;}

    *commandline << "--geometry="+ComboBox_Resolution->currentText().stripWhiteSpace();
    *commandline << "--bpp="+ComboBox_Resolution_bpp->currentText().stripWhiteSpace();

    if (CB_Shadows_Aircraft->isChecked())
        { *commandline << "--prop:sim/rendering/shadows-ac[0]=true"; }
        else { *commandline << "--prop:sim/rendering/shadows-ac[0]=false"; }
    if (CB_Shadows_AircraftTransp->isChecked())
        { *commandline << "--prop:sim/rendering/shadows-ac-transp[0]=true"; }
        else { *commandline << "--prop:sim/rendering/shadows-ac-transp[0]=false"; }
    if (CB_Shadows_SceneryObjects->isChecked())
        { *commandline << "--prop:sim/rendering/shadows-to[0]=true"; }
        else { *commandline << "--prop:sim/rendering/shadows-to[0]=false"; }
    if (CB_Shadows_AiObjects->isChecked())
        { *commandline << "--prop:sim/rendering/shadows-ai[0]=true"; }
        else { *commandline << "--prop:sim/rendering/shadows-ai[0]=false"; }

    if (CB_Lightning->isChecked())
        { *commandline << "--prop:sim/rendering/lightning-enable[0]=true"; }
        else { *commandline << "--prop:sim/rendering/lightning-enable[0]=false"; }
    if (CB_Precipitation->isChecked())
        { *commandline << "--prop:sim/rendering/precipitation-enable[0]=true"; }
        else { *commandline << "--prop:sim/rendering/precipitation-enable[0]=false"; }

    //airport
    if (RB_Ground->isChecked() || RB_InAIr->isChecked())
    {
        if (LE_Airport->text().stripWhiteSpace().isEmpty())
        {
            buffer=tr2i18n("No airport selected!")
                +"\n"+tr2i18n("Try without define this option ?");
            switch (KMessageBox::warningYesNo( this, buffer))
            {
                case 3: break;
                default: return;
            }
        }
        else
        {
            *commandline << "--airport="+LE_Airport->text().stripWhiteSpace().upper();
            if (LE_Runway->text().stripWhiteSpace() != "")
            {
                *commandline << "--runway="+LE_Runway->text().stripWhiteSpace().upper();
            }
        }
        if (CB_CarrierProperty->isChecked())
        { *commandline <<  LE_CarrierProp->text().stripWhiteSpace(); }
    }

    //carrier
    if (RB_Carrier->isChecked())
    {
        *commandline << LE_CarrierProp->text().stripWhiteSpace();
        *commandline << "--carrier="+LE_CarrierName->text().stripWhiteSpace();
        if(RB_CarrierPosC1->isChecked()) buffer="cat-1";
        if(RB_CarrierPosC2->isChecked()) buffer="cat-2";
        if(RB_CarrierPosC3->isChecked()) buffer="cat-3";
        if(RB_CarrierPosC4->isChecked()) buffer="cat-4";
        if(RB_CarrierPosP1->isChecked()) buffer="park-1";
        if(RB_CarrierPosOther->isChecked()) buffer=LE_CarrierStart->text().stripWhiteSpace();
        *commandline << "--parkpos="+buffer;
    }

    if (RB_GPS->isChecked())
    {
        *commandline << "--lon="+kDoubleSpinBox_GPS_long->text().stripWhiteSpace().replace( QChar(','), "." );
        *commandline << "--lat="+kDoubleSpinBox_GPS_lat->text().stripWhiteSpace().replace( QChar(','), "." );
        *commandline << "--heading="+SpinBox_Heading->text().stripWhiteSpace();
        if (CB_CarrierProperty->isChecked())
            { *commandline <<  LE_CarrierProp->text().stripWhiteSpace(); }
    }

    //aircraft
    if (ComboBox_Aircraft->currentText()==tr2i18n("Available Aircraft") || ComboBox_Aircraft->currentText()=="")
    {
        buffer=tr2i18n("No aircraft selected!")
            +"\n"+tr2i18n("Try without define this option ?");;

        switch (KMessageBox::warningYesNo( this, buffer))
        {
            case 3: break;
            default: return;
        }
    }
    else { *commandline << "--aircraft="+ComboBox_Aircraft->currentText().stripWhiteSpace(); }

    if (CB_AiTraffic->isChecked()) 
    {
        *commandline << "--enable-ai-models";
        *commandline << "--prop:sim/ai-traffic/enabled[0]=true";
        *commandline << "--prop:sim/ai-traffic/level[0]=2";
    }
        else { *commandline << "--disable-ai-models"; }

    if (CB_Freeze->isChecked()) { *commandline << "--enable-freeze"; }
        else { *commandline << "--disable-freeze"; }

    if (CB_FuelFreeze->isChecked()) { *commandline << "--enable-fuel-freeze"; }
        else { *commandline << "--disable-fuel-freeze"; }

    if (CB_AutoCoordon->isChecked()) { *commandline << "--enable-auto-coordination"; }
        else { *commandline << "--disable-auto-coordination"; }

    if (RB_InAIr->isChecked())
    {
        *commandline << "--in-air";
        *commandline << "--altitude="+SpinBox_Altitude->text().stripWhiteSpace();
        *commandline << "--vc="+SpinBox_Speed->text().stripWhiteSpace();
    }

    if (CB_Failure_Pitot->isChecked()) { *commandline << "--failure=pitot"; }
    if (CB_Failure_Static->isChecked()) { *commandline << "--failure=static"; }
    if (CB_Failure_System->isChecked()) { *commandline << "--failure=electrical"; }
    if (CB_Failure_Vacuum->isChecked()) { *commandline << "--failure=vacuum"; }


    //time
    if (CB_FreezeTime->isChecked()) { *commandline << "--enable-clock-freeze"; }
        else { *commandline << "--disable-clock-freeze"; }

    if (RB_Fixed_Time->isChecked())
    {
        MyYear=MyYear.setNum(DateEdit_Date->date().year(),10);

        if (DateEdit_Date->date().month() <= 9) 
        { MyMonth="0"+MyMonth.setNum(DateEdit_Date->date().month(),10); }
            else { MyMonth.setNum(DateEdit_Date->date().month(),10); }

        if (DateEdit_Date->date().day() <=9 ) 
        { MyDay="0"+MyDay.setNum(DateEdit_Date->date().day(),10); }
            else { MyDay.setNum(DateEdit_Date->date().day(),10);  }

        if (TimeEdit_Time->time().hour() <= 9) 
        { MyHour="0"+MyHour.setNum(TimeEdit_Time->time().hour(),10); }
            else { MyHour.setNum(TimeEdit_Time->time().hour(),10); }

        if (TimeEdit_Time->time().minute() <= 9) 
        { MyMinute="0"+MyMinute.setNum(TimeEdit_Time->time().minute(),10); }
            else { MyMinute.setNum(TimeEdit_Time->time().minute(),10); }

        *commandline <<
        "--start-date-lat="+MyYear+":"+MyMonth+":"+MyDay+":"+MyHour+":"+MyMinute+":00";
    }

    if (RB_TimeOfDay->isChecked())
    {
        switch (ComboBox_Time->currentItem())
        {
            case 0: buffer="dawn";break;
            case 1: buffer="morning";break;
            case 2: buffer="noon";break;
            case 3: buffer="afternoon";break;
            case 4: buffer="dusk";break;
            case 5: buffer="evening";break;
            case 6: buffer="midnight";break;
            default: buffer="noon";
        }
        *commandline << "--timeofday="+buffer;
    }

    if(ComboBox_Season->currentItem() == 1)
        *commandline << "--prop:sim/startup/season=winter";

    //weather
    if (flagWeatherFetch == false)
    {
        if (CB_RandomWind->isChecked()) *commandline << "--random-wind";
        else *commandline << "--wind="+SpinBox_DirectionWind->text().stripWhiteSpace()
        +"@"+SpinBox_SpeedWind->text().stripWhiteSpace();

        *commandline << "--visibility="+SpinBox_Visibility->text();

        buffer=buffer.setNum(Slider_Turbulence->value(),10);
        turbulence=buffer.toFloat()/10;
        buffer=buffer.number ( turbulence, 'f', 1 );
        *commandline << "--turbulence="+buffer;
    }

    if (RB_Fog_0->isChecked()) { *commandline << "--fog-disable"  ;}
    if (RB_Fog_1->isChecked()) { *commandline << "--fog-fastest"  ;}
    if (RB_Fog_2->isChecked()) { *commandline << "--fog-nicest"  ;}


    if (verbose_app == true ) TXTEdit_STDOUT->append(buffer);

    //radio 
    *commandline <<
        "--nav1="+SpinBox_nav1_rad->text().stripWhiteSpace()+":"
        +kDoubleSpinBox_NAV1->text().stripWhiteSpace().replace( QChar(','), "." );
    *commandline <<
        "--prop:instrumentation/nav/frequencies/standby-mhz="
        +kDoubleSpinBox_NAV1standby->text().stripWhiteSpace().replace( QChar(','), "." );

    *commandline <<
    "--nav2="+SpinBox_nav2_rad->text().stripWhiteSpace()
        +":"+kDoubleSpinBox_NAV2->text().stripWhiteSpace().replace( QChar(','), "." );
    *commandline <<
        "--prop:instrumentation/nav[1]/frequencies/standby-mhz="
        +kDoubleSpinBox_NAV2standby->text().stripWhiteSpace().replace( QChar(','), "." );

    *commandline <<
    "--adf="+SpinBox_adf_rot->text().stripWhiteSpace()+":"
        +SpinBox_adf->text().stripWhiteSpace();
    *commandline << "--prop:instrumentation/adf/frequencies/standby-khz="
        +SpinBox_adfstandby->text().stripWhiteSpace();

    *commandline <<  "--prop:instrumentation/tacan/frequencies/selected-channel[1]="
        +SpinBox_TACAN1->text().stripWhiteSpace();
    *commandline <<  "--prop:instrumentation/tacan/frequencies/selected-channel[2]="
        +SpinBox_TACAN2->text().stripWhiteSpace();
    *commandline <<  "--prop:instrumentation/tacan/frequencies/selected-channel[3]="
        +SpinBox_TACAN3->text().stripWhiteSpace();
    *commandline <<  "--prop:instrumentation/tacan/frequencies/selected-channel[4]="
        +ComboBox_tacan->currentText().stripWhiteSpace();

    if (RB_nav1->isChecked()) { *commandline << "--dme=nav1" ; }
    if (RB_nav2->isChecked()) { *commandline << "--dme=nav2" ; }
    if (RB_dme->isChecked())
    {
        *commandline << "--dme="+kDoubleSpinBox_DME->text().stripWhiteSpace().replace( QChar(','), "." );
    }

    //comm
    *commandline <<
        "--prop:instrumentation/comm/frequencies/selected-mhz="
        +kDoubleSpinBox_COMM1->text().stripWhiteSpace().replace( QChar(','), "." );
    *commandline <<
        "--prop:instrumentation/comm/frequencies/standby-mhz="
        +kDoubleSpinBox_COMM1standby->text().stripWhiteSpace().replace( QChar(','), "." );
    *commandline <<
        "--prop:instrumentation/comm[1]/frequencies/selected-mhz="
        +kDoubleSpinBox_COMM2->text().stripWhiteSpace().replace( QChar(','), "." );
    *commandline <<
        "--prop:instrumentation/comm[1]/frequencies/standby-mhz="
        +kDoubleSpinBox_COMM2standby->text().stripWhiteSpace().replace( QChar(','), "." );
    if (CB_Comm_AtcVoices->isChecked())
        { *commandline << "--prop:sim/sound/atc-chatter[0]=true"; }
        else { *commandline << "--prop:sim/sound/atc-chatter[0]=false"; }

    //Configure
    if (RB_multiplayer_local->isChecked())
    {
        buffer=spinBoxAddressRange1->text()+"."+spinBoxAddressRange2->text()+"."
            +spinBoxAddressRange3->text()+".255";
        *commandline <<
          "--multiplay=out,"+SpinBox_Hz->text()+","+buffer+","+SpinBox_ServerPort->text().stripWhiteSpace();
        *commandline <<
          "--multiplay=in,"+SpinBox_Hz->text()+","+buffer+","+SpinBox_ServerPort->text().stripWhiteSpace();
        *commandline << "--callsign=player"+SpinBox_Player->text();
    }
    if (RB_multiplayer_internet->isChecked())
    {
        buffer=spinBoxAddressRange1->text()+"."+spinBoxAddressRange2->text()+"."
          +spinBoxAddressRange3->text()+"."+spinBoxAddressRange4->text();
        *commandline <<
          "--multiplay=in,"+SpinBox_Hz->text()+","+buffer+","+SpinBox_ServerPort->text().stripWhiteSpace();
        buffer=spinBoxAddressRange1out->text()+"."+spinBoxAddressRange2out->text()+"."
          +spinBoxAddressRange3out->text()+"."+spinBoxAddressRange4out->text();
        if (LE_Server->text().stripWhiteSpace() != "")
        {
            *commandline << "--multiplay=out,"+SpinBox_Hz->text()+","
              +LE_Server->text().stripWhiteSpace()+","+SpinBox_ServerPort->text().stripWhiteSpace();
        }
        else
        {
            *commandline << "--multiplay=out,"
              +SpinBox_Hz->text()+","+buffer+","+SpinBox_ServerPort->text().stripWhiteSpace();
        }
        *commandline << "--callsign="+LE_callsign->text();
    }


    //Flight Plan
    if (RB_WayPoint_load->isChecked())
    {
        *commandline << "--flight-plan="+LE_FindFile->text().stripWhiteSpace();
    }

    if (RB_WayPoint_edit->isChecked())
    {
        for (ite=0 ; ite < ListBox_WayPoint->count() ; ite++)
        {
            ListBox_WayPoint->setCurrentItem(ite);
            *commandline << "--wp="+ListBox_WayPoint->currentText().stripWhiteSpace().upper() ;
        }
    }

    //Externals options
    m_config->setGroup("Settings FlightGear");
    buffer=m_config->readEntry("Options list", "noOption");
    if((buffer.stripWhiteSpace() != "noOption") && (buffer.stripWhiteSpace() != ""))
    {
        for (i=0 ; i < (buffer.contains(',',false)+1) ; i++)
        {
            buffer2 = buffer;
            *commandline << buffer2.section(',',i,i);
        }
    }

    //disable opengl window
    disableOpenGLWidget();

    TXTEdit_STDOUT->setText(tr2i18n("Launching FlightGear, please wait ..."));
    commandline->setUseShell(true,"/bin/sh");

    arguments = commandline->args();
    Args::iterator Iterator ;

    buffer="";
    for ( Iterator = arguments.begin() ; Iterator != arguments.end() ; ++Iterator )
    {
        buffer += (*Iterator)+" ";
    }
    if (verbose_app == true ) { TXTEdit_STDOUT->append(buffer); }

    //launch
    QApplication::connect(commandline, SIGNAL(receivedStdout(KProcess *, char *, int)),
        this, SLOT(fgfsStdoutSlot(KProcess *, char *, int)));
    QApplication::connect(commandline, SIGNAL(receivedStderr(KProcess *, char *, int)),
        this, SLOT(fgfsStdoutSlot(KProcess *, char *, int)));
    QApplication::connect(commandline, SIGNAL(processExited(KProcess *)),
        this, SLOT(writeFgfsOutputSlot(KProcess *)));

    if(commandline->start(KProcess::NotifyOnExit, KProcess::AllOutput))
    {
            commandline->resume();
            TXTEdit_STDOUT->append(tr2i18n("Process started"));
    }
    else
    {
            TXTEdit_STDOUT->append(tr2i18n("*** Error *** : process failed."));
    }
    if (flag_atlas) atlasSlot();
}

void KFreeFlight_view::fgfsStdoutSlot(KProcess *, char *b, int l)
{
    m_fgfsOutput->append(QString::fromLatin1(b,l));
}

void KFreeFlight_view::writeFgfsOutputSlot(KProcess *)
{
    m_config->reparseConfiguration();
    if (m_config->hasGroup("Settings General"))
    {
        m_config->setGroup("Settings General");
        if (m_config->readEntry("FGFS messages","false") == "true")
        {
            m_fgfsOutput->prepend("<p>");
            m_fgfsOutput->prepend(tr2i18n("<h3>FlightGear messages are :</h3>"));
            m_fgfsOutput->append("</p>");
            m_fgfsOutput->replace("\n","<br>");
            m_fgfsOutput->replace("<br><br>","<br>");
            m_fgfsOutput->simplifyWhiteSpace();
            TXTEdit_STDOUT->append(*m_fgfsOutput);
        }
    }
    enableOpenGLWidget();
    changePixmapSlot();
}

void KFreeFlight_view::changeAirportSlot ()
{
    int i;

    i=Table_Airport->currentRow();
    Table_Airport->selectRow(i);
    LE_Airport->setText(Table_Airport->text( i,0 ));
    LE_AddAirport_City->setText(Table_Airport->text( i,1 ));
    LE_Runway->clear();
    changeAirportInformations();
}

int KFreeFlight_view::loadAirportList()
{
    QString buffer, bufferBegin, bufferEnd;
    QTextStream stream;
    QFile file;
    int i;

    file.setName(QDir::homeDirPath ()+AppDirectory+AirportFile);
    if ( file.open( IO_ReadOnly ) ) 
    {
        stream.setDevice( &file );
        i=0;
        Table_Airport->setNumRows(0);
        while ( !stream.atEnd() ) 
        {
            buffer = stream.readLine();
            bufferBegin=buffer.section(' ',0,0).stripWhiteSpace();
            bufferEnd=buffer.section(' ',1).stripWhiteSpace();
            Table_Airport->insertRows(i, 1);
            Table_Airport->setText(i, 0, bufferBegin);
            Table_Airport->setText(i, 1, bufferEnd);
            i++;
        }
        file.close();
        return 0;
    }
    else return -1;
}

void KFreeFlight_view::getConfigFile()
{
    QString buffer;

    //m_config->reparseConfiguration();
    KConfig *m_configTmp = new KConfig("kfreeflightrc", false, true, "config");
    m_configTmp->setGroup("Config file");
    buffer=m_configTmp->readEntry("File", "default");
    delete m_configTmp;

    //delete m_config;
    m_config = new KConfig("kfreeflight/"+buffer, false, true, "config");
    TXTEdit_STDOUT->append(tr2i18n("New Config file:")+buffer);
}

void KFreeFlight_view::getAircraftListSlot()
{
 typedef QValueList<QCString> Args;

    Args arguments;
    KProcess *getAircraftList;
    QString buffer;
    KMessageBox *m_waitMessage;
    QDir *m_aircraftDir;

    m_config->setGroup("Settings FlightGear");
    buffer=m_config->readEntry("FG_ROOT", "undefined");

    if ((buffer == "") || (buffer == "undefined"))  return;
    buffer=buffer.append("/Aircraft");
    m_aircraftDir = new QDir(buffer);
    m_aircraftDir->setSorting( QDir::Name);
    m_aircraftDir->setFilter(QDir::Dirs);
    m_tmpAircraftList = new QString;
    m_aircraftDirectories = new QStringList();
    *m_aircraftDirectories = m_aircraftDir->entryList ( QDir::Dirs, QDir::Name);

    //creating list of aircraft 
    if (verbose_app == true ) TXTEdit_STDOUT->append(tr2i18n("Create aircraft list!"));

    if (notFirstAircraftFilling == true) 
    {
      m_waitMessage = new KMessageBox;
      m_waitMessage->setDontShowAskAgainConfig(m_config);
      m_waitMessage->information(this, tr2i18n(
        "Please wait during processing.\nIt may take a long time."),tr2i18n("Information"),
        tr2i18n("Don't show it again"),1);
    }
/* Insert new search function here
*/
    getAircraftList=new KProcess;

    m_config->setGroup("Settings FlightGear");

    buffer=m_config->readEntry("Executable", "fgfs");
    if (((buffer == "undefined") || (buffer == "")) && (notFirstDisplay == true))
    {
        buffer=tr2i18n("No FlightGear executable file selected");
        KMessageBox::sorry( this, buffer);
    }
    if ((buffer == "undefined") || (buffer == "")) buffer="fgfs";

    ComboBox_Aircraft->setMaxCount(-1);

    *getAircraftList << buffer;

    *getAircraftList << "--show-aircraft";

    buffer=m_config->readEntry("FG_ROOT", "undefined");
    buffer.stripWhiteSpace();
    if (((buffer == "undefined") || (buffer == "")) && (notFirstDisplay == true))
    {
        buffer=tr2i18n("No FlightGear root directory");
        KMessageBox::sorry( this, buffer);
    }
    if ((buffer != "undefined") && (buffer != "")) *getAircraftList << "--fg-root="+buffer;

    QApplication::connect(getAircraftList, SIGNAL(receivedStdout(KProcess *, char *, int)),
        this, SLOT(receiveAircraftListSlot(KProcess *, char *, int)));
    QApplication::connect(getAircraftList, SIGNAL(receivedStderr(KProcess *, char *, int)),
        this, SLOT(fgfsStdoutSlot(KProcess *, char *, int)));
    QApplication::connect(getAircraftList, SIGNAL(processExited(KProcess *)),
        this, SLOT(fillWidgetAircraftListSlot( KProcess *)));

    arguments = getAircraftList->args();
    Args::iterator Iterator ;

    buffer="";
    for ( Iterator = arguments.begin() ; Iterator != arguments.end() ; ++Iterator )
    {
        buffer += (*Iterator)+" ";
    }
    if (verbose_app == true ) { TXTEdit_STDOUT->append(buffer); }

    if(getAircraftList->start(KProcess::NotifyOnExit, KProcess::AllOutput))
    {
        notFirstAircraftFilling = true;
    }
    else
    {
        notFirstAircraftFilling = true;
        if (verbose_app == true )
        {
            TXTEdit_STDOUT->append(tr2i18n("*** Error *** : Can't create aircrafts list!")); 
            TXTEdit_STDOUT->append(tr2i18n("*** Error *** : Flightgear is not installed"));
            TXTEdit_STDOUT->append(tr2i18n("*** Error *** : or the path FG_ROOT is bad"));
        }
        ComboBox_Aircraft->insertItem("No Aircraft available");
    }
}

void KFreeFlight_view::receiveAircraftListSlot(KProcess *p, char *b, int l)
{
    m_tmpAircraftList->append(QString::fromLatin1(b,l));
}

void KFreeFlight_view::fillWidgetAircraftListSlot(KProcess *p)
{
    QString buffer, bufferBegin, bufferEnd;

    m_aircraftList = new QString();
    m_aircraftDescription = new QString();

    m_aircraftList = m_tmpAircraftList;
    m_aircraftList->stripWhiteSpace();
    m_aircraftList->replace("\n","<br>");

    ComboBox_Aircraft->setMaxCount(0);
    ComboBox_Aircraft->insertItem(tr2i18n("Available Aircraft"));

    for (int i=0 ; i <= m_aircraftList->contains("<br>")+2 ; i++)
    {
        buffer = m_aircraftList->section("<br>",i,i);
        bufferBegin = buffer.section(' ',2,3);
        m_aircraftDescription->append(buffer.section(' ',4).stripWhiteSpace()+"\n");
        if (bufferBegin.stripWhiteSpace() != "") { ComboBox_Aircraft->insertItem(bufferBegin); }
    }

    if (notFirstDisplay == true) 
    {
        ComboBox_Aircraft->setCurrentItem(0);
    }
    emit (aircraftComboBoxFully());

    //3D aircraft view
    //enableOpenGLWidget();
    changePixmapSlot();

    if (verbose_app == true ) 
        { TXTEdit_STDOUT->append(tr2i18n("*** Success *** : aircrafts list created!")); }
}

/*void KFreeFlight_view::getAircraftListSlot2()
{
    QStringList *m_aircraftTmpDirectory;
    QString buffer;
    QDir *m_aircraftFiles;

    for ( QStringList::Iterator it = m_aircraftDirectories->begin(); it != m_aircraftDirectories->end(); ++it )
    {
        if ((*it != ".") && (*it != "..") && (*it != "CVS" ))
        {
            m_aircraftTmpDirectory = new QStringList();
            *m_aircraftTmpDirectory = m_aircraftFiles->entryList ( QDir::Files, QDir::Name);
            for ( QStringList::Iterator it2 = m_aircraftDirectories->begin(); 
                it2 != m_aircraftDirectories->end(); ++it2 )
            {
                if ((*it2 != ".") && (*it2 != "..") && (*it2 != "CVS" ))
                {
                    buffer=*it2;
                    if (buffer.right(8) == "-set.xml")
                    {
                        buffer=buffer.remove("-set.xml").append("\n");
                        *m_aircraftList=m_aircraftList->append(buffer);
                    }
                }
            }
            delete m_aircraftTmpDirectory;
        }
    }
}*/

void KFreeFlight_view::changeSettingsFile()
{
    if(m_aircraftView != 0) disableOpenGLWidget();

    disableAllOptionsSlot();
    m_config->reparseConfiguration();
    getConfigFile();
    verboseSlot();
    getAircraftListSlot();
    applySettings();
    connect(this, SIGNAL(aircraftComboBoxFully()), this, SLOT(reloadSlot()) );
}

void KFreeFlight_view::changeNewFile()
{
    m_config->reparseConfiguration();
    getConfigFile();
    saveSlot();
    verboseSlot();
    if(m_weatherWindow != 0) { m_weatherWindow->close();m_weatherWindow=0; }
    if(m_airportWindow != 0) { m_airportWindow->close();m_airportWindow=0; }
}

void KFreeFlight_view::setServerSlot()
{
//pigeond
//mpserver02.flightgear.org:5002 (202.83.200.172)
//This is pigeons server, listening to port 5002 fg cvs
//listening to port 5000 fg v0.9.9
//Use "--multiplay=out,10,mpserver02.flightgear.org,5002" to connect to this server.
//This server is located in Hongkong/China.
//schroeder
//mpserver01.flightgear.org:5002 (85.214.36.1)
//This is flightbases server, listening to port 5002 fg cvs
//listening to port 5000 fg v0.9.9
//Use "--multiplay=out,10,mpserver01.flightgear.org,5002" to connect to this server.
//This server is located in Frankfurt/Germany.
//flamebunny
//flamebunny.homelinux.net:5002 (204.111.144.158)
//This is jpierrus server, listening to port 5002 fg cvs
//listening to port 5000 fg v0.9.9
//Use "--multiplay=out,10,flamebunny.homelinux.net,5002" to connect to this server.
//This server is located in Blacksburg/Virginia/USA.    
    switch(ComboBox_Server->currentItem())
    {
        case 1:
        {
            spinBoxAddressRange1out->setValue(202);
            spinBoxAddressRange2out->setValue(83);
            spinBoxAddressRange3out->setValue(200);
            spinBoxAddressRange4out->setValue(172);
            SpinBox_ServerPort->setValue(5000);
            LE_Server->setText("mpserver02.flightgear.org");
            break;
        }
        case 2:
        {
            spinBoxAddressRange1out->setValue(202);
            spinBoxAddressRange2out->setValue(83);
            spinBoxAddressRange3out->setValue(200);
            spinBoxAddressRange4out->setValue(172);
            SpinBox_ServerPort->setValue(5002);
            LE_Server->setText("mpserver02.flightgear.org");
            break;
        }
        case 3:
        {
            spinBoxAddressRange1out->setValue(85);
            spinBoxAddressRange2out->setValue(214);
            spinBoxAddressRange3out->setValue(36);
            spinBoxAddressRange4out->setValue(1);
            SpinBox_ServerPort->setValue(5000);
            LE_Server->setText("mpserver01.flightgear.org");
            break;
        }
        case 4:
        {

            spinBoxAddressRange1out->setValue(85);
            spinBoxAddressRange2out->setValue(214);
            spinBoxAddressRange3out->setValue(36);
            spinBoxAddressRange4out->setValue(1);
            SpinBox_ServerPort->setValue(5002);
            LE_Server->setText("mpserver01.flightgear.org");
            break;
        }
        case 5:
        {
            spinBoxAddressRange1out->setValue(204);
            spinBoxAddressRange2out->setValue(111);
            spinBoxAddressRange3out->setValue(144);
            spinBoxAddressRange4out->setValue(158);
            SpinBox_ServerPort->setValue(5000);
            LE_Server->setText("flamebunny.homelinux.net");
            break;
        }
        case 6:
        {
            spinBoxAddressRange1out->setValue(204);
            spinBoxAddressRange2out->setValue(111);
            spinBoxAddressRange3out->setValue(144);
            spinBoxAddressRange4out->setValue(158);
            SpinBox_ServerPort->setValue(5002);
            LE_Server->setText("flamebunny.homelinux.net");
            break;
        }
        default:
        {
            spinBoxAddressRange1out->setValue(127);
            spinBoxAddressRange2out->setValue(0);
            spinBoxAddressRange3out->setValue(0);
            spinBoxAddressRange4out->setValue(1);
            SpinBox_ServerPort->setValue(5000);
            LE_Server->setText("");
        }
    }
}

int KFreeFlight_view::createIniFiles( QString DestDirectory )
{
    QString FileToCreate, buffer;
    QStringList lines;
    int ReturnValue=0, i;
    QPixmap buf;
    QFile file;
    QDir tmp;
    QTextStream stream;

    //create weather directory
    buffer=DestDirectory+"Weather/";
    if (tmp.mkdir(buffer,true))
    {
        if (verbose_app == true ) 
            { TXTEdit_STDOUT->append(tr2i18n("Construction of directory :")+buffer);}
    }

    //create airport.dat and 7 files for airport informations
    for (i=0; i<=11; i++)
    {
        switch (i)
        {
            case 0:
                lines = "KSFO San Fransisco";
                lines << "LFML Marseille-Provence";
                lines << "LFTW Nimes-Garons";
                lines << "LFMV Avignon-Caumont";
                lines << "LFMT Montpellier-Mediterrannee";
                lines << "LFMP Perpignan-Rivesaltes";
                lines << "LFPG Paris-CDG";
                lines << "LFPO Paris-Orly";
                FileToCreate=AirportFile;
            break;
            case 1:
                lines = "28R";
                lines << "10L";
                lines << "28L";
                lines << "10R";
                lines << "1R";
                lines << "19L";
                lines << "1L";
                lines << "19R";
                FileToCreate="KSFO.dat";
                break;
            case 2:
                lines = "32R";
                lines << "14L";
                lines << "32L";
                lines << "14R";
                FileToCreate="LFML.dat";
                break;
            case 3:
                lines = "18";
                lines << "36";
                FileToCreate="LFTW.dat";
                break;
            case 4:
                lines = "35";
                lines << "17";
                FileToCreate="LFMV.dat";
                break;
            case 5:
                lines = "31R";
                lines << "13L";
                lines << "31L";
                lines << "13R";
                FileToCreate="LFMT.dat";
                break;
            case 6:
                lines = "15";
                lines << "33";
                lines << "13";
                lines << "31";
                FileToCreate="LFMP.dat";
                break;
            case 7:
                lines = "8L";
                lines << "26R";
                lines << "8R";
                lines << "26L";
                lines << "9R";
                lines << "27L";
                lines << "9L";
                lines << "27R";
                FileToCreate="LFPG.dat";
                break;
            case 8:
                lines = "8";
                lines << "26";
                lines << "6";
                lines << "24";
                lines << "2";
                lines << "20";
                FileToCreate="LFPO.dat";
                break;
            case 9:
                lines = "<p>TuxPlane.png have been modified.</p>";
                lines << "<p>The original tuxplane and all others pixmaps (execpt in general and weather tabs)";
                lines << "have been created ";
                lines << "by Bruno Coudoin using StarDraw and the Gimp from Staroffice gallery</p>";
                lines << "<p>Thanks Bruno.</p>";
                lines << "<p>In general and weather tabs, it's my screenshot of FlightGear.</p>";
                lines << "<p>In radio tab, the pixmap went to http://openclipart.org and"
                    " made by Mauro Olivo</p>";
                FileToCreate="README";
                break;
            case 10:
                lines = "LFML@0";
                lines << "MCE07@2000";
                lines << "ITR25@2000";
                lines << "MTG05@2000";
                lines << "MTG99@2000";
                lines << "LFML@0";
                FileToCreate="Promenade_marseille.txt";
                break;
            case 11:
                lines = "A380";
                lines << "MD11";
                lines << "FA-18";
                FileToCreate="aircraft.dat";
            default:
                lines = "";
                FileToCreate="";
        }

        file.setName(DestDirectory+FileToCreate);
        if ( file.open( IO_WriteOnly ) ) 
        {
            stream.setDevice( &file );
            for ( QStringList::Iterator it = lines.begin(); it != lines.end(); ++it )
            { stream << *it << "\n"; }
            file.close();
        }

        else { ReturnValue=-1; } //error
    }
    //save pixmap in the $ROOT/.fgLauncher directory
    buf.loadFromData( tuxaircraft, sizeof( tuxaircraft ), "PNG" );
    buf.save ( DestDirectory+"TuxPlane.png","PNG", 100 );

    return ReturnValue;
}
void KFreeFlight_view::fillObjects()
{
    QImage img,imageTux;
    img.loadFromData( tuxaircraft, sizeof( tuxaircraft ), "PNG" );
    imageTux=img;

    Table_Airport->setColumnWidth(0,60);
    Table_Airport->setColumnWidth(1,280);
    Table_Airport->horizontalHeader()->setLabel( 0, tr2i18n( "ID" ) );
    Table_Airport->horizontalHeader()->setLabel( 1, tr2i18n( "City" ) );
    Table_Runway->setColumnWidth(0,92);
    Table_Runway->horizontalHeader()->setLabel( 0, tr2i18n( "Runway" ) );

    //Aircraft
    kDoubleSpinBox_GPS_long->setRange(-179.999999, 180.0, 0.000001, FALSE);
    kDoubleSpinBox_GPS_lat->setRange(-179.999999, 180.0, 0.000001, FALSE);
    kDoubleSpinBox_COMM1->setPrecision( 3 );
    kDoubleSpinBox_COMM1->setMinValue( 108.0 );
    kDoubleSpinBox_COMM1->setMaxValue( 129.975 );
    kDoubleSpinBox_COMM1->setLineStep(0.025);
    kDoubleSpinBox_COMM1->setValue( 108.325 );


    //Radio
    kDoubleSpinBox_NAV1->setPrecision( 3 );
    kDoubleSpinBox_NAV1->setMinValue( 108.0 );
    kDoubleSpinBox_NAV1->setMaxValue( 117.975 );
    kDoubleSpinBox_NAV1->setLineStep(0.025);
    kDoubleSpinBox_NAV1->setValue( 108.000 );
    kDoubleSpinBox_NAV1standby->setPrecision( 3 );
    kDoubleSpinBox_NAV1standby->setMinValue( 108.0 );
    kDoubleSpinBox_NAV1standby->setMaxValue( 117.975 );
    kDoubleSpinBox_NAV1standby->setLineStep(0.025);
    kDoubleSpinBox_NAV1standby->setValue( 108.000 );
    kDoubleSpinBox_NAV2->setPrecision( 3 );
    kDoubleSpinBox_NAV2->setMinValue( 108.0 );
    kDoubleSpinBox_NAV2->setMaxValue( 117.975 );
    kDoubleSpinBox_NAV2->setLineStep(0.025);
    kDoubleSpinBox_NAV2->setValue( 108.000 );
    kDoubleSpinBox_NAV2standby->setPrecision( 3 );
    kDoubleSpinBox_NAV2standby->setMinValue( 108.0 );
    kDoubleSpinBox_NAV2standby->setMaxValue( 117.975 );
    kDoubleSpinBox_NAV2standby->setLineStep(0.025);
    kDoubleSpinBox_NAV2standby->setValue( 108.000 );
    kDoubleSpinBox_DME->setEnabled(false);

    //Comm
    kDoubleSpinBox_COMM1->setPrecision( 3 );
    kDoubleSpinBox_COMM1->setMinValue( 108.0 );
    kDoubleSpinBox_COMM1->setMaxValue( 129.975 );
    kDoubleSpinBox_COMM1->setLineStep(0.025);
    kDoubleSpinBox_COMM1->setValue( 108.325 );
    kDoubleSpinBox_COMM1standby->setPrecision( 3 );
    kDoubleSpinBox_COMM1standby->setMinValue( 108.0 );
    kDoubleSpinBox_COMM1standby->setMaxValue( 129.975 );
    kDoubleSpinBox_COMM1standby->setLineStep(0.025);
    kDoubleSpinBox_COMM1standby->setValue( 108.325 );
    kDoubleSpinBox_COMM2->setPrecision( 3 );
    kDoubleSpinBox_COMM2->setMinValue( 108.0 );
    kDoubleSpinBox_COMM2->setMaxValue( 129.975 );
    kDoubleSpinBox_COMM2->setLineStep(0.025);
    kDoubleSpinBox_COMM2->setValue( 108.325 );
    kDoubleSpinBox_COMM2standby->setPrecision( 3 );
    kDoubleSpinBox_COMM2standby->setMinValue( 108.0 );
    kDoubleSpinBox_COMM2standby->setMaxValue( 129.975 );
    kDoubleSpinBox_COMM2standby->setLineStep(0.025);
    kDoubleSpinBox_COMM2standby->setValue( 108.325 );
    kDoubleSpinBox_DME->setPrecision( 3 );
    kDoubleSpinBox_DME->setMinValue( 108.0 );
    kDoubleSpinBox_DME->setMaxValue( 129.975 );
    kDoubleSpinBox_DME->setLineStep(0.025);
    kDoubleSpinBox_DME->setValue( 108.325 );

    //Network
    LE_FindFile->setText(QDir::homeDirPath ()+"/.kfreeflight/promenade_marseille.txt");
}

void KFreeFlight_view::alertScreenSlot()
{
    QString buffer;

    if (ComboBox_Resolution->currentItem() > 2)
    {
        buffer=tr2i18n("This screen resolution:")+buffer
            +" "+tr2i18n("may be not supported by FlightGear");
        TXTEdit_STDOUT->append(buffer);
        if(!CB_DisableWarning->isChecked())
        {
            KMessageBox::sorry( this, buffer );
        }

    }
}

void KFreeFlight_view::applySettings()
{
    QString buffer, buf1, buf2, buf3;
    int r, g, b;

    m_appForegroundColor = new QColor();
    m_appBackgroundColor = new QColor();
    m_appEditColor = new QColor();
    m_appOpenGLColor = new QColor();
    m_appFont = new QFont;

    m_config->reparseConfiguration();

    if (m_config->hasGroup("Settings Font"))
    {
        m_config->setGroup("Settings Font");
        buffer=m_config->readEntry("Family","Bitstream Vera Sans");
        m_appFont->setFamily(buffer);
        buffer=m_config->readEntry("PointSize","12");
        m_appFont->setPointSize( buffer.toInt() );
        buffer=m_config->readEntry("bold","false");
        if (buffer == "1") m_appFont->setBold( TRUE );
        if (buffer == "0") m_appFont->setBold( FALSE );
        buffer=m_config->readEntry("italic","false");
        if (buffer == "1") m_appFont->setItalic( TRUE );
        if (buffer == "0") m_appFont->setItalic( FALSE );
    }

    if (m_config->hasGroup("Settings Color"))
    {
        m_config->setGroup("Settings Color");

        buffer=m_config->readEntry("ForegroundColor", "0,0,0");
        buf1=buffer; buf2=buffer; buf3=buffer;
        r=buf1.section(',',0,0).toInt();
        g=buf2.section(',',1,1).toInt();
        b=buf3.section(',',2,2).toInt();
        m_appForegroundColor->setRgb(r, g, b);

        buffer=m_config->readEntry("BackgroundColor", "255,255,255");
        buf1=buffer; buf2=buffer; buf3=buffer;
        r=buf1.section(',',0,0).toInt();
        g=buf2.section(',',1,1).toInt();
        b=buf3.section(',',2,2).toInt();
        m_appBackgroundColor->setRgb(r, g, b);

        buffer=m_config->readEntry("EditColor", "210,210,210");
        buf1=buffer; buf2=buffer; buf3=buffer;
        r=buf1.section(',',0,0).toInt();
        g=buf2.section(',',1,1).toInt();
        b=buf3.section(',',2,2).toInt();
        m_appEditColor->setRgb(r, g, b);

        buffer=m_config->readEntry("OpenGL Color", "23,64,105");
        buf1=buffer; buf2=buffer; buf3=buffer;
        r=buf1.section(',',0,0).toInt();
        g=buf2.section(',',1,1).toInt();
        b=buf3.section(',',2,2).toInt();
        m_appOpenGLColor->setRgb(r, g, b);
    }

    if(m_weatherWindow != 0)
    {
        m_weatherWindow->m_font = m_appFont;
        m_weatherWindow->m_foreground = m_appForegroundColor;
        m_weatherWindow->m_background = m_appBackgroundColor;
        m_weatherWindow->m_edit = m_appEditColor;
        m_weatherWindow->m_config = m_config;
        m_weatherWindow->applySettings();
    }
    if(m_airportWindow != 0)
    {
        m_airportWindow->m_font = m_appFont;
        m_airportWindow->m_foreground = m_appForegroundColor;
        m_airportWindow->m_background = m_appBackgroundColor;
        m_airportWindow->m_edit = m_appEditColor;
        m_airportWindow->m_config = m_config;
        m_airportWindow->applySettings();
    }
    if(m_aircraftView != 0)
    {
        m_aircraftView->m_backgroundColor = m_appBackgroundColor;
    }
     //changeSettingsFile() TODO

    setFont( *m_appFont );
    setPaletteForegroundColor( *m_appForegroundColor );

//FOREGROUND
    //buttons and TextEdit
    BTN_Launch->setPaletteForegroundColor( *m_appForegroundColor );
    BTN_Quit->setPaletteForegroundColor( *m_appForegroundColor );
    TXTEdit_STDOUT->setPaletteForegroundColor( *m_appEditColor );
    ComboBox_Resolution->setPaletteForegroundColor( *m_appForegroundColor );
    ComboBox_Resolution_bpp->setPaletteForegroundColor( *m_appForegroundColor );

    //Airport
    BTN_Airport_Info->setPaletteForegroundColor( *m_appForegroundColor );
    BTN_Airport_Info->setPaletteForegroundColor( *m_appForegroundColor );
    BTN_Airport_Add->setPaletteForegroundColor( *m_appForegroundColor );
    BTN_Airport_Del->setPaletteForegroundColor( *m_appForegroundColor );
    BTN_Runway_Add->setPaletteForegroundColor( *m_appForegroundColor );
    BTN_Runway_Del->setPaletteForegroundColor( *m_appForegroundColor );
    BTN_FindAirport->setPaletteForegroundColor( *m_appForegroundColor );
    Table_Airport->setPaletteForegroundColor( *m_appEditColor );
    Table_Runway->setPaletteForegroundColor( *m_appEditColor );
    LE_Airport->setPaletteForegroundColor( *m_appEditColor );
    LE_AddAirport_City->setPaletteForegroundColor( *m_appEditColor );
    LE_Runway->setPaletteForegroundColor( *m_appEditColor );

    //Carrier
    LE_CarrierProp->setPaletteForegroundColor( *m_appEditColor );
    LE_CarrierStart->setPaletteForegroundColor( *m_appEditColor );
    LE_CarrierName->setPaletteForegroundColor( *m_appEditColor );

    //Aircraft
    SpinBox_Altitude->setPaletteForegroundColor( *m_appEditColor );
    SpinBox_Speed->setPaletteForegroundColor( *m_appEditColor );
    ComboBox_Aircraft->setPaletteForegroundColor( *m_appForegroundColor  );
    kDoubleSpinBox_GPS_long->setPaletteForegroundColor( *m_appEditColor );
    kDoubleSpinBox_GPS_lat->setPaletteForegroundColor( *m_appEditColor );
    SpinBox_Heading->setPaletteForegroundColor( *m_appEditColor );
    BTN_LoadModel->setPaletteForegroundColor( *m_appForegroundColor  );
    BTN_RefreshAircraftList->setPaletteForegroundColor( *m_appForegroundColor );

    //Time
    ComboBox_Time->setPaletteForegroundColor( *m_appForegroundColor );
    ComboBox_Season->setPaletteForegroundColor( *m_appForegroundColor );


    //Weather
    BTN_GetWeather->setPaletteForegroundColor( *m_appForegroundColor );
    SpinBox_DirectionWind->setPaletteForegroundColor( *m_appEditColor );
    SpinBox_SpeedWind->setPaletteForegroundColor( *m_appEditColor );
    SpinBox_Visibility->setPaletteForegroundColor( *m_appEditColor );

    //Radio
    kDoubleSpinBox_NAV1->setPaletteForegroundColor( *m_appEditColor );
    kDoubleSpinBox_NAV1standby->setPaletteForegroundColor( *m_appEditColor );
    kDoubleSpinBox_NAV2->setPaletteForegroundColor( *m_appEditColor );
    kDoubleSpinBox_NAV2standby->setPaletteForegroundColor( *m_appEditColor );
    kDoubleSpinBox_DME->setPaletteForegroundColor( *m_appEditColor );
    SpinBox_adf->setPaletteForegroundColor( *m_appEditColor );
    SpinBox_adfstandby->setPaletteForegroundColor( *m_appEditColor );
    SpinBox_nav1_rad->setPaletteForegroundColor( *m_appEditColor );
    SpinBox_nav2_rad->setPaletteForegroundColor( *m_appEditColor );
    SpinBox_adf_rot->setPaletteForegroundColor( *m_appEditColor );
    SpinBox_TACAN1->setPaletteForegroundColor( *m_appEditColor );
    SpinBox_TACAN2->setPaletteForegroundColor( *m_appEditColor );
    SpinBox_TACAN3->setPaletteForegroundColor( *m_appEditColor );

    //Comm
    kDoubleSpinBox_COMM1->setPaletteForegroundColor( *m_appEditColor );
    kDoubleSpinBox_COMM1standby->setPaletteForegroundColor( *m_appEditColor );
    kDoubleSpinBox_COMM2->setPaletteForegroundColor( *m_appEditColor );
    kDoubleSpinBox_COMM2standby->setPaletteForegroundColor( *m_appEditColor );

    //Network
    SpinBox_Player->setPaletteForegroundColor( *m_appEditColor );
    SpinBox_Hz->setPaletteForegroundColor( *m_appEditColor );
    spinBoxAddressRange1->setPaletteForegroundColor( *m_appEditColor );
    spinBoxAddressRange2->setPaletteForegroundColor( *m_appEditColor );
    spinBoxAddressRange3->setPaletteForegroundColor( *m_appEditColor );
    spinBoxAddressRange4->setPaletteForegroundColor( *m_appEditColor );
    spinBoxAddressRange1out->setPaletteForegroundColor( *m_appEditColor );
    spinBoxAddressRange2out->setPaletteForegroundColor( *m_appEditColor );
    spinBoxAddressRange3out->setPaletteForegroundColor( *m_appEditColor );
    spinBoxAddressRange4out->setPaletteForegroundColor( *m_appEditColor );
    LE_callsign->setPaletteForegroundColor( *m_appEditColor );
    SpinBox_ServerPort->setPaletteForegroundColor( *m_appEditColor );
    LE_Point1->setPaletteForegroundColor( *m_appEditColor );
    LE_Point2->setPaletteForegroundColor( *m_appEditColor );
    LE_Point3->setPaletteForegroundColor( *m_appEditColor );
    LE_Point1out->setPaletteForegroundColor( *m_appEditColor );
    LE_Point2out->setPaletteForegroundColor( *m_appEditColor );
    LE_Point3out->setPaletteForegroundColor( *m_appEditColor );
    ComboBox_Server->setPaletteForegroundColor( *m_appForegroundColor );
    LE_Server->setPaletteForegroundColor( *m_appEditColor );

    //Flight plan
    BTN_WayPoint_Add->setPaletteForegroundColor( *m_appForegroundColor );
    BTN_WayPoint_Help->setPaletteForegroundColor( *m_appForegroundColor );
    BTN_WayPoint_Delete->setPaletteForegroundColor( *m_appForegroundColor );
    BTN_WayPoint_Save->setPaletteForegroundColor( *m_appForegroundColor );
    BTN_WayPoint_Atlas->setPaletteForegroundColor( *m_appForegroundColor );
    LE_FindFile->setPaletteForegroundColor( *m_appEditColor );
    ListBox_WayPoint->setPaletteForegroundColor( *m_appEditColor );
    SpinBox_WayPoint_Altitude->setPaletteForegroundColor( *m_appEditColor );
    LE_Waypoint_ID->setPaletteForegroundColor( *m_appEditColor );

//$BACKGROUND$
    TXTEdit_STDOUT->setPaletteBackgroundColor( *m_appBackgroundColor );
    Table_Airport->setPaletteBackgroundColor( *m_appBackgroundColor );
    Table_Runway->setPaletteBackgroundColor( *m_appBackgroundColor );
    LE_Airport->setPaletteBackgroundColor( *m_appBackgroundColor );
    LE_AddAirport_City->setPaletteBackgroundColor( *m_appBackgroundColor );
    LE_Runway->setPaletteBackgroundColor( *m_appBackgroundColor );
    SpinBox_Altitude->setPaletteBackgroundColor( *m_appBackgroundColor );
    SpinBox_Speed->setPaletteBackgroundColor( *m_appBackgroundColor );
    SpinBox_DirectionWind->setPaletteBackgroundColor( *m_appBackgroundColor );
    SpinBox_SpeedWind->setPaletteBackgroundColor( *m_appBackgroundColor );
    SpinBox_Visibility->setPaletteBackgroundColor( *m_appBackgroundColor );
    LE_FindFile->setPaletteBackgroundColor( *m_appBackgroundColor );
    ListBox_WayPoint->setPaletteBackgroundColor( *m_appBackgroundColor );
    SpinBox_WayPoint_Altitude->setPaletteBackgroundColor( *m_appBackgroundColor );
    LE_Waypoint_ID->setPaletteBackgroundColor( *m_appBackgroundColor );
    spinBoxAddressRange1->setPaletteBackgroundColor( *m_appBackgroundColor );
    spinBoxAddressRange2->setPaletteBackgroundColor( *m_appBackgroundColor );
    spinBoxAddressRange3->setPaletteBackgroundColor( *m_appBackgroundColor );
    spinBoxAddressRange4->setPaletteBackgroundColor( *m_appBackgroundColor );
    spinBoxAddressRange1out->setPaletteBackgroundColor( *m_appBackgroundColor );
    spinBoxAddressRange2out->setPaletteBackgroundColor( *m_appBackgroundColor );
    spinBoxAddressRange3out->setPaletteBackgroundColor( *m_appBackgroundColor );
    spinBoxAddressRange4out->setPaletteBackgroundColor( *m_appBackgroundColor );
    LE_callsign->setPaletteBackgroundColor( *m_appBackgroundColor );
    LE_Server->setPaletteBackgroundColor( *m_appBackgroundColor );
    SpinBox_ServerPort->setPaletteBackgroundColor( *m_appBackgroundColor );
    SpinBox_Player->setPaletteBackgroundColor( *m_appBackgroundColor );
    SpinBox_Hz->setPaletteBackgroundColor( *m_appBackgroundColor );
    LE_Point1->setPaletteBackgroundColor( *m_appBackgroundColor );
    LE_Point2->setPaletteBackgroundColor( *m_appBackgroundColor );
    LE_Point3->setPaletteBackgroundColor( *m_appBackgroundColor );
    LE_Point1out->setPaletteBackgroundColor( *m_appBackgroundColor );
    LE_Point2out->setPaletteBackgroundColor( *m_appBackgroundColor );
    LE_Point3out->setPaletteBackgroundColor( *m_appBackgroundColor );
    LE_CarrierName->setPaletteBackgroundColor( *m_appBackgroundColor );
    LE_CarrierStart->setPaletteBackgroundColor( *m_appBackgroundColor );
    LE_CarrierProp->setPaletteBackgroundColor( *m_appBackgroundColor );
    kDoubleSpinBox_GPS_long->setPaletteBackgroundColor( *m_appBackgroundColor );
    kDoubleSpinBox_GPS_lat->setPaletteBackgroundColor( *m_appBackgroundColor );
    SpinBox_Heading->setPaletteBackgroundColor( *m_appBackgroundColor );
    kDoubleSpinBox_COMM1->setPaletteBackgroundColor( *m_appBackgroundColor );
    kDoubleSpinBox_COMM1standby->setPaletteBackgroundColor( *m_appBackgroundColor );
    kDoubleSpinBox_COMM2->setPaletteBackgroundColor( *m_appBackgroundColor );
    kDoubleSpinBox_COMM2standby->setPaletteBackgroundColor( *m_appBackgroundColor );
    kDoubleSpinBox_NAV1->setPaletteBackgroundColor( *m_appBackgroundColor );
    kDoubleSpinBox_NAV1standby->setPaletteBackgroundColor( *m_appBackgroundColor );
    kDoubleSpinBox_NAV2->setPaletteBackgroundColor( *m_appBackgroundColor );
    kDoubleSpinBox_NAV2standby->setPaletteBackgroundColor( *m_appBackgroundColor );
    kDoubleSpinBox_DME->setPaletteBackgroundColor( *m_appBackgroundColor );
    SpinBox_adf->setPaletteBackgroundColor( *m_appBackgroundColor );
    SpinBox_adfstandby->setPaletteBackgroundColor( *m_appBackgroundColor );
    SpinBox_nav1_rad->setPaletteBackgroundColor( *m_appBackgroundColor );
    SpinBox_nav2_rad->setPaletteBackgroundColor( *m_appBackgroundColor );
    SpinBox_adf_rot->setPaletteBackgroundColor( *m_appBackgroundColor );
    SpinBox_TACAN1->setPaletteBackgroundColor( *m_appBackgroundColor );
    SpinBox_TACAN2->setPaletteBackgroundColor( *m_appBackgroundColor );
    SpinBox_TACAN3->setPaletteBackgroundColor( *m_appBackgroundColor );

    verboseSlot();

}

void KFreeFlight_view::getAirportInformationSlot()
{
    m_airportWindow = new Airport_view(0, "airport", 0, LE_Airport->text().upper().stripWhiteSpace());

    m_airportWindow->m_font = m_appFont;
    m_airportWindow->m_foreground = m_appForegroundColor;
    m_airportWindow->m_background = m_appBackgroundColor;
    m_airportWindow->m_edit = m_appEditColor;
    m_airportWindow->m_config = m_config;
    m_airportWindow->applySettings();
    m_airportWindow->show();
}

void KFreeFlight_view::aircraftViewEmptySlot()
{
    disableOpenGLWidget();
    enableOpenGLWidget();
    aircraftViewSlot(QString::null, QString::null);
}

void KFreeFlight_view::aircraftViewSlot(const QString aircraftAcFile, const QString textureAircraftPath )
{
    QString aircraft, texture, fgroot;

    if(m_aircraftSpinTimer != 0)
    {
        m_aircraftSpinTimer->stop();
        disconnect(m_aircraftSpinTimer);
        delete m_aircraftSpinTimer;
    }

    m_aircraftSpinTimer = new QTimer();
    m_config->setGroup("Settings FlightGear");
    fgroot=m_config->readEntry("FG_ROOT", "undefined");
    fgroot.append("/Aircraft/");
    if (aircraftAcFile.isNull())
    {
        aircraft = m_fileDlg->getOpenFileName (fgroot,
            "*.ac|ACAD file(*.ac)\n*.mdl|imported FS file(*.mdl)\n*.3ds|gmax file(*.3ds)\n*|all files",
            this,  tr2i18n("Aircraft" ));
            if(aircraft=="") return;
        texture = aircraft;
        texture=texture.remove(aircraft.section('/',-1));
        texture = m_fileDlg->getExistingDirectory(texture, this,tr2i18n("Textures Directory" ));
        *m_aircraftModel = aircraft;
        *m_aircraftTexturePath = texture;
        TXTEdit_STDOUT->append(tr2i18n("Load Model")+" : "+aircraft);
    }
    else
    {
        if (aircraftAcFile.left(1) == "/")
        {
            aircraft = aircraftAcFile;
            texture = textureAircraftPath;
        }
        else
        {
            aircraft = aircraftAcFile;
            aircraft = aircraft.prepend(fgroot);
            texture = textureAircraftPath;
            texture = texture.prepend(fgroot);
        }
    }
    if (aircraft == "" || texture == "") { return; }
    //else

    //m_aircraftView->clear(); //too dangerous at this point
    m_aircraftView->loadAircraft( aircraft, texture);

    m_aircraftSpinTimer->start(50,false);
    connect(m_aircraftSpinTimer, SIGNAL(timeout()), m_aircraftView, SLOT(updateView()));
}

void KFreeFlight_view::aircraftViewXmlSlot( const QString aircraftXmlFile, bool animStart )
{
    QString aircraft, fgroot;

    if(m_aircraftSpinTimer != 0)
    {
        m_aircraftSpinTimer->stop();
        disconnect(m_aircraftSpinTimer);
        delete m_aircraftSpinTimer;
    }

    m_aircraftSpinTimer = new QTimer();
    m_config->setGroup("Settings FlightGear");
    fgroot=m_config->readEntry("FG_ROOT", "undefined");

    if (aircraftXmlFile.isNull())
    {
        aircraft = m_fileDlg->getOpenFileName (fgroot,
            "*.xml|XML file(*.xml)\n*|all files",
            this,  tr2i18n("Aircraft" ));
            if(aircraft=="") return;
        *m_aircraftModel = aircraft;
    }
    else
    {
        aircraft = aircraftXmlFile;
    }
    if (aircraft == "" ) { return; }
    //else

    //m_aircraftView->clear(); //too dangerous at this point
    m_aircraftView->loadAircraftXml( fgroot, aircraft);

    if (animStart == true)
    {
        m_aircraftSpinTimer->start(50,false);
        connect(m_aircraftSpinTimer, SIGNAL(timeout()), m_aircraftView, SLOT(updateView()));
    }
    else
    {
        //m_aircraftSpinTimer->start(1000,false);
        //connect(m_aircraftSpinTimer, SIGNAL(timeout()), m_aircraftView, SLOT(updateView()));
    }

}

QString KFreeFlight_view::getAircraftDirectory(QString pathAircraft)
{
    QString currentAircraft, returnString;
    QFile file;

    returnString="xxx";
    currentAircraft = ComboBox_Aircraft->currentText().stripWhiteSpace()+"-set.xml";
    file.setName(currentAircraft);
    for ( QStringList::Iterator it = m_aircraftDirectories->begin(); it != m_aircraftDirectories->end(); ++it )
    {
        if ((*it != ".") && (*it != "..") && (*it != "CVS" ))
        {
            file.setName(pathAircraft+"/"+*it+"/"+currentAircraft);
            if ( file.exists() ) { returnString = *it; }
        }
    }
    return returnString;
}

void KFreeFlight_view::enableOpenGLWidget()
{
    if (openglEnabled == false)
    {
        m_aircraftView = new Aircraft_view(GrBox_GL, "Aircraft");
        m_aircraftView->setGeometry(5,5,400,270);
        m_aircraftView->m_backgroundColor = m_appOpenGLColor;
        //m_aircraftView->m_font = m_appFont;
        m_aircraftView->m_foregroundColor = m_appEditColor;
        *m_aircraftView->m_aircraftName = " "+
            m_aircraftDescription->section('\n',ComboBox_Aircraft->currentItem(),
            ComboBox_Aircraft->currentItem());
        m_aircraftView->show();
        QToolTip::add( m_aircraftView, ComboBox_Aircraft->currentText() +" : "+
            m_aircraftDescription->section('\n',ComboBox_Aircraft->currentItem(), 
            ComboBox_Aircraft->currentItem()) +"\n\n" + *m_aircraftToolTip );
        QWhatsThis::add( m_aircraftView, tr2i18n("This is the Render model window"));
        m_aircraftView->initPlib();
        openglEnabled=true;
    }
}

void KFreeFlight_view::disableOpenGLWidget()
{
    if (m_aircraftSpinTimer != 0)
    {
        m_aircraftSpinTimer->stop();
        delete m_aircraftSpinTimer;
        m_aircraftSpinTimer=0;
    }
    if (openglEnabled == true)
    {
        m_aircraftView->clear();
        delete m_aircraftView;
        openglEnabled=false;
        m_aircraftView=0;
        openglEnabled=false;
        //enablePixmapLabelWidget();
    }
}

/*void KFreeFlight_view::enablePixmapLabelWidget()
{
    QPixmap thumbnail;
    QString buffer, fgroot, Aircraft;
    QFile file;


    if(m_aircraftPixmapView) delete m_aircraftPixmapView;
    m_aircraftPixmapView = new QLabel(GrBox_GL, "PixmapAircraft");
    m_aircraftPixmapView->setGeometry(25,5,360,270);
    m_aircraftPixmapView->setScaledContents(true);
    m_aircraftPixmapView->setBackgroundColor(*m_appBackgroundColor);
    thumbnail.loadFromData( tuxaircraft, sizeof( tuxaircraft ), "PNG" );
    m_aircraftPixmapView->setPixmap(thumbnail);
    m_config->setGroup("Settings FlightGear");
    buffer=m_config->readEntry("FG_ROOT", "undefined");
    if ((buffer == "") || (buffer == "undefined"))  return;
    fgroot=buffer;

    Aircraft=ComboBox_Aircraft->currentText().stripWhiteSpace();
    if (verbose_app == true )
                { TXTEdit_STDOUT->append(tr2i18n("Change thumbnail aircraft with current aircraft")); }

    buffer=fgroot.stripWhiteSpace()+"/Aircraft/";
    buffer = buffer.replace("//","/");

    buffer=buffer.append(getAircraftDirectory(buffer.remove('\n'))+"/"+
        ComboBox_Aircraft->currentText().stripWhiteSpace()+"-set.xml");
    TXTEdit_STDOUT->append(buffer);
    file.setName(buffer);
    if (!file.open(IO_ReadOnly))
    {
        *m_aircraftModel="undefined";
        if (notFirstDisplay == true)
        {
            TXTEdit_STDOUT->append(tr2i18n("No model found for this aircraft :")+Aircraft);
            thumbnail.loadFromData( tuxaircraft, sizeof( tuxaircraft ), "PNG" );
            m_aircraftPixmapView->setPixmap(thumbnail);
        }
        return;
    }
    file.close();
    Aircraft=fgroot.stripWhiteSpace()+"/Aircraft/"+Aircraft+"/thumbnail.jpg";
    if (verbose_app == true ) { TXTEdit_STDOUT->append(tr2i18n("try :")+Aircraft); }

    file.setName(Aircraft);
    if ( file.open( IO_ReadOnly ) ) 
    {
        file.close();
        thumbnail.load(Aircraft, 0, 0);
        m_aircraftPixmapView->setPixmap(thumbnail);
        if (verbose_app == true ) TXTEdit_STDOUT->append(tr2i18n("*** Success ***"));
    }
}

void KFreeFlight_view::disablePixmapLabelWidget()
{
}*/

QString KFreeFlight_view::searchInXMLFile(QString fileName, QString nodeString)
{
    QString buffer=QString::null;

    SGPropertyNode propNode;
    readProperties( fileName.ascii(),  &propNode);
    if (propNode.hasValue( nodeString.ascii() ))
    {
        buffer=propNode.getStringValue( nodeString.ascii() );
        if (buffer == "") buffer=QString::null;
        return buffer;
    }
    else {return buffer=QString::null;}
}

#include "kfreeflight_view.moc"

