/***************************************************************************
 *   KFreeFlight : a FlightGear GUI-Frontend designed for KDE users        *
 *                                                                         *
 *   Copyright (C) 2006 by Didier Fabert                                   *
 *   [didier.fabert AT free.fr]                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef KFREEFLIGHT_VIEW_H
#define KFREEFLIGHT_VIEW_H

#include <kapplication.h>
#include <kprocess.h>
#include <klocale.h>
#include <knuminput.h>
#include <kconfig.h>
#include <kstandarddirs.h>
#include <kmessagebox.h>
#include <kfiledialog.h>

#include <qapplication.h>
#include <qmessagebox.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qradiobutton.h>
#include <qtextedit.h>
#include <qlistbox.h>
#include <qcheckbox.h>
#include <qcombobox.h>
#include <qpixmap.h>
#include <qimage.h>
#include <qpushbutton.h>
#include <qstring.h>
#include <qstringlist.h>
#include <qslider.h>
#include <qvaluelist.h>
#include <qcstring.h>
#include <qgroupbox.h>
#include <qbuttongroup.h>
#include <qspinbox.h> 
#include <qdatetimeedit.h>
#include <qdatetime.h>
#include <qtable.h>
#include <qtoolbox.h>
#include <qwhatsthis.h>
#include <qtabwidget.h>
#include <qdir.h>
#include <qtextstream.h>
#include <qfile.h>
#include <qtooltip.h>

#include "const.h"
#include "app_img.h"
#include "mainwindow.h"
#include "weather_view.h"
#include "airport_view.h"
#include "aircraft_view.h"

#include <simgear/props/props_io.hxx>
#include <simgear/structure/exception.hxx>
#include <simgear/misc/sg_path.hxx>
#include <stdio.h>
#include <vector>
#include <map>
#include <string>

class KFreeFlight_view : public mymainwindow
{
  Q_OBJECT

public:
  KFreeFlight_view(QWidget* parent = 0, const char* name = 0, WFlags fl = 0);

  KConfig *m_config;
  QFont *m_appFont;
  QColor *m_appForegroundColor, *m_appBackgroundColor, *m_appEditColor, *m_appOpenGLColor;
  QString *m_destDirectory, *m_fgfsOutput, *m_tmpAircraftList, *m_aircraftList;
  QString *m_aircraftDescription, *m_aircraftModel, *m_aircraftTexturePath, *m_aircraftToolTip;
  Weather_view *m_weatherWindow;
  Airport_view *m_airportWindow;
  QStringList *m_pid;
  Aircraft_view *m_aircraftView;
  QLabel *m_aircraftPixmapView;
  QStringList *m_aircraftDirectories;
  QStringList *m_loadBySimgear;

  ~KFreeFlight_view();
  /*$PUBLIC_FUNCTIONS$*/

public slots:
  /*$PUBLIC_SLOTS$*/
  virtual void alertScreenSlot();
  virtual void dmeDefreezeSlot();
  virtual void dmeFreezeSlot();
  virtual void runwayAddSlot();
  virtual void runwayDelSlot();
  virtual void airportDelSlot();
  virtual void airportAddSlot();
  virtual void wayPointDefreezeEditSlot();
  virtual void wayPointDefreezeFileSlot();
  virtual void atlasSlot();
  virtual void wayPointSaveSlot();
  virtual void wayPointHelpSlot();
  virtual void wayPointDeleteSlot();
  virtual void wayPointFreezeAllSlot();
  virtual void findFlightPlanFileSlot();
  virtual void runwaySlot();
  virtual void verboseSlot();
  virtual void changePixmapSlot();
  virtual void getAirportWebInfoSlot();
  virtual void getAirportWeatherSlot();
  virtual void startPositionSlot();
  virtual void defreezeTimeOfDaySlot();
  virtual void changeAirportSlot();
  virtual void defreezeTimeEditSlot();
  virtual void wayPointAddSlot();
  virtual void quitSlot();
  virtual void freezeTimeSlot();
  virtual void reloadSlot();
  virtual void saveSlot();
  virtual void launchFlightgearSlot();
  virtual void freezeCarrierStartEditSlot();
  virtual void defreezeCarrierStartEditSlot();
  virtual void applySettings();
  virtual void getConfigFile();
  virtual void getAircraftListSlot();
  virtual void receiveAircraftListSlot(KProcess *p, char *b, int l );
  virtual void fillWidgetAircraftListSlot(KProcess *p);
  virtual void defreezeMultiplayerInternetSlot();
  virtual void defreezeMultiplayerLocalSlot();
  virtual void freezeMultiplayerSlot();
  virtual void setServerSlot();
  virtual void changeSettingsFile();
  virtual void changeNewFile();
  virtual void fgfsStdoutSlot(KProcess *, char *b, int l);
  virtual void writeFgfsOutputSlot(KProcess *);
  virtual void getAirportInformationSlot();
  virtual void receivePID(KProcess *, char *b, int l);
  virtual void aircraftViewEmptySlot();
  virtual void aircraftViewSlot(const QString aircraftAcFile = QString::null,
    const QString textureAircraftPath = QString::null);
  virtual void aircraftViewXmlSlot(const QString aircraftXmlFile = QString::null, bool animStart = true );
  virtual QString getAircraftDirectory(QString pathAircraft);
  virtual void enableOpenGLWidget();
  virtual void disableOpenGLWidget();
  //virtual void enablePixmapLabelWidget();
  //virtual void disablePixmapLabelWidget();
  virtual QString searchInXMLFile(QString fileName, QString nodeString);
  virtual void reloadSimgearList();
  //virtual void getAircraftListSlot2();


protected:
  /*$PROTECTED_FUNCTIONS$*/

protected slots:
  /*$PROTECTED_SLOTS$*/

private slots:

private:
  /*$PERSONNAL FUNCTIONS$*/
  int createIniFiles( QString DestDirectory );
  void changeAirportInformations();
  int loadAirportList();
  void fillObjects();
  bool searchPID(QString appName = 0);
  KFileDialog *m_fileDlg;
  QTimer *m_aircraftSpinTimer;
  bool openglEnabled;

signals:
  void aircraftComboBoxFully();
  void allJobsFinished();
  void loadingData(QString loadData);
  void queryClose();

};

#endif

