/***************************************************************************
 *   KFreeFlight : a FlightGear GUI-Frontend designed for KDE users        *
 *                                                                         *
 *   Copyright (C) 2006 by Didier Fabert                                   *
 *   [didier.fabert AT free.fr]                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "kfreeflight.h"
#include <kfiledialog.h>
/**
 * kfreeflight class constructor: init the kmainwindow
 * @return 
 */
kfreeflight_window::kfreeflight_window()
    : KMainWindow( 0, "kfreeflight" ), m_mainWindow(new KFreeFlight_view(this, "kfreeflight", 0))
{
    QString buffer;

    externExitQuery=false;
    notSystrayIntegrated=false;
    setInstance( KGlobal::instance() );
    m_windowSize = new QSize();

    //setup pointers
    m_config = new KConfig("kfreeflightrc", false, true, "config");

    // tell the KMainWindow that this is indeed the main widget
    setCentralWidget(m_mainWindow);
    // set the shell's ui resource file
    setXMLFile("kfreeflightui.rc");

    // accept dnd
    setAcceptDrops(true);

    // then, setup our actions
    setupAction();

    //size main window
    *m_windowSize = m_mainWindow->minimumSize();
    resize(m_windowSize->width(),m_windowSize->height());
    setFrameBorderWidth(5);

    //create gui
    createGUI(xmlFile(), true);

    //combo box profile manager
    m_profileToolbar = toolBar("mainToolBar");
    m_profileToolbar->insertCombo("Profile", 0, false, SIGNAL(activated(const QString &)),
        this, SLOT(manageProfile(const QString &)),
        true, "Choose a configuration", 200, 0, QComboBox::AtBottom);
    fillComboProfile();
    m_profileToolbar->insertSeparator(1, -1);
    m_profileToolbar->insertLineSeparator(2, -1);

    setAutoSaveSettings();

    //initialising QString pointers
    m_userDirectory = new QString(QDir::homeDirPath ()+AppDirectory);
    m_fileConfig = new QString();

    connect(m_mainWindow, SIGNAL(queryClose()), this, SLOT(hideMainWindow()));
    m_fileDlg = new KFileDialog(QString::null, "text/plain", this, "fileDlg", true);

}

/**
 * kfreeflight class destructor
 * @return 
 */
kfreeflight_window::~kfreeflight_window()
{
    //save config on exit
    m_mainWindow->saveSlot();
    m_config->sync();
}

/**
 * setup the action, toolbar and statusbar
 */
void kfreeflight_window::setupAction()
{
    setStandardToolBarMenuEnabled(true);
    createStandardStatusBarAction();

    //connect the statusbar actions
    actionCollection()->setHighlightingEnabled(true);
    connect(actionCollection(), SIGNAL( actionStatusText( const QString & ) ),
           statusBar(), SLOT( message( const QString & ) ) );
    connect(actionCollection(), SIGNAL( clearStatusText() ),
           statusBar(), SLOT( clear() ) );

    //File entry menu
    KStdAction::quit(this, SLOT(applicationQuit()), actionCollection());
    KStdAction::openNew(this, SLOT(openNewConfig()), actionCollection());
    KStdAction::open(this, SLOT(openConfig()), actionCollection());
    KStdAction::save(this, SLOT(saveConfig()), actionCollection());
    KStdAction::saveAs(this, SLOT(saveAsConfig()), actionCollection());
    KStdAction::revert(this, SLOT(revertConfig()), actionCollection());

    //Settings entry menu
    KStdAction::keyBindings(guiFactory(), SLOT(configureShortcuts()), actionCollection());
    KStdAction::configureToolbars(this, SLOT(configureToolBar()), actionCollection());
    KStdAction::preferences(this, SLOT(optionPreferences()), actionCollection());

    //Help entry menu
    KStdAction::tipOfDay(this, SLOT(optionTipOfDay()), actionCollection())
        ->setShortcut( KShortcut( Key_F10) );
}

void kfreeflight_window::applicationQuit()
{
    m_mainWindow->saveSlot();
    kapp->quit();
}

/**
 * close splashscreen, show application window and determine the config file to use
 */
void kfreeflight_window::splashClosed()
{
    QString buffer;

    //check if tip of day is required
    if (m_config->hasGroup("TipOfDay"))
    {
        m_config->setGroup("TipOfDay");
        buffer=m_config->readEntry("RunOnStart", "true");
        if (buffer == "true") { optionTipOfDay(); }
    }

    //check if config file name is defined otherwise create it
    if (!m_config->hasGroup("Config file"))
    {
        m_config->setGroup("Config file");
        m_config->writeEntry("File","default");
        m_config->sync();
        optionPreferences();
    }
    else
    {
        m_config->setGroup("Config file");
        buffer=m_config->readEntry("File", "default");
    }
    *m_fileConfig = buffer;

    statusBar()->message(tr2i18n( "Current config file :" )+*m_fileConfig );

    applySettings();
}

void kfreeflight_window::fillComboProfile()
{
    QStringList ProfileList;
    QDir ProfileDirectory;

    ProfileDirectory.setPath( QDir::homeDirPath()+"/.kde/share/config/kfreeflight");
    ProfileList = ProfileDirectory.entryList("*", QDir::Files, QDir::Name );

    m_profileToolbar->clearCombo(0);
    m_profileToolbar->insertComboList(0, ProfileList, 0);
}

void kfreeflight_window::manageProfile(const QString &profile)
{
    //write selected config file name in the main config file
    *m_fileConfig = profile;
    m_config->writeEntry("File",*m_fileConfig);
    m_config->sync();
    //emit that settings file is changed to kfreeflight_view
    emit (settingsFileChanged());
    statusBar()->message( tr2i18n( "Current config file name:" )+*m_fileConfig );
}

/**
 * show tip of day window
 */
void kfreeflight_window::optionTipOfDay()
{
    //show tip of day
    KTipDialog::showTip( this, "kfreeflight/tips", true );
}

/**
 * create a new config file
 */
void kfreeflight_window::openNewConfig()
{
    QString buffer;
    QFile file;

    //choice file dialog
    buffer = m_fileDlg->getSaveFileName (QDir::homeDirPath ()+"/.kde/share/config/kfreeflight",
        "text/plain", this,  tr2i18n("Choose a config file to open" ));

    if (!buffer.stripWhiteSpace().isEmpty())
    {
        file.setName(buffer);
        //if file exist -> abort operation
        if ( file.open( IO_ReadOnly ) )
        {
            file.close();
            KMessageBox::sorry( this, tr2i18n("The file you are selected already exist.\nOperation aborted"),
                tr2i18n("Error"), 1);
            return;
        }
        buffer = buffer.section( '/', -1 );
        //else write selected config file name in the main config file
        *m_fileConfig = buffer;
        m_config->setGroup("Config file");
        m_config->writeEntry("File",*m_fileConfig);
        m_config->sync();

        optionPreferences();
        //emit that settings file is changed to kfreeflight_view
        emit (settingsFileChanged());
        statusBar()->message(tr2i18n( "Current config file name :" )+*m_fileConfig );
    }
}

/**
 * open a existing config file
 */
void kfreeflight_window::openConfig()
{
    QString buffer;

    //choice file dialog
    buffer = m_fileDlg->getOpenFileName (QDir::homeDirPath ()+"/.kde/share/config/kfreeflight",
        "text/plain", this,  tr2i18n("Choose a config file to open" ));
    buffer = buffer.section( '/', -1 );
    if (!buffer.stripWhiteSpace().isEmpty())
    {
        //write selected config file name in the main config file
        *m_fileConfig = buffer;
        m_config->writeEntry("File",*m_fileConfig);
        m_config->sync();
        //emit that settings file is changed to kfreeflight_view
        emit (settingsFileChanged());
        statusBar()->message( tr2i18n( "Current config file name:" )+*m_fileConfig );
    }
}

/**
 * save the current config
 */
void kfreeflight_window::saveConfig()
{
    m_mainWindow->saveSlot();
}

/**
 * revert the config saved on disk
 */
void kfreeflight_window::revertConfig()
{
    m_mainWindow->reloadSlot();
}

void kfreeflight_window::saveAsConfig()
{
    QString buffer;
    QFile file;

    m_oldSettings = new KConfig("kfreeflight/"+*m_fileConfig, false, true, "config");
    buffer =  m_fileDlg->getSaveFileName (QDir::homeDirPath ()+"/.kde/share/config/kfreeflight",
        "text/plain", this,  tr2i18n("Choose a config file to open" ));
    file.setName(buffer.stripWhiteSpace());
        //if file exist -> warning message
        if ( file.open( IO_ReadOnly ) )
        {
            file.close();
            if(KMessageBox::warningContinueCancel( this, tr2i18n("Overwrite existed file ?"),
                  tr2i18n("Question")) < 5 ) { return; }
        }
    buffer = buffer.section( '/', -1 );
    *m_fileConfig = buffer;
    m_config->writeEntry("File",*m_fileConfig);
    m_config->sync();
    emit(settingsNewFile());
    m_newSettings = new KConfig("kfreeflight/"+*m_fileConfig, false, true, "config");
    //copy old config window settings
    optionCopySettings();

    m_mainWindow->saveSlot();
    applySettings();
    statusBar()->message( tr2i18n( "Current config file name:" )+*m_fileConfig );
}

void kfreeflight_window::configureToolBar()
{
    KEditToolbar dlg(actionCollection());
    if (dlg.exec())
    {
    createGUI();
    }

    connect(&dlg, SIGNAL(newToolbarConfig()), SLOT(resizeMainWindow()));
}

/**
 * resize the main window
 */
void kfreeflight_window::resizeMainWindow()
{
    //TODO in future version
    //when toolbar change -> resize window
}

/**
 * create and open the configuration dialog
 */
void kfreeflight_window::optionPreferences()
{
    m_prefDialog = new Pref(this);
    m_prefDialog->m_generalConfig = m_config;
    m_prefDialog->show();
    connect(m_prefDialog, SIGNAL(settingsAreChanged()), this, SLOT(applySettings()) );
    connect(m_prefDialog, SIGNAL(queryIntegrated(bool)), this, SLOT(resendQuery(bool)) );
    disconnect(m_prefDialog);
}

void kfreeflight_window::resendQuery(bool query)
{
    emit queryIntegrated(query);
}

/**
 * apply settings
 */
void kfreeflight_window::applySettings()
{
    //emit that settings are changed to kfreeflight_view
    m_config->reparseConfiguration();
    emit (settingsChanged());
}

void kfreeflight_window::hideMainWindow()
{
    queryClose();
}

bool kfreeflight_window::queryClose()
{
    m_config->reparseConfiguration();
    if (notSystrayIntegrated == true) { kapp->quit();}
    else
    {
        if (externExitQuery == false)
        {
            KMessageBox::information(this,
              tr2i18n("You have choosen to integrate KFreeFlightin the system tray")+" \n"
              +tr2i18n("KFreeFlight will still running in the KDE System Tray")
              +".\n"+tr2i18n("Select \"File / Quit\" menu entry or click on Exit icon (toolbar) to exit")+".",
              0, "Don't show it again");
        }
        hide();
        return false;
    }
    return true;
}

void  kfreeflight_window::queryShowAbout()
{
    showAboutApplication();
}

/**
 * copy all pref entries from the old config file in the new one
 */
void kfreeflight_window::optionCopySettings()
{
    QString buffer;

    if (m_oldSettings->hasGroup("Settings General"))
    {
        m_oldSettings->setGroup("Settings General");
        m_newSettings->setGroup("Settings General");

        buffer=m_oldSettings->readEntry("Verbose","false");
        m_newSettings->writeEntry("Verbose",buffer);

        buffer=m_oldSettings->readEntry("WebBrowser","konqueror");
        m_newSettings->writeEntry("WebBrowser",buffer);
    }

//page2
    if (m_oldSettings->hasGroup("Settings Font"))
    {
        m_oldSettings->setGroup("Settings Font");
        m_newSettings->setGroup("Settings Font");

        buffer=m_oldSettings->readEntry("Family","Bitstream Vera Sans");
        m_newSettings->writeEntry("Family",buffer);
        buffer=m_oldSettings->readEntry("PointSize","12");
        m_newSettings->writeEntry("PointSize",buffer);
        buffer=m_oldSettings->readEntry("bold","false");
        m_newSettings->writeEntry("bold",buffer);
        buffer=m_oldSettings->readEntry("italic","false");
        m_newSettings->writeEntry("italic",buffer);
    }

//page3
    if (m_oldSettings->hasGroup("Settings Color"))
    {
        m_oldSettings->setGroup("Settings Color");
        m_newSettings->setGroup("Settings Color");

        buffer=m_oldSettings->readEntry("ForegroundColor", "0,0,0");
        m_newSettings->writeEntry("ForegroundColor",buffer);
        buffer=m_oldSettings->readEntry("BackgroundColor", "255,255,255");
        m_newSettings->writeEntry("BackgroundColor",buffer);
        buffer=m_oldSettings->readEntry("EditColor", "210,210,210");
        m_newSettings->writeEntry("EditColor",buffer);
    }

//page4
    if (m_oldSettings->hasGroup("Settings FlightGear"))
    {
        m_oldSettings->setGroup("Settings FlightGear");
        m_newSettings->setGroup("Settings FlightGear");

        buffer=m_oldSettings->readEntry("FG_ROOT","/usr/share/games/FlightGear");
        m_newSettings->writeEntry("FG_ROOT",buffer);
        buffer=m_oldSettings->readEntry("FG_SCENERY","/usr/share/games/FlightGear/Scenery");
        m_newSettings->writeEntry("FG_SCENERY",buffer);
        buffer=m_oldSettings->readEntry("Executable","fgfs");
        m_newSettings->writeEntry("Executable",buffer);
        buffer=m_oldSettings->readEntry("Executables list","fgfs");
        m_newSettings->writeEntry("Executables list",buffer);
        buffer=m_oldSettings->readEntry("Options list","noOption");
        m_newSettings->writeEntry("Options list",buffer);
    }

//page5
    if (m_oldSettings->hasGroup("Settings Atlas"))
    {
        m_oldSettings->setGroup("Settings Atlas");
        m_newSettings->setGroup("Settings Atlas");
        buffer=m_oldSettings->readEntry("Glut Fonts","false");
        m_newSettings->writeEntry("Glut Fonts",buffer);
        buffer=m_oldSettings->readEntry("Images Directory Path","/usr/share/games/Atlas");
        m_newSettings->writeEntry("Images Directory Path",buffer);
    }
    m_newSettings->sync();
    delete m_oldSettings;
    delete m_newSettings;
}

#include "kfreeflight_window.moc"
