/***************************************************************************
 *   KFreeFlight : a FlightGear GUI-Frontend designed for KDE users        *
 *                                                                         *
 *   Copyright (C) 2006 by Didier Fabert                                   *
 *   [didier.fabert AT free.fr]                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifndef _KFREEFLIGHT_WINDOW_H_
#define _KFREEFLIGHT_WINDOW_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <kmainwindow.h>
#include <kapplication.h>
#include <kconfig.h>
#include <kaction.h>
#include <kstdaction.h>
#include <ktip.h>
#include <kglobal.h>
#include <kedittoolbar.h>
#include <kmessagebox.h>
#include <kactioncollection.h>
#include <kstatusbar.h>
#include <ktoolbar.h>
#include <kcombobox.h>
#include <kfiledialog.h>

#include <qdir.h>
#include <qfile.h>

#include "kfreeflight_view.h"
#include "pref.h"

/**
 * @short Application Main Window
 * @author Didier <didier.fabert@free.fr>
 * @version 0.3.x
 */
class kfreeflight_window : public KMainWindow
{
    Q_OBJECT
public:
    /**
     * Default Constructor
     */
    kfreeflight_window();

    /**
     * Default Destructor
     */
    virtual ~kfreeflight_window();

    KConfig *m_config;
    QSize *m_windowSize;
    QString *m_userDirectory, *m_fileConfig;
    KFreeFlight_view *m_mainWindow;
    Pref *m_prefDialog;
    bool externExitQuery;
    bool notSystrayIntegrated;
    KToolBar *m_profileToolbar;


public slots:

    virtual void optionTipOfDay();
    virtual void optionPreferences();
    virtual void optionCopySettings();
    virtual void applySettings();
    virtual void setupAction();
    virtual void resizeMainWindow();
    virtual void splashClosed();
    virtual void queryShowAbout();
    virtual void manageProfile(const QString &profile);
    virtual void applicationQuit();

private slots:

    virtual void openNewConfig();
    virtual void openConfig();
    virtual void saveConfig();
    virtual void saveAsConfig();
    virtual void revertConfig();
    virtual void configureToolBar();
    virtual void hideMainWindow();
    virtual void resendQuery(bool query);
    virtual void fillComboProfile();

private:

    KConfig *m_oldSettings, *m_newSettings;
    KFileDialog *m_fileDlg;

protected:

    virtual bool queryClose ();

signals:

    void settingsChanged();
    void settingsFileChanged();
    void settingsNewFile();
    void queryIntegrated(bool);
};

#endif // _KFREEFLIGHT_WINDOW_H_
