/***************************************************************************
 *   KFreeFlight : a FlightGear GUI-Frontend designed for KDE users        *
 *                                                                         *
 *   Copyright (C) 2006 by Didier Fabert                                   *
 *   [didier.fabert AT free.fr]                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "pref.h"
#include "app_img.h"

Pref::Pref(QWidget *parent)
 : KDialogBase(IconList, tr2i18n("Preferences"),
                  Help|Default|Ok|Apply|Cancel, Ok)
{
    QFrame *frame;
    QRect framecube( 0, 0, 550, 470 );
    KIconLoader prefPageIcon;
    QString buffer;

    //Initialising pointer
    m_Font = new QFont();
    m_ForegroundColor = new QColor;
    m_BackgroundColor = new QColor;
    m_EditColor = new QColor;
    m_OpenGLColor = new QColor;

    KConfig *m_configTmp = new KConfig("kfreeflightrc", false, true, "config");
    m_configTmp->setGroup("Config file");
    buffer=m_configTmp->readEntry("File", "default");

    m_prefConfig = new KConfig("kfreeflight/"+buffer, false, true, "config");

    frame = addPage(tr2i18n("General"), tr2i18n("General settings"), 
        prefPageIcon.loadIcon("configure", KIcon::NoGroup, 32, 0, 0L, false));
    m_pageOne = new prefPageOne(frame);
    m_pageOne->setGeometry(framecube);
    connect(m_pageOne->m_resetAsking, SIGNAL(clicked()), SLOT(eraseSettingsMessage()));

    frame = addPage(tr2i18n("Font"), tr2i18n("Select Display Font"), 
        prefPageIcon.loadIcon("fonts", KIcon::NoGroup, 32, 0, 0L, false));
    m_pageTwo = new prefPageTwo(frame);
    m_pageTwo->setGeometry(framecube);

    frame = addPage(tr2i18n("Color"), tr2i18n("Button & Display Colors"),
         prefPageIcon.loadIcon("colorize", KIcon::NoGroup, 32, 0, 0L, false));
    m_pageThree = new prefPageThree(frame);
    m_pageThree->setGeometry(framecube);

    frame = addPage(tr2i18n("FlightGear\nPage 1"), tr2i18n("FlightGear settings"),
         prefPageIcon.loadIcon("exec", KIcon::NoGroup, 32, 0, 0L, false));
    m_pageFour = new prefPageFour(frame);
    m_pageFour->setGeometry(framecube);

    frame = addPage(tr2i18n("FlightGear\nPage 2"), tr2i18n("FlightGear settings"),
         prefPageIcon.loadIcon("exec", KIcon::NoGroup, 32, 0, 0L, false));
    m_pageFive = new prefPageFive(frame);
    m_pageFive->setGeometry(framecube);

    frame = addPage(tr2i18n("Atlas"), tr2i18n("Atlas settings"),
         prefPageIcon.loadIcon("exec", KIcon::NoGroup, 32, 0, 0L, false));
    m_pageSix = new prefPageSix(frame);
    m_pageSix->setGeometry(framecube);

    resize( QSize(690, 520));

    if(m_prefConfig->hasGroup("Settings General"))
    {
        loadSettings();
        changeSettings();
    }
    else slotDefault();

}


Pref::~Pref()
{
}

void Pref::slotDefault()
{
    m_pageOne->m_radioBrowser1->setChecked(true);
    m_pageOne->m_checkVerbose->setChecked(false);
    m_pageOne->m_checkFlightgear->setChecked(false);
    m_pageOne->m_minimizedStart->setChecked(false);
    m_pageOne->m_sytrayIntegration->setChecked(true);

    m_Font->setFamily( "Bitstream Vera Sans" );
    m_Font->setPointSize( 12 );
    m_Font->setBold( FALSE );
    m_Font->setItalic( FALSE );
    m_pageTwo->m_fontChooser->setFont(*m_Font);

    m_ForegroundColor->setRgb(0, 0, 0);
    m_pageThree->m_buttonFront->setColor(*m_ForegroundColor);
    m_BackgroundColor->setRgb(25, 25, 85);
    m_pageThree->m_buttonBottom->setColor(*m_BackgroundColor);
    m_EditColor->setRgb(255, 255, 0);
    m_pageThree->m_buttonEdit->setColor(*m_EditColor);

    m_pageFour->m_fgSettings->m_fgroot->setText("/usr/share/games/FlightGear");
    m_pageFour->m_fgSettings->m_fgscenery->setText("/usr/share/games/Data/FlightGear/Scenery");
    m_pageFour->m_fgSettings->m_fgexe->setText("fgfs");
    m_pageFive->m_fgSettingsBis->m_resolutionWidth->setValue(2048);
    m_pageFive->m_fgSettingsBis->m_resolutionHeight->setValue(1280);
    m_pageFive->m_fgSettingsBis->m_justOneInstance->setChecked(true);
    m_pageFive->m_fgSettingsBis->m_httpHost->setText("localhost");
    m_pageFive->m_fgSettingsBis->m_httpPort->setText("5500");

    m_pageSix->m_atlasSettings->m_checkAtlasGlutFont->setChecked(true);
    m_pageSix->m_atlasSettings->m_atlasPath->setText("/usr/share/games/Atlas");
    m_pageSix->m_atlasSettings->m_atlasExe->setText("Atlas");
    m_pageSix->m_atlasSettings->m_justOneInstance->setChecked(true);
}

void Pref::slotApply()
{
    changeSettings();
}

void Pref::slotOk ()
{
    saveSettings();
    m_prefConfig->sync();
    emit settingsAreChanged();
    emit queryIntegrated(m_pageOne->m_sytrayIntegration->isChecked());
    close();
}


prefPageOne::prefPageOne(QWidget *parent)
    : QFrame(parent)
{
    QPixmap pixmap;
    KStandardDirs appShareDir;

    QImage img, imageWebBrowser1, imageWebBrowser2, imageWebBrowser3;
    QFrame *line, *line2, *line3, *line4;

    img.loadFromData( imgKonqueror, sizeof( imgKonqueror ), "PNG" );
    imageWebBrowser1 = img;
    img.loadFromData( imgMozilla, sizeof( imgMozilla ), "PNG" );
    imageWebBrowser2 = img;
    img.loadFromData( imgFirefox, sizeof( imgFirefox ), "PNG" );
    imageWebBrowser3 = img;

    m_checkVerbose = new QCheckBox( tr2i18n("Make application more talkative"), this, "CB_Verbose" );
    m_checkVerbose->setGeometry( QRect( 0, 10, 500, 20 ) );

    line = new QFrame( this, "line" );
    line->setGeometry( QRect( 0, 40, 550, 20 ) );
    line->setFrameShape( QFrame::HLine );
    line->setFrameShadow( QFrame::Sunken );
    line->setLineWidth( 2 );
    line->setFrameShape( QFrame::HLine );

    m_chooseBrowser = new QLabel( tr2i18n("Choose your web browser"), this );
    m_chooseBrowser->setGeometry( QRect( 0, 60, 281, 30 ) );

    m_browserGroup = new QButtonGroup( this, "m_browserGroup" );
    m_browserGroup->setGeometry( QRect( 10, 100, 520, 40 ) );
    m_browserGroup->setFrameShape( QButtonGroup::NoFrame );

    m_radioBrowser1 = new QRadioButton( m_browserGroup, "RB_Navigator_1" );
    m_radioBrowser1->setGeometry( QRect( 0, 0, 50, 26 ) );
    m_radioBrowser1->setFocusPolicy( QRadioButton::NoFocus );
    m_radioBrowser1->setPixmap( imageWebBrowser1 );

    m_textBrowser1 = new QLabel( tr2i18n( "Konqueror" ), m_browserGroup, "TXTLabel_browser1" );
    m_textBrowser1->setGeometry( QRect( 40, 0, 100, 26 ) );

    m_textBrowser2 = new QLabel( tr2i18n( "Mozilla" ), m_browserGroup, "TXTLabel_browser2" );
    m_textBrowser2->setGeometry( QRect( 210, 0, 87, 26 ) );

    m_radioBrowser2 = new QRadioButton( m_browserGroup, "RB_Navigator_2" );
    m_radioBrowser2->setGeometry( QRect( 160, 0, 50, 26 ) );
    m_radioBrowser2->setFocusPolicy( QRadioButton::NoFocus );
    m_radioBrowser2->setPixmap( imageWebBrowser2 );

    m_radioBrowser3 = new QRadioButton( m_browserGroup, "RB_Navigator_3" );
    m_radioBrowser3->setGeometry( QRect( 330, 0, 50, 26 ) );
    m_radioBrowser3->setFocusPolicy( QRadioButton::NoFocus );
    m_radioBrowser3->setPixmap( imageWebBrowser3 );

    m_textBrowser3 = new QLabel( tr2i18n( "Firefox" ), m_browserGroup, "TXTLabel_browser3" );
    m_textBrowser3->setGeometry( QRect( 380, 0, 87, 26 ) );

    line2 = new QFrame( this, "line2" );
    line2->setGeometry( QRect( 0, 130, 550, 20 ) );
    line2->setFrameShape( QFrame::HLine );
    line2->setFrameShadow( QFrame::Sunken );
    line2->setLineWidth( 2 );
    line2->setFrameShape( QFrame::HLine );

    m_checkFlightgear = new QCheckBox( tr2i18n("Show FlightGear messages"), this, "CB_fgfsTalkative" );
    m_checkFlightgear->setGeometry( QRect( 0, 160, 500, 20 ) );

    m_resetAsking = new QPushButton(this,"BTN_ResetAsking");
    m_resetAsking->setGeometry( QRect( 0, 200, 550, 30 ) );
    m_resetAsking->setText(tr2i18n("Reset \"Don't show it again\""));

    line3 = new QFrame( this, "line3" );
    line3->setGeometry( QRect( 0, 240, 550, 20 ) );
    line3->setFrameShape( QFrame::HLine );
    line3->setFrameShadow( QFrame::Sunken );
    line3->setLineWidth( 2 );
    line3->setFrameShape( QFrame::HLine );

    m_sytrayIntegration = new QCheckBox( tr2i18n("Integrate in the system tray"), this, "CB_Systray" );
    m_sytrayIntegration->setGeometry( QRect( 0, 260, 500, 20 ) );
    m_minimizedStart = new QCheckBox( tr2i18n("If integrated in the system tray, starting minimized"), this, "CB_Minimized" );
    m_minimizedStart->setGeometry( QRect( 0, 290, 500, 20 ) );


    line4 = new QFrame( this, "line4" );
    line4->setGeometry( QRect( 0, 320, 550, 20 ) );
    line4->setFrameShape( QFrame::HLine );
    line4->setFrameShadow( QFrame::Sunken );
    line4->setLineWidth( 2 );
    line4->setFrameShape( QFrame::HLine );

    m_aircraftLabel = new QLabel(0, this);
    m_aircraftLabel->setGeometry( QRect( 220, 350, 88, 66 ) );
    m_aircraftLabel->setScaledContents(true);
    pixmap.loadFromData( tuxaircraft, sizeof( tuxaircraft ), "PNG" );
    m_aircraftLabel->setPixmap(pixmap);
}

prefPageTwo::prefPageTwo(QWidget *parent)
    : QFrame(parent)
{
    QVBoxLayout *layout = new QVBoxLayout(this);
    layout->setAutoAdd(true);

    m_fontChooser = new KFontChooser( this, "m_FontChooser", false, QStringList(), true, 8, false, 0L);

}

prefPageThree::prefPageThree(QWidget *parent)
    : QFrame(parent)
{
    QPixmap aircraft;
    aircraft.loadFromData( tuxaircraft, sizeof( tuxaircraft ), "PNG" );

    m_grp = new QGroupBox(this, "group");
    m_grp->setGeometry( QRect( 30, 10, 500, 250 ) );
    m_grp->setTitle(tr2i18n("Display color") );

    m_foreground = new QLabel(tr2i18n("Foreground"), m_grp);
    m_foreground->setGeometry( QRect( 30, 30, 180, 30) );
    m_background = new QLabel(tr2i18n("Background"), m_grp);
    m_background->setGeometry( QRect( 30, 80, 180, 30) );
    m_edit = new QLabel(tr2i18n("Foreground\nfield edition "), m_grp);
    m_edit->setGeometry( QRect( 30, 130, 180, 60) );
    m_opengl = new QLabel(tr2i18n("OpenGL Window"), m_grp);
    m_opengl->setGeometry( QRect( 30, 200, 180, 30) );


    m_buttonFront = new KColorButton(m_grp, "front");
    m_buttonFront->setGeometry( QRect( 300, 30, 130, 30) );

    m_buttonBottom = new KColorButton(m_grp, "bottom");
    m_buttonBottom->setGeometry( QRect( 300, 80, 130, 30) );

    m_buttonEdit = new KColorButton(m_grp, "edit");
    m_buttonEdit->setGeometry( QRect( 300, 140, 130, 30) );

    m_buttonOpengl = new KColorButton(m_grp, "opengl");
    m_buttonOpengl->setGeometry( QRect( 300, 200, 130, 30) );

    m_aircraftLabel = new QLabel(0, this);
    m_aircraftLabel->setGeometry( QRect( 180, 300, 175, 132 ) );
    m_aircraftLabel->setPixmap(aircraft);

}

prefPageFour::prefPageFour(QWidget *parent)
    : QFrame(parent)
{
    m_fgSettings = new FgPref(this, "General", 0);
}

prefPageFive::prefPageFive(QWidget *parent)
    : QFrame(parent)
{
    m_fgSettingsBis = new FgPrefBis(this, "General", 0);
}

prefPageSix::prefPageSix(QWidget *parent)
    : QFrame(parent)
{
    m_atlasSettings = new AtlasPref(this, "General", 0);
}

void Pref::changeSettings()
{

    *m_Font = m_pageTwo->m_fontChooser->font();
    *m_ForegroundColor = m_pageThree->m_buttonFront->color();
    *m_BackgroundColor = m_pageThree->m_buttonBottom->color();
    *m_EditColor = m_pageThree->m_buttonEdit->color();

//page4
    m_pageFour->m_fgSettings->m_fgroot->setPaletteBackgroundColor( *m_BackgroundColor );
    m_pageFour->m_fgSettings->m_fgroot->setPaletteForegroundColor( *m_EditColor );
    m_pageFour->m_fgSettings->m_fgscenery->setPaletteBackgroundColor( *m_BackgroundColor );
    m_pageFour->m_fgSettings->m_fgscenery->setPaletteForegroundColor( *m_EditColor );
    m_pageFour->m_fgSettings->m_fgexelist->setPaletteBackgroundColor( *m_BackgroundColor );
    m_pageFour->m_fgSettings->m_fgexelist->setPaletteForegroundColor( *m_EditColor );
    m_pageFour->m_fgSettings->m_fgexe->setPaletteBackgroundColor( *m_BackgroundColor );
    m_pageFour->m_fgSettings->m_fgexe->setPaletteForegroundColor( *m_EditColor );
    m_pageFour->m_fgSettings->m_fgoptionslist->setPaletteBackgroundColor( *m_BackgroundColor );
    m_pageFour->m_fgSettings->m_fgoptionslist->setPaletteForegroundColor( *m_EditColor );
    m_pageFour->m_fgSettings->m_fgoptions->setPaletteBackgroundColor( *m_BackgroundColor );
    m_pageFour->m_fgSettings->m_fgoptions->setPaletteForegroundColor( *m_EditColor );
    m_pageFour->m_fgSettings->m_fgexeadd->setPaletteForegroundColor( *m_ForegroundColor );
    m_pageFour->m_fgSettings->m_fgexedel->setPaletteForegroundColor( *m_ForegroundColor );
    m_pageFour->m_fgSettings->m_fgoptionsadd->setPaletteForegroundColor( *m_ForegroundColor );
    m_pageFour->m_fgSettings->m_fgoptionsdel->setPaletteForegroundColor( *m_ForegroundColor );

//page 5
    m_pageFive->m_fgSettingsBis->m_httpHost->setPaletteForegroundColor( *m_EditColor );
    m_pageFive->m_fgSettingsBis->m_httpPort->setPaletteForegroundColor( *m_EditColor );
    m_pageFive->m_fgSettingsBis->m_resolutionHeight->setPaletteForegroundColor( *m_EditColor );
    m_pageFive->m_fgSettingsBis->m_resolutionWidth->setPaletteForegroundColor( *m_EditColor );
    m_pageFive->m_fgSettingsBis->m_httpHost->setPaletteBackgroundColor( *m_BackgroundColor );
    m_pageFive->m_fgSettingsBis->m_httpPort->setPaletteBackgroundColor( *m_BackgroundColor );
    m_pageFive->m_fgSettingsBis->m_resolutionHeight->setPaletteBackgroundColor( *m_BackgroundColor );
    m_pageFive->m_fgSettingsBis->m_resolutionWidth->setPaletteBackgroundColor( *m_BackgroundColor );

//page6
    m_pageSix->m_atlasSettings->m_atlasPath->setPaletteBackgroundColor( *m_BackgroundColor );
    m_pageSix->m_atlasSettings->m_atlasPath->setPaletteForegroundColor( *m_EditColor );
    m_pageSix->m_atlasSettings->m_atlasExe->setPaletteBackgroundColor( *m_BackgroundColor );
    m_pageSix->m_atlasSettings->m_atlasExe->setPaletteForegroundColor( *m_EditColor );
    setFont( *m_Font );
    setPaletteForegroundColor( *m_ForegroundColor );
}

void Pref::loadSettings()
{
    QString buffer, buf1, buf2, buf3;
    QStringList list;
    int r, g, b;
    int i;

//page1
    if (m_prefConfig->hasGroup("Settings General"))
    {
        m_prefConfig->setGroup("Settings General");
        buffer=m_prefConfig->readEntry("Verbose","false");
        if (buffer == "true") { m_pageOne->m_checkVerbose->setChecked(true); }
        else  { m_pageOne->m_checkVerbose->setChecked(false); }
        buffer=m_prefConfig->readEntry("WebBrowser",m_pageOne->m_textBrowser1->text().stripWhiteSpace().lower());
        if (buffer == m_pageOne->m_textBrowser1->text().stripWhiteSpace().lower()) 
            { m_pageOne->m_radioBrowser1->setChecked(true); }
        if (buffer == m_pageOne->m_textBrowser2->text().stripWhiteSpace().lower()) 
            { m_pageOne->m_radioBrowser2->setChecked(true); }
        if (buffer == m_pageOne->m_textBrowser3->text().stripWhiteSpace().lower()) 
            { m_pageOne->m_radioBrowser3->setChecked(true); }
        buffer=m_prefConfig->readEntry("FGFS messages","false");
        if (buffer == "true") { m_pageOne->m_checkFlightgear->setChecked(true); }
        else  { m_pageOne->m_checkFlightgear->setChecked(false); }
        buffer=m_prefConfig->readEntry("Minimized starting","false");
        if (buffer == "true") { m_pageOne->m_minimizedStart->setChecked(true); }
        else  { m_pageOne->m_minimizedStart->setChecked(false); }
        buffer=m_prefConfig->readEntry("Systray integration","false");
        if (buffer == "true") { m_pageOne->m_sytrayIntegration->setChecked(true); }
        else  { m_pageOne->m_sytrayIntegration->setChecked(false); }
    }

//page2
    if (m_prefConfig->hasGroup("Settings Font"))
    {
        m_prefConfig->setGroup("Settings Font");
        buffer=m_prefConfig->readEntry("Family","Bitstream Vera Sans");
        m_Font->setFamily(buffer);
        buffer=m_prefConfig->readEntry("PointSize","12");
        m_Font->setPointSize( buffer.toInt() );
        buffer=m_prefConfig->readEntry("bold","false");
        if (buffer == "1") m_Font->setBold( TRUE );
        if (buffer == "0") m_Font->setBold( FALSE );
        buffer=m_prefConfig->readEntry("italic","false");
        if (buffer == "1") m_Font->setItalic( TRUE );
        if (buffer == "0") m_Font->setItalic( FALSE );
        m_pageTwo->m_fontChooser->setFont(*m_Font);
    }

//page3
    if (m_prefConfig->hasGroup("Settings Color"))
    {
        m_prefConfig->setGroup("Settings Color");

        buffer=m_prefConfig->readEntry("ForegroundColor", "0,0,0");
        buf1=buffer; buf2=buffer; buf3=buffer;
        r=buf1.section(',',0,0).toInt();
        g=buf2.section(',',1,1).toInt();
        b=buf3.section(',',2,2).toInt();
        m_ForegroundColor->setRgb(r, g, b);
        m_pageThree->m_buttonFront->setColor(*m_ForegroundColor);

        buffer=m_prefConfig->readEntry("BackgroundColor", "25,25,85");
        buf1=buffer; buf2=buffer; buf3=buffer;
        r=buf1.section(',',0,0).toInt();
        g=buf2.section(',',1,1).toInt();
        b=buf3.section(',',2,2).toInt();
        m_BackgroundColor->setRgb(r, g, b);
        m_pageThree->m_buttonBottom->setColor(*m_BackgroundColor);

        buffer=m_prefConfig->readEntry("EditColor", "255,255,0");
        buf1=buffer; buf2=buffer; buf3=buffer;
        r=buf1.section(',',0,0).toInt();
        g=buf2.section(',',1,1).toInt();
        b=buf3.section(',',2,2).toInt();
        m_EditColor->setRgb(r, g, b);
        m_pageThree->m_buttonEdit->setColor(*m_EditColor);

        buffer=m_prefConfig->readEntry("OpenGL Color", "23,64,105");
        buf1=buffer; buf2=buffer; buf3=buffer;
        r=buf1.section(',',0,0).toInt();
        g=buf2.section(',',1,1).toInt();
        b=buf3.section(',',2,2).toInt();
        m_OpenGLColor->setRgb(r, g, b);
        m_pageThree->m_buttonOpengl->setColor(*m_OpenGLColor);
    }

//page4 & 5
    if (m_prefConfig->hasGroup("Settings FlightGear"))
    {
        m_prefConfig->setGroup("Settings FlightGear");
        buffer=m_prefConfig->readEntry("FG_ROOT","/usr/share/games/FlightGear");
        m_pageFour->m_fgSettings->m_fgroot->setText(buffer);
        buffer=m_prefConfig->readEntry("FG_SCENERY","/usr/share/games/FlightGear/Scenery");
        m_pageFour->m_fgSettings->m_fgscenery->setText(buffer);
        buffer=m_prefConfig->readEntry("Executable","fgfs");
        m_pageFour->m_fgSettings->m_fgexe->setText(buffer);
        buffer=m_prefConfig->readEntry("Executables list","fgfs");
        for (i=0 ; i < (buffer.contains(',',false)+1) ; i++)
        {
            buf1 = buffer;
            m_pageFour->m_fgSettings->m_fgexelist->insertItem(buf1.section(',',i,i),i);
        }
        buffer=m_prefConfig->readEntry("Options list","noOption");
        if((buffer != "noOption") && (buffer != ""))
        {
            for (i=0 ; i < (buffer.contains(',',false)+1) ; i++)
            {
                buf1 = buffer;
                m_pageFour->m_fgSettings->m_fgoptionslist->insertItem(buf1.section(',',i,i),i);
            }
        }
        buffer=m_prefConfig->readEntry("Personnal resolution","2048x1280");
        m_pageFive->m_fgSettingsBis->m_resolutionWidth->setValue(buffer.section('x',0,0).toInt());
        m_pageFive->m_fgSettingsBis->m_resolutionHeight->setValue(buffer.section('x',1,1).toInt());
        buffer=m_prefConfig->readEntry("Only one instance","false");
        if (buffer == "true") { m_pageFive->m_fgSettingsBis->m_justOneInstance->setChecked(true);}
        else  { m_pageFive->m_fgSettingsBis->m_justOneInstance->setChecked(false); }
    }
    if (m_prefConfig->hasGroup("Flightgear Network"))
    {
        m_prefConfig->setGroup("Flightgear Network");
        buffer=m_prefConfig->readEntry("PortHttp","5500");
        m_pageFive->m_fgSettingsBis->m_httpPort->setText(buffer);
        buffer=m_prefConfig->readEntry("HostHttp","localhost");
        m_pageFive->m_fgSettingsBis->m_httpHost->setText(buffer);
    }

//page6
    if (m_prefConfig->hasGroup("Settings Atlas"))
    {
        m_prefConfig->setGroup("Settings Atlas");
        buffer=m_prefConfig->readEntry("Glut Fonts","false");
        if (buffer == "true") { m_pageSix->m_atlasSettings->m_checkAtlasGlutFont->setChecked(true);}
        else  { m_pageSix->m_atlasSettings->m_checkAtlasGlutFont->setChecked(false); }
        buffer=m_prefConfig->readEntry("Images Directory Path","/usr/share/games/Atlas");
        m_pageSix->m_atlasSettings->m_atlasPath->setText(buffer);
        buffer=m_prefConfig->readEntry("Atlas exe","Atlas");
        m_pageSix->m_atlasSettings->m_atlasExe->setText(buffer);
        buffer=m_prefConfig->readEntry("Only one instance","false");
        if (buffer == "true") { m_pageSix->m_atlasSettings->m_justOneInstance->setChecked(true);}
        else  { m_pageSix->m_atlasSettings->m_justOneInstance->setChecked(false); }
    }
}

void Pref::saveSettings()
{
    QString buffer, buf1, buf2, buf3;
    int r, g, b;
    uint i;
//page1
    m_prefConfig->setGroup("Settings General");
    if (m_pageOne->m_checkVerbose->isChecked())
        m_prefConfig->writeEntry("Verbose","true");
    else
        m_prefConfig->writeEntry("Verbose","false");

    if (m_pageOne->m_radioBrowser1->isChecked())
        m_prefConfig->writeEntry("WebBrowser",m_pageOne->m_textBrowser1->text().lower());

    if (m_pageOne->m_radioBrowser2->isChecked())
        m_prefConfig->writeEntry("WebBrowser",m_pageOne->m_textBrowser2->text().lower());

    if (m_pageOne->m_radioBrowser3->isChecked())
        m_prefConfig->writeEntry("WebBrowser",m_pageOne->m_textBrowser3->text().lower());

    if (m_pageOne->m_checkFlightgear->isChecked())
        m_prefConfig->writeEntry("FGFS messages","true");
    else
        m_prefConfig->writeEntry("FGFS messages","false");

    if (m_pageOne->m_minimizedStart->isChecked())
        m_prefConfig->writeEntry("Minimized starting","true");
    else
        m_prefConfig->writeEntry("Minimized starting","false");

    if (m_pageOne->m_sytrayIntegration->isChecked())
        m_prefConfig->writeEntry("Systray integration","true");
    else
        m_prefConfig->writeEntry("Systray integration","false");

//page2
    m_prefConfig->setGroup("Settings Font");
    *m_Font = m_pageTwo->m_fontChooser->font();
    m_prefConfig->writeEntry("Family",m_Font->family());
    m_prefConfig->writeEntry("PointSize",buffer.setNum(m_Font->pointSize(),10));
    m_prefConfig->writeEntry("bold",buffer.sprintf("%d",m_Font->bold() ));
    m_prefConfig->writeEntry("italic",buffer.sprintf("%d",m_Font->italic() ));

//page3
    m_prefConfig->setGroup("Settings Color");

    *m_ForegroundColor = m_pageThree->m_buttonFront->color();
    m_ForegroundColor->getRgb(&r, &g, &b);
    buffer=buf1.setNum(r,10)+","+buf2.setNum(g,10)+","+buf3.setNum(b,10);
    m_prefConfig->writeEntry("ForegroundColor",buffer);

    *m_BackgroundColor = m_pageThree->m_buttonBottom->color();
    m_BackgroundColor->getRgb(&r, &g, &b);
    buffer=buf1.setNum(r,10)+","+buf2.setNum(g,10)+","+buf3.setNum(b,10);
    m_prefConfig->writeEntry("BackgroundColor",buffer);

    *m_EditColor = m_pageThree->m_buttonEdit->color();
    m_EditColor->getRgb(&r, &g, &b);
    buffer=buf1.setNum(r,10)+","+buf2.setNum(g,10)+","+buf3.setNum(b,10);
    m_prefConfig->writeEntry("EditColor",buffer);

    *m_OpenGLColor = m_pageThree->m_buttonOpengl->color();
    m_OpenGLColor->getRgb(&r, &g, &b);
    buffer=buf1.setNum(r,10)+","+buf2.setNum(g,10)+","+buf3.setNum(b,10);
    m_prefConfig->writeEntry("OpenGL Color",buffer);

//page4 & 5
    m_prefConfig->setGroup("Settings FlightGear");
    m_prefConfig->writeEntry("FG_ROOT",m_pageFour->m_fgSettings->m_fgroot->text());
    m_prefConfig->writeEntry("FG_SCENERY",m_pageFour->m_fgSettings->m_fgscenery->text());
    m_prefConfig->writeEntry("Executable",m_pageFour->m_fgSettings->m_fgexe->text());
    buffer="";
    for (i=0 ; i < (m_pageFour->m_fgSettings->m_fgexelist->count()) ; i++)
    {
        m_pageFour->m_fgSettings->m_fgexelist->setCurrentItem(i);
        buffer.append(m_pageFour->m_fgSettings->m_fgexelist->currentText().stripWhiteSpace());
        if (i != (m_pageFour->m_fgSettings->m_fgexelist->count()-1))
            buffer.append(",");
    }
    m_prefConfig->writeEntry("Executables list",buffer);
    buffer="";
    for (i=0 ; i < (m_pageFour->m_fgSettings->m_fgoptionslist->count()) ; i++)
    {
        m_pageFour->m_fgSettings->m_fgoptionslist->setCurrentItem(i);
        buffer.append(m_pageFour->m_fgSettings->m_fgoptionslist->currentText().stripWhiteSpace());
        if (i != (m_pageFour->m_fgSettings->m_fgoptionslist->count()-1))
            buffer.append(",");
    }
    m_prefConfig->writeEntry("Options list",buffer);
    buffer=m_pageFive->m_fgSettingsBis->m_resolutionWidth->text().stripWhiteSpace()+"x"+
        m_pageFive->m_fgSettingsBis->m_resolutionHeight->text().stripWhiteSpace();
    m_prefConfig->writeEntry("Personnal resolution",buffer);
    if (m_pageFive->m_fgSettingsBis->m_justOneInstance->isChecked())
        m_prefConfig->writeEntry("Only one instance","true");
    else
        m_prefConfig->writeEntry("Only one instance","false");

    m_prefConfig->setGroup("Flightgear Network");
    m_prefConfig->writeEntry("PortHttp",m_pageFive->m_fgSettingsBis->m_httpPort->text().stripWhiteSpace()) ;
    m_prefConfig->writeEntry("HostHttp",m_pageFive->m_fgSettingsBis->m_httpHost->text().stripWhiteSpace()) ;

//page6
    m_prefConfig->setGroup("Settings Atlas");
    if (m_pageSix->m_atlasSettings->m_checkAtlasGlutFont->isChecked())
        m_prefConfig->writeEntry("Glut Fonts","true");
    else
        m_prefConfig->writeEntry("Glut Fonts","false");
    m_prefConfig->writeEntry("Images Directory Path",m_pageSix->m_atlasSettings->m_atlasPath->text());
    m_prefConfig->writeEntry("Atlas exe",m_pageSix->m_atlasSettings->m_atlasExe->text());
    if (m_pageSix->m_atlasSettings->m_justOneInstance->isChecked())
        m_prefConfig->writeEntry("Only one instance","true");
    else
        m_prefConfig->writeEntry("Only one instance","false");
}

void Pref::eraseSettingsMessage()
{
    m_prefConfig->deleteGroup("Notification Messages", true, false );
    m_generalConfig->deleteGroup("Notification Messages", true, false );
    m_prefConfig->sync();
    m_generalConfig->sync();
}
