/***************************************************************************
 *   KFreeFlight : a FlightGear GUI-Frontend designed for KDE users        *
 *                                                                         *
 *   Copyright (C) 2006 by Didier Fabert                                   *
 *   [didier.fabert AT free.fr]                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef PREF_H
#define PREF_H

#include <kdialogbase.h>
#include <kfontdialog.h>
#include <kconfig.h>
#include <kcolorbutton.h>
#include <kiconloader.h>
#include <klocale.h>
#include <kstandarddirs.h>
#include <kmessagebox.h>

#include <qgroupbox.h>
#include <qlabel.h>
#include <qframe.h>
#include <qradiobutton.h>
#include <qcheckbox.h>
#include <qlayout.h>
#include <qrect.h>
#include <qframe.h>
#include <qfont.h>
#include <qimage.h>
#include <qlabel.h>
#include <qbuttongroup.h>
#include <qpushbutton.h>

#include "fgpref.h"
#include "fgprefbis.h"
#include "atlaspref.h"

class prefPageOne;
class prefPageTwo;
class prefPageThree;
class prefPageFour;
class prefPageFive;
class prefPageSix;

/**
	@author Didier <didier.fabert@free.fr>
*/
class Pref : public KDialogBase
{
    Q_OBJECT
public:
    Pref(QWidget *parent=0);
    ~Pref();
    KConfig *m_generalConfig;

public slots:
    virtual void   eraseSettingsMessage();

protected:
    //virtual void   slotHelp();  // connect by default in man app page
    virtual void   slotDefault ();
    virtual void   slotOk ();
    virtual void   slotApply ();
    //virtual void   slotCancel (); //connect by default -> close

private:
    prefPageOne *m_pageOne;
    prefPageTwo *m_pageTwo;
    prefPageThree *m_pageThree;
    prefPageFour *m_pageFour;
    prefPageFive *m_pageFive;
    prefPageSix *m_pageSix;

    KConfig *m_prefConfig;
    QFont *m_Font;
    QColor *m_ForegroundColor, *m_BackgroundColor, *m_EditColor, *m_OpenGLColor;
    //functions
    void changeSettings();
    void loadSettings();
    void saveSettings();


signals:
    void settingsAreChanged();
    void updateFgWidget();
    void updateAtlasWidget();
    void queryIntegrated(bool);
};

class prefPageOne : public QFrame
{
    Q_OBJECT
public:
    prefPageOne(QWidget *parent = 0);
    QLabel *m_chooseBrowser, *m_textBrowser1, *m_textBrowser2, *m_textBrowser3;
    QButtonGroup *m_browserGroup;
    QRadioButton *m_radioBrowser1, *m_radioBrowser2, *m_radioBrowser3;
    QCheckBox *m_checkVerbose, *m_checkFlightgear, *m_minimizedStart, *m_sytrayIntegration;
    QLabel *m_aircraftLabel;
    QPushButton *m_resetAsking;
};

class prefPageTwo : public QFrame
{
    Q_OBJECT
public:
    prefPageTwo(QWidget *parent = 0);
    KFontChooser *m_fontChooser;
};

class prefPageThree : public QFrame
{
    Q_OBJECT
public:
    prefPageThree(QWidget *parent = 0);
    KColorButton *m_buttonFront, *m_buttonEdit, *m_buttonBottom, *m_buttonOpengl;
    QGroupBox *m_grp;
    QLabel *m_aircraftLabel, *m_foreground, *m_background, *m_edit, *m_opengl;
};

class prefPageFour : public QFrame
{
    Q_OBJECT
public:
    prefPageFour(QWidget *parent = 0);
    FgPref *m_fgSettings;
};

class prefPageFive : public QFrame
{
    Q_OBJECT
public:
    prefPageFive(QWidget *parent = 0);
    FgPrefBis *m_fgSettingsBis;
};

class prefPageSix : public QFrame
{
    Q_OBJECT
public:
    prefPageSix(QWidget *parent = 0);
    AtlasPref *m_atlasSettings;
};
#endif
