/***************************************************************************
 *   KFreeFlight : a FlightGear GUI-Frontend designed for KDE users        *
 *                                                                         *
 *   Copyright (C) 2006 by Didier Fabert                                   *
 *   [didier.fabert AT free.fr]                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#include "weather_view.h"

Weather_view::Weather_view(QWidget* parent, const char* name, WFlags fl,
    QString AirportID, QString HomeDirectory )
: weatherwindow(parent,name,fl)
{
    LE_AirportID->setText(AirportID);
    m_homeDirectory = new QString(HomeDirectory);
    m_appShareDir = new KStandardDirs();
}

Weather_view::~Weather_view()
{
}

/*$SPECIALIZATION$*/
void Weather_view::downloadMetarSlot()
{
    //download METAR and save it in the user app directory
    //wget -P ~/.kfreeflight ftp://weather.noaa.gov/data/observations/metar/stations/LFML.TXT

    KProcess *getMetarFile;
    QString buffer, fichier;
    QStringList list;
    gzFile m_metarfile;
    char line[128];
    int It;
    bool flagFoundInDatabase=false;

    //Find the name
    fichier = LE_AirportID->text().simplifyWhiteSpace().upper();

    //check in databse if exist
    m_config->setGroup("Settings FlightGear");
    buffer=m_config->readEntry("FG_ROOT", "undefined");
    buffer.append("/Airports/metar.dat.gz");
    m_metarfile = gzopen( buffer, "rb" );
    if (m_metarfile == 0)
    {
        KMessageBox::sorry(this, buffer+"\n"
            +tr2i18n("file not found!\n\nPlease check your FG_ROOT path in the settings menu."));
        return;
    }
    for (It=0; gzgets( m_metarfile, line, sizeof line ) != 0 ; It++)
    {
        buffer = line;
        if (buffer.simplifyWhiteSpace().contains(fichier,true) > 0)
        {
            flagFoundInDatabase = true;
            break;
        }
    }
    gzclose(m_metarfile);
    if ( flagFoundInDatabase == false)
    {
        switch (KMessageBox::warningYesNo(this, fichier+"\n"
            +tr2i18n("This METAR doesn't exist in metar.dat.gz file.\n")
            +tr2i18n("Try download anyway ?")))
        {
            case 3: break;
            default: return;
        }
        //return;
    }

    //Set correct name
    fichier.prepend(*m_homeDirectory+"/Weather/");
    fichier.append(".TXT");
    //file.setName(fichier);
    m_metarFile = new QFile(fichier);

    //if update is checked delete file
    if (CB_update->isChecked()) m_metarFile->remove();

    //check if file exist
    if ( !m_metarFile->open( IO_ReadOnly ) )
    {
        m_metarFile->close();
        CB_update->setChecked(false);
        //if not download
        getMetarFile=new KProcess;

        *getMetarFile << "wget -P";
        buffer=*m_homeDirectory+"/Weather/";
        *getMetarFile << buffer;
        buffer = LE_AirportID->text().upper().stripWhiteSpace()+".TXT";
        buffer.prepend("ftp://weather.noaa.gov/data/observations/metar/stations/");
        *getMetarFile << buffer;
        getMetarFile->setUseShell(true,"/bin/sh");

        QApplication::connect(getMetarFile, SIGNAL(processExited(KProcess *)),
                         this, SLOT(showMetarSlot(KProcess *)));
        if(!(getMetarFile->start(KProcess::NotifyOnExit, KProcess::AllOutput)))
        {
            KMessageBox::information(this,tr2i18n("Could not download metar file"));
        }
        TXTEdit_METAR->clear();
        TXTEdit_METAR->setText(tr2i18n("Please wait during processing.\n"
            "It may take a long time."));
        BTN_Download->setEnabled(false);
    }
    else { m_metarFile->close(); CB_update->setChecked(false); showMetarSlot(0);}
}

void Weather_view::showMetarSlot(KProcess *)
{
    QString buffer, fichier;
    QStringList list;
    QTextStream stream;
    int i;

    BTN_Download->setEnabled(true);
    LE_Temperature->setText("");
    LE_TemperatureMin->setText("");
    LE_Presure->setText("");
    LE_Visibility->setText("");
    LE_VisibilityObscuring->setText("");
    LE_Precipitation->setText("");
    LE_WindSpeedMax->setText("");
    LE_WindDirection->setText("");
    LE_WindSpeed->setText("");
    LE_WindDirectionVariable->setText("");
    LE_Date->setText("");
    LE_Time->setText("");
    LE_Airport->setText("");
    LE_CloudAltitude1->clear();
    LE_CloudAltitude2->clear();
    LE_CloudAltitude3->clear();
    LE_CloudsString1->clear();
    LE_CloudsString2->clear();
    LE_CloudsString3->clear();

    //Read the file and put it in the TXTEdit_METAR
    TXTEdit_METAR->clear();
    if ( m_metarFile->open( IO_ReadOnly ) )
    {
        i=0;
        stream.setDevice( m_metarFile );

        while ( !stream.atEnd() )
        {
            buffer = stream.readLine();
            TXTEdit_METAR->append(buffer);
            dataParsing( buffer.simplifyWhiteSpace(), i);
            i++;
        }
        m_metarFile->close();
    }
    else KMessageBox::information(this,tr2i18n("Could not open metar file"));
}

void Weather_view::dataParsing(QString data, int It)
{
    QString buffer;
    int i=0;

    switch (It)
    {
        case 0:
        {
            LE_Date->setText(data.section(' ',0,0));
            LE_Time->setText(data.section(' ',1,1));
            break;
        }
        case 1:
        {
            if ((data.section(' ',2,2) == "AUTO") || (data.section(' ',2,2) == "COR")) i++;
            LE_Airport->setText(data.section(' ',0,0));
            if (data.section(' ',2+i,2+i).left(3) == "VRB") 
                { LE_WindDirection->setText(tr2i18n("Variable")); }
            else { LE_WindDirection->setText(data.section(' ',2+i,2+i).left(3)); }
            if (data.section(' ',2+i,2+i).contains('G',true) > 0)
            {
                buffer=data.section(' ',2+i,2+i);
                LE_WindSpeedMax->setText(buffer.section('G',1,1).remove("KT",true));
            }
            if ((data.section(' ',3+i,3+i).contains('V',true) > 0) && 
              ((data.section(' ',3+i,3+i) != "CAVOK") && (data.section(' ',3+i,3+i).right(3) != "NDV") ))
            {
                buffer=data.section(' ',3+i,3+i);
                buffer=buffer.section('V',0,0)+"-"+buffer.section('V',1,1);
                LE_WindDirectionVariable->setText(buffer);
            }
            //if contains MPS il faut multiplier par deux
            if (data.section(' ',2+i,2+i).contains("MPS") > 0)
            {
                buffer=buffer.setNum(data.section(' ',2+i,2+i).mid(3,2).toInt()*2,10);
                LE_WindSpeed->setText(buffer);
                if (data.section(' ',2+i,2+i).contains('G',true) > 0)
                {
                    buffer=buffer.setNum
                      (data.section(' ',2+i,2+i).section('G',1,1).remove("MPS",true).toInt()*2,10);
                    LE_WindSpeedMax->setText(buffer.remove("MPS",true));
                }
            }
            //si KT c'est directement en noeuds
            if (data.section(' ',2+i,2+i).contains("KT") > 0)
            {
                LE_WindSpeed->setText(data.section(' ',2+i,2+i).mid(3,2));
                if (data.section(' ',2+i,2+i).contains('G',true) > 0)
                {
                    buffer=data.section(' ',2+i,2+i);
                    LE_WindSpeedMax->setText(buffer.section('G',1,1).remove("KT",true));
                }
            }
            LE_Temperature->setText(findInData(data, "temperature", data.contains(' ', false)+2));
            LE_TemperatureMin->setText(findInData(data, "temperatureMin", data.contains(' ', false)+2));
            LE_Presure->setText(findInData(data, "presure", data.contains(' ', false)+2));
            findInData( data, "ceiling", data.contains(' ', false)+2);
            LE_Visibility->setText(findInData(data, "visibility", data.contains(' ', false)+2));
            LE_VisibilityObscuring->setText(findInData(data, "obscuring", data.contains(' ', false)+2));
            LE_Precipitation->setText(findInData(data, "precipitation", data.contains(' ', false)+2));
            break;
        }
        default: return;
    }
}

QString Weather_view::findInData(QString data, QString type, int lengthTotal)
{
    QString buffer, buffer2, rabbit, rabbit2, pixmapString;
    int i, j;
    uint minLength;
    bool unitIso=false;
    QPixmap weatherPixmap;
    static int length;

    if(type == "presure")
    {
        rabbit="A"; rabbit2="Q"; minLength=5;

        for(i=0; i<lengthTotal; i++)
        {
            if ((data.section(' ',i,i).left(1) == rabbit) || (data.section(' ',i,i).left(1) == rabbit2))
            {
                buffer = data.section(' ',i,i);
                if ((data.section(' ',i,i).left(1) == rabbit2) && (data.section(' ',i,i).left(1) != rabbit))
                    unitIso=true;
                if (buffer.length() >= minLength) {length=i; break;}
            }
        }
        if (unitIso == false) return buffer.mid(1,2)+"."+buffer.mid(3,2);
        else
        {
            if (LE_Temperature->text().toInt() > 15 )
                buffer2.setNum((buffer.mid(1,4).toDouble()*100)/3377.18,'f',2);
            else buffer2.setNum((buffer.mid(1,4).toDouble()*100)/3386.38,'f',2);
            return buffer2;
        }
    }
    if(type == "temperature")
    {
        for(i=0; i<lengthTotal; i++)
        {
            if ((data.section(' ',i,i).simplifyWhiteSpace().contains('/',false) > 0)
                && ((data.section(' ',i,i).replace('M',"").replace('/',"").toInt() > 0) || 
                (data.section(' ',i,i).replace('M',"").replace('/',"") == "0000") ) )
            {
                 buffer = data.section(' ',i,i);
                 break;
            }
        }
        return buffer.section('/',0,0).replace('M',"-");
    }

    if(type == "temperatureMin" ) 
    {
        for(i=0; i<lengthTotal; i++)
        {
            if ((data.section(' ',i,i).simplifyWhiteSpace().contains('/',false) > 0)
                && ((data.section(' ',i,i).replace('M',"").replace('/',"").toInt() > 0) || 
                (data.section(' ',i,i).replace('M',"").replace('/',"") == "0000") ) )
            {
                 buffer = data.section(' ',i,i);
                 break;
            }
        }
        return buffer.section('/',1,1).replace('M',"-");
    }
    if(type == "visibility")
    {
        for(i=3; i<=5; i++)
        {
            buffer = data.section(" ",i,i);

            if (buffer.contains("SM",false) > 0)
            {
                if (buffer.contains("/2",false) > 0)
                {
                    buffer2 = buffer2.setNum(((data.section(" ",i-1,i-1).remove('M').toInt()*1600)+800),10);
                    return buffer2;
                }
                if (buffer.contains("/4",false) > 0)
                {
                    buffer2 = buffer2.setNum(((data.section(" ",i-1,i-1).remove('M').toInt()*1600)+400),10);
                    return buffer2;
                }
                else
                {
                    buffer2 = buffer2.setNum(buffer.remove("SM").toInt()*1600, 10);
                    if (buffer.remove("SM").toInt()*1600 >= 1000)
                    buffer2=buffer2.left(2)+" "+buffer2.right(3);
                    return buffer2;
                }
                return buffer2;
            }
            else
            {
                if ((data.section(' ',i,i).remove("NDV").toInt() > 0) || (data.section(' ',i,i) == "CAVOK") )
                {
                    buffer = data.section(" ",i,i).remove("NDV");
                    if ((buffer.toInt() >= 9999) || (buffer == "CAVOK") ) buffer ="> 10 000";
                    if (buffer.toInt() >=1000) buffer=buffer.left(1)+" "+buffer.right(3);
                    return buffer;
                }
            }
        }
    }
    if(type == "precipitation" ) 
    {
        buffer="";
        pixmapString="";
        for(i=0; i<length; i++)
        {
            if (data.section(' ',i,i) == "CAVOK") buffer=tr2i18n("None");
            if (data.section(' ',i,i).contains("DZ",false))
              { buffer=buffer.append(tr2i18n("Drizzle")+" "); pixmapString="light_rain"; }
            if (data.section(' ',i,i).contains("RA",false))
              { buffer=buffer.append(tr2i18n("Rain")+" "); pixmapString="shower3"; }
            if (data.section(' ',i,i).contains("SN",false))
              { buffer=buffer.append(tr2i18n("Snow")+" "); pixmapString="snow4"; }
            if (data.section(' ',i,i).contains("SG",false))
              { buffer=buffer.append(tr2i18n("Snow grains")+" "); pixmapString="snow5"; }
            if (data.section(' ',i,i).contains("IC",false))
              { buffer=buffer.append(tr2i18n("Ice Crystals")+" "); pixmapString="snow5"; }
            if (data.section(' ',i,i).contains("PL",false))
              { buffer=buffer.append(tr2i18n("Ice pellets")+" "); pixmapString="snow5"; }
            if (data.section(' ',i,i).contains("GR",false))
              { buffer=buffer.append(tr2i18n("Hail")+" "); pixmapString="hail"; }
            if (data.section(' ',i,i).contains("GS",false)) 
              { buffer=buffer.append(tr2i18n("Small hail / snow pellets ")); pixmapString="snow5"; }
            if (buffer != "")
            {
                if (data.section(' ',i,i).contains('+',false) > 0) buffer.prepend(tr2i18n("Heavy")+" ");
                if (data.section(' ',i,i).contains('-',false) > 0) buffer.prepend(tr2i18n("Light")+" ");
                break;
            }
        }
        for(i=0; i<length; i++)
        {
            if (data.section(' ',i,i).contains("TS",true) > 0)
                { buffer.prepend(tr2i18n("Thunderstorm")+" + "); pixmapString="tstorm3"; }
            if ((data.section(' ',i,i).contains("TS",true) > 0) && (buffer ==""))
                { buffer=tr2i18n("Thunderstorm"); pixmapString="tstorm3"; }
        }
        if (pixmapString != "")
        {
            pixmapString.append(".png");
            pixmapString.prepend("kweather/");
            weatherPixmap.load(m_appShareDir->findResource("data",pixmapString),
                "PNG", QPixmap::Auto);
            PixmapLabel_Clouds->setPixmap(weatherPixmap);
        }
        if (buffer != "") return buffer;
        else return buffer=tr2i18n("None");
    }
    if(type == "obscuring" ) 
    {
        buffer="";
        pixmapString="";
        for(i=0; i<length; i++)
        {
            if (data.section(' ',i,i) == "MI") buffer.append(tr2i18n("Shallow")+" ");
            if (data.section(' ',i,i) == "PR") buffer.append(tr2i18n("Partiel")+" ");
            if (data.section(' ',i,i) == "BR")
              { buffer.append(tr2i18n("Mist")+" "); pixmapString="mist"; }
            if (data.section(' ',i,i) == "FG")
              { buffer.append(tr2i18n("Fog")+" "); pixmapString="fog"; }
            if (data.section(' ',i,i) == "FU") buffer.append(tr2i18n("Smoke")+" ");
            if (data.section(' ',i,i) == "VA") buffer.append(tr2i18n("Volcanic Ash")+" ");
            if (data.section(' ',i,i) == "DU") buffer.append(tr2i18n("Widespread Dust")+" "); 
            if (data.section(' ',i,i) == "SA") buffer.append(tr2i18n("Sand")+" ");
            if (data.section(' ',i,i) == "HZ") buffer.append(tr2i18n("Haze")+" ");
            if (data.section(' ',i,i) == "FZ") buffer.append(tr2i18n("Freezing")+" ");
        }
        if (pixmapString != "")
        {
            pixmapString.append(".png");
            pixmapString.prepend("kweather/");
            weatherPixmap.load(m_appShareDir->findResource("data",pixmapString),
                "PNG", QPixmap::Auto);
            PixmapLabel_Clouds->setPixmap(weatherPixmap);
        }
        return buffer;
    }
    if(type == "ceiling")
    {
        j=0;cloudsChangeWidget( j);
        for(i=0; i<length; i++)
        {
            //KMessageBox::sorry(this, "essai");
            if ((data.section(' ',i,i).contains("CAVOK") > 0) || (data.section(' ',i,i).contains("SKC") > 0)
                || (data.section(' ',i,i).contains("NSC") > 0) )
            {
                buffer=data.section(' ',i,i);
                buffer.simplifyWhiteSpace();
                m_cloudsString->setText(tr2i18n("Sky Clear"));
                pixmapString="sunny";
                break;
            }
            if (data.section(' ',i,i).contains("CLR") > 0)
            {
                m_cloudsString->setText(tr2i18n("Automatic METAR without cloud layer report"));
                m_cloudsAltitude->setText("< 12 000");
                pixmapString="dunno";
                break;
            }
            if ((data.section(' ',i,i).contains("FEW") > 0))
            {
                buffer=data.section(' ',i,i);
                buffer.simplifyWhiteSpace();
                m_cloudsAltitude->setText
                  (buffer.section('W',1,1).remove('/').remove("TCU").remove("TCB").remove("CB").left(2)+" "+
                  buffer.section('W',1,1).remove('/').remove("TCU").remove("TCB").remove("CB").right(1)+"00");
                m_cloudsString->setText(tr2i18n("Few"));
                if (j == 0) { pixmapString="cloudy1"; }
                j++;cloudsChangeWidget( j);
            }
            if ((data.section(' ',i,i).contains("SCT") > 0))
            {
                buffer=data.section(' ',i,i);
                buffer.simplifyWhiteSpace();
                m_cloudsAltitude->setText
                  (buffer.section('T',1,1).remove('/').remove("TCU").remove("TCB").remove("CB").left(2)+" "+
                  buffer.section('T',1,1).remove('/').remove("TCU").remove("TCB").remove("CB").right(1)+"00");
                m_cloudsString->setText(tr2i18n("Scattered"));
                if (j == 0) { pixmapString="cloudy2"; }
                j++;cloudsChangeWidget( j);
            }
            if ((data.section(' ',i,i).contains("BKN") > 0))
            {
                buffer=data.section(' ',i,i);
                buffer.simplifyWhiteSpace();
                m_cloudsAltitude->setText
                  (buffer.section('N',1,1).remove('/').remove("TCU").remove("TCB").remove("CB").left(2)+" "+
                  buffer.section('N',1,1).remove('/').remove("TCU").remove("TCB").remove("CB").right(1)+"00");
                m_cloudsString->setText(tr2i18n("Boken"));
                if (j == 0) { pixmapString="cloudy3"; }
                j++;cloudsChangeWidget( j);
            }
            if ((data.section(' ',i,i).contains("OVC") > 0))
            {
                buffer=data.section(' ',i,i);
                buffer.simplifyWhiteSpace();
                m_cloudsAltitude->setText
                  (buffer.section('C',1,1).remove('/').remove("TCU").remove("TCB").remove("CB").left(2)+" "+
                  buffer.section('C',1,1).remove('/').remove("TCU").remove("TCB").remove("CB").right(1)+"00");
                m_cloudsString->setText(tr2i18n("Overcast"));
                if (j == 0) { pixmapString="cloudy4"; }
                j++;cloudsChangeWidget( j);
            }
        }
        pixmapString.append(".png");
        pixmapString.prepend("kweather/");
        weatherPixmap.load(m_appShareDir->findResource("data",pixmapString),
            "PNG", QPixmap::Auto);
        PixmapLabel_Clouds->setPixmap(weatherPixmap);
    }

    return buffer="NA";
}

void Weather_view::cloudsChangeWidget( int it)
{
    switch (it)
    {
        case 0: { m_cloudsAltitude=LE_CloudAltitude1; m_cloudsString=LE_CloudsString1;break; }
        case 1: { m_cloudsAltitude=LE_CloudAltitude2; m_cloudsString=LE_CloudsString2;break; }
        case 2: { m_cloudsAltitude=LE_CloudAltitude3; m_cloudsString=LE_CloudsString3;break; }
        default: return ;
    }
}

void Weather_view::applySettings()
{
    setFont(*m_font);
    setPaletteForegroundColor( *m_foreground );

    BTN_WeatherClose->setPaletteForegroundColor( *m_foreground );
    BTN_Download->setPaletteForegroundColor( *m_foreground );
    LE_Temperature->setPaletteForegroundColor( *m_edit );
    LE_TemperatureMin->setPaletteForegroundColor( *m_edit );
    LE_Presure->setPaletteForegroundColor( *m_edit );
    LE_Visibility->setPaletteForegroundColor( *m_edit );
    LE_VisibilityObscuring->setPaletteForegroundColor( *m_edit );
    LE_Precipitation->setPaletteForegroundColor( *m_edit );
    LE_Precipitation2->setPaletteForegroundColor( *m_edit );
    LE_WindSpeedMax->setPaletteForegroundColor( *m_edit );
    LE_WindDirection->setPaletteForegroundColor( *m_edit );
    LE_WindSpeed->setPaletteForegroundColor( *m_edit );
    LE_WindDirectionVariable->setPaletteForegroundColor( *m_edit );
    LE_Date->setPaletteForegroundColor( *m_edit );
    LE_Time->setPaletteForegroundColor( *m_edit );
    LE_Airport->setPaletteForegroundColor( *m_edit );
    TXTEdit_METAR->setPaletteForegroundColor( *m_edit );
    LE_AirportID->setPaletteForegroundColor( *m_edit );
    LE_CloudAltitude1->setPaletteForegroundColor( *m_edit );
    LE_CloudAltitude2->setPaletteForegroundColor( *m_edit );
    LE_CloudAltitude3->setPaletteForegroundColor( *m_edit );
    LE_CloudsString1->setPaletteForegroundColor( *m_edit );
    LE_CloudsString2->setPaletteForegroundColor( *m_edit );
    LE_CloudsString3->setPaletteForegroundColor( *m_edit );

    LE_Temperature->setPaletteBackgroundColor( *m_background );
    LE_TemperatureMin->setPaletteBackgroundColor( *m_background );
    LE_Presure->setPaletteBackgroundColor( *m_background );
    LE_Visibility->setPaletteBackgroundColor( *m_background );
    LE_VisibilityObscuring->setPaletteBackgroundColor( *m_background );
    LE_Precipitation->setPaletteBackgroundColor( *m_background );
    LE_Precipitation2->setPaletteBackgroundColor( *m_background );
    LE_WindSpeedMax->setPaletteBackgroundColor( *m_background );
    LE_WindDirection->setPaletteBackgroundColor( *m_background );
    LE_WindSpeed->setPaletteBackgroundColor( *m_background );
    LE_WindDirectionVariable->setPaletteBackgroundColor( *m_background );
    LE_Date->setPaletteBackgroundColor( *m_background );
    LE_Time->setPaletteBackgroundColor( *m_background );
    LE_Airport->setPaletteBackgroundColor( *m_background );
    TXTEdit_METAR->setPaletteBackgroundColor( *m_background );
    LE_AirportID->setPaletteBackgroundColor( *m_background );
    LE_CloudAltitude1->setPaletteBackgroundColor( *m_background );
    LE_CloudAltitude2->setPaletteBackgroundColor( *m_background );
    LE_CloudAltitude3->setPaletteBackgroundColor( *m_background );
    LE_CloudsString1->setPaletteBackgroundColor( *m_background );
    LE_CloudsString2->setPaletteBackgroundColor( *m_background );
    LE_CloudsString3->setPaletteBackgroundColor( *m_background );
}

void Weather_view::closeWindowSlot()
{
    close();
}

#include "weather_view.moc"
