/***************************************************************************
 *   KFreeFlight : a FlightGear GUI-Frontend designed for KDE users        *
 *                                                                         *
 *   Copyright (C) 2006 by Didier Fabert                                   *
 *   [didier.fabert AT free.fr]                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#include "world_view.h"



World_view::World_view(QWidget* parent, const char* name, WFlags fl, KConfig* config)
: worldMap(parent,name,fl)
{
    QString buffer;

    m_point = PixmapLabel_Point;
    m_close=BTN_Close;
    m_change=BTN_ChangeImage;
    m_showGrid=BTN_ShowGrid;
    m_timer = new QTimer(this);
    m_worldMap = new QPixmap();
    m_appShareDir = new KStandardDirs();

    flagFatPoint=false;
    flagToggled=true;
    flagMinor=false;
    flagNoSave=false;
    It=0;

    m_config=config;

    m_config->setGroup("Settings World Map");
    buffer=m_config->readEntry("Map", "0");
    It=buffer.toInt()-1;
    changeImageSlot();
    PixmapLabel_World->setScaledContents(true);
    PixmapLabel_World->setPixmap(*m_worldMap);
    PixmapLabel_Point->lower();
    connect(m_timer, SIGNAL(timeout()), SLOT(animPointSlot()));
    m_timer->start(75, false);
}

World_view::~World_view()
{
    m_timer->stop();
    delete m_timer;
    closeSlot();
}

/*$SPECIALIZATION$*/
void World_view::animationPointSlot()
{
    if(flagToggled == false )
    {
        BTN_ShowGrid->setText(tr2i18n("Stop Animation"));
        m_timer->start(75, false);
        flagToggled=true;
    }
    else
    {
        BTN_ShowGrid->setText(tr2i18n("Restart Animation"));

        m_timer->stop();
        while (flagMinor == false) { minorPointSizeSlot(); }
        flagToggled=false;
    }
}

void World_view::animPointSlot()
{
    if(flagFatPoint == false) majorPointSizeSlot();
    else minorPointSizeSlot();

}

void World_view::putPoint(int widthOffset, int heightOffset)
{
    PixmapLabel_Point->move(((widthOffset*2)+365)-(PixmapLabel_Point->width()/2),
        ((heightOffset*-2)+185)-(PixmapLabel_Point->height()/2));
    PixmapLabel_Point->raise();
}

void World_view::minorPointSizeSlot()
{
  if (PixmapLabel_Point->width() > 3)
  {
    PixmapLabel_Point->setFixedSize(QSize(PixmapLabel_Point->width()-2, PixmapLabel_Point->height()-2));
    PixmapLabel_Point->move(PixmapLabel_Point->x()+1, PixmapLabel_Point->y()+1);
  }
  if (PixmapLabel_Point->width() <= 3) { flagFatPoint=false; flagMinor=true; }
}

void World_view::majorPointSizeSlot()
{
  if (PixmapLabel_Point->width() < 15)
  {
    PixmapLabel_Point->setFixedSize(QSize(PixmapLabel_Point->width()+2, PixmapLabel_Point->height()+2));
    PixmapLabel_Point->move(PixmapLabel_Point->x()-1, PixmapLabel_Point->y()-1);
    flagMinor=false;
  }
  if (PixmapLabel_Point->width() >= 15) { flagFatPoint=true; }
}

void World_view::closeSlot()
{
    QString buffer;

    if (flagNoSave == false)
    {
        buffer=buffer.setNum(It,10);
        m_config->setGroup("Settings World Map");
        m_config->writeEntry("Map", buffer);
        m_config->sync();
    }
    close();
}

void World_view::changeImageSlot()
{
    QString imgDirectory;

    It++;
    if(It >= 8) It=0;
    switch (It)
    {
        case 1: { imgDirectory="kworldclock/maps/alt/800.jpg"; break; }
        case 2: { imgDirectory="kworldclock/maps/caida/800.jpg"; break; }
        case 3: { imgDirectory="kworldclock/maps/caida_bw/800.jpg"; break; }
        case 4: { imgDirectory="kworldclock/maps/depths/800.jpg"; break; }
        case 5: { imgDirectory="kworldclock/maps/flatworld/800.jpg"; break; }
        case 6: { imgDirectory="kworldclock/maps/mggd/800.jpg"; break; }
        case 7: { imgDirectory="kworldclock/maps/rainfall/800.jpg"; break; }
        default: { imgDirectory="kworldclock/maps/bio/800.jpg"; }
    }
    if(m_worldMap->load(m_appShareDir->findResource("data", imgDirectory),
        "JPEG", QPixmap::Auto))
    {
        PixmapLabel_World->setPixmap(*m_worldMap);
        PixmapLabel_Point->raise();
    }
    else
    {
        imgDirectory=QDir::homeDirPath ();
        imgDirectory.append("/.kfreeflight/800.jpg" );
        m_worldMap->load(imgDirectory, "JPEG", QPixmap::Auto);
        flagNoSave=true;
    }
}


#include "world_view.moc"

